( cd lib ; rm -rf libncurses.so.5 )
( cd lib ; ln -sf libncurses.so.5.4 libncurses.so.5 )
( cd lib ; rm -rf libncursesw.so.5 )
( cd lib ; ln -sf libncursesw.so.5.4 libncursesw.so.5 )
( cd usr/bin ; rm -rf infotocap )
( cd usr/bin ; ln -sf tic infotocap )
( cd usr/bin ; rm -rf reset )
( cd usr/bin ; ln -sf tset reset )
( cd usr/bin ; rm -rf captoinfo )
( cd usr/bin ; ln -sf tic captoinfo )
( cd usr/lib ; rm -rf libformw.so )
( cd usr/lib ; ln -sf libformw.so.5 libformw.so )
( cd usr/lib ; rm -rf libcurses.so )
( cd usr/lib ; ln -sf libncurses.so libcurses.so )
( cd usr/lib ; rm -rf libmenu.so )
( cd usr/lib ; ln -sf libmenu.so.5 libmenu.so )
( cd usr/lib ; rm -rf libformw.so.5 )
( cd usr/lib ; ln -sf libformw.so.5.4 libformw.so.5 )
( cd usr/lib ; rm -rf libcurses.a )
( cd usr/lib ; ln -sf libncurses.a libcurses.a )
( cd usr/lib ; rm -rf libform.so )
( cd usr/lib ; ln -sf libform.so.5 libform.so )
( cd usr/lib ; rm -rf terminfo )
( cd usr/lib ; ln -sf ../share/terminfo terminfo )
( cd usr/lib ; rm -rf libmenu.so.5 )
( cd usr/lib ; ln -sf libmenu.so.5.4 libmenu.so.5 )
( cd usr/lib ; rm -rf libcursesw.so )
( cd usr/lib ; ln -sf libncursesw.so libcursesw.so )
( cd usr/lib ; rm -rf libmenuw.so )
( cd usr/lib ; ln -sf libmenuw.so.5 libmenuw.so )
( cd usr/lib ; rm -rf libpanelw.so )
( cd usr/lib ; ln -sf libpanelw.so.5 libpanelw.so )
( cd usr/lib ; rm -rf libncursesw.so )
( cd usr/lib ; ln -sf /lib/libncursesw.so.5 libncursesw.so )
( cd usr/lib ; rm -rf libpanelw.so.5 )
( cd usr/lib ; ln -sf libpanelw.so.5.4 libpanelw.so.5 )
( cd usr/lib ; rm -rf libncurses.so )
( cd usr/lib ; ln -sf /lib/libncurses.so.5 libncurses.so )
( cd usr/lib ; rm -rf libmenuw.so.5 )
( cd usr/lib ; ln -sf libmenuw.so.5.4 libmenuw.so.5 )
( cd usr/lib ; rm -rf libpanel.so.5 )
( cd usr/lib ; ln -sf libpanel.so.5.4 libpanel.so.5 )
( cd usr/lib ; rm -rf libform.so.5 )
( cd usr/lib ; ln -sf libform.so.5.4 libform.so.5 )
( cd usr/lib ; rm -rf libpanel.so )
( cd usr/lib ; ln -sf libpanel.so.5 libpanel.so )
( cd usr/man/man1 ; rm -rf reset.1.gz )
( cd usr/man/man1 ; ln -sf tset.1.gz reset.1.gz )
( cd usr/man/man3 ; rm -rf innstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_instr.3x.gz innstr.3x.gz )
( cd usr/man/man3 ; rm -rf killchar.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termattrs.3x.gz killchar.3x.gz )
( cd usr/man/man3 ; rm -rf pechochar.3x.gz )
( cd usr/man/man3 ; ln -sf curs_pad.3x.gz pechochar.3x.gz )
( cd usr/man/man3 ; rm -rf delch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_delch.3x.gz delch.3x.gz )
( cd usr/man/man3 ; rm -rf insch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_insch.3x.gz insch.3x.gz )
( cd usr/man/man3 ; rm -rf winch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inch.3x.gz winch.3x.gz )
( cd usr/man/man3 ; rm -rf new_field.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_new.3x.gz new_field.3x.gz )
( cd usr/man/man3 ; rm -rf wadd_wchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wchstr.3x.gz wadd_wchstr.3x.gz )
( cd usr/man/man3 ; rm -rf tparm.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz tparm.3x.gz )
( cd usr/man/man3 ; rm -rf cbreak.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz cbreak.3x.gz )
( cd usr/man/man3 ; rm -rf mvaddch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addch.3x.gz mvaddch.3x.gz )
( cd usr/man/man3 ; rm -rf erase.3x.gz )
( cd usr/man/man3 ; ln -sf curs_clear.3x.gz erase.3x.gz )
( cd usr/man/man3 ; rm -rf mvin_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_in_wch.3x.gz mvin_wch.3x.gz )
( cd usr/man/man3 ; rm -rf mvdelch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_delch.3x.gz mvdelch.3x.gz )
( cd usr/man/man3 ; rm -rf mvwhline.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border.3x.gz mvwhline.3x.gz )
( cd usr/man/man3 ; rm -rf keyname.3x.gz )
( cd usr/man/man3 ; ln -sf curs_util.3x.gz keyname.3x.gz )
( cd usr/man/man3 ; rm -rf mvinsch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_insch.3x.gz mvinsch.3x.gz )
( cd usr/man/man3 ; rm -rf mvwinch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inch.3x.gz mvwinch.3x.gz )
( cd usr/man/man3 ; rm -rf move_panel.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz move_panel.3x.gz )
( cd usr/man/man3 ; rm -rf is_wintouched.3x.gz )
( cd usr/man/man3 ; ln -sf curs_touch.3x.gz is_wintouched.3x.gz )
( cd usr/man/man3 ; rm -rf field_opts_off.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_opts.3x.gz field_opts_off.3x.gz )
( cd usr/man/man3 ; rm -rf dupwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_window.3x.gz dupwin.3x.gz )
( cd usr/man/man3 ; rm -rf idlok.3x.gz )
( cd usr/man/man3 ; ln -sf curs_outopts.3x.gz idlok.3x.gz )
( cd usr/man/man3 ; rm -rf set_panel_userptr.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz set_panel_userptr.3x.gz )
( cd usr/man/man3 ; rm -rf reset_shell_mode.3x.gz )
( cd usr/man/man3 ; ln -sf curs_kernel.3x.gz reset_shell_mode.3x.gz )
( cd usr/man/man3 ; rm -rf curs_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_kernel.3x.gz curs_set.3x.gz )
( cd usr/man/man3 ; rm -rf field_arg.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_validation.3x.gz field_arg.3x.gz )
( cd usr/man/man3 ; rm -rf mvins_wstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_ins_wstr.3x.gz mvins_wstr.3x.gz )
( cd usr/man/man3 ; rm -rf set_field_opts.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_opts.3x.gz set_field_opts.3x.gz )
( cd usr/man/man3 ; rm -rf newpad.3x.gz )
( cd usr/man/man3 ; ln -sf curs_pad.3x.gz newpad.3x.gz )
( cd usr/man/man3 ; rm -rf set_field_type.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_validation.3x.gz set_field_type.3x.gz )
( cd usr/man/man3 ; rm -rf mvvline_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border_set.3x.gz mvvline_set.3x.gz )
( cd usr/man/man3 ; rm -rf waddnwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addwstr.3x.gz waddnwstr.3x.gz )
( cd usr/man/man3 ; rm -rf set_form_init.3x.gz )
( cd usr/man/man3 ; ln -sf form_hook.3x.gz set_form_init.3x.gz )
( cd usr/man/man3 ; rm -rf wcolor_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz wcolor_set.3x.gz )
( cd usr/man/man3 ; rm -rf mvhline_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border_set.3x.gz mvhline_set.3x.gz )
( cd usr/man/man3 ; rm -rf set_item_term.3x.gz )
( cd usr/man/man3 ; ln -sf menu_hook.3x.gz set_item_term.3x.gz )
( cd usr/man/man3 ; rm -rf item_opts_off.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_opts.3x.gz item_opts_off.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_userptr.3x.gz )
( cd usr/man/man3 ; ln -sf menu_userptr.3x.gz set_menu_userptr.3x.gz )
( cd usr/man/man3 ; rm -rf _traceattr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_trace.3x.gz _traceattr.3x.gz )
( cd usr/man/man3 ; rm -rf scr_restore.3x.gz )
( cd usr/man/man3 ; ln -sf curs_scr_dump.3x.gz scr_restore.3x.gz )
( cd usr/man/man3 ; rm -rf mcprint.3x.gz )
( cd usr/man/man3 ; ln -sf curs_print.3x.gz mcprint.3x.gz )
( cd usr/man/man3 ; rm -rf endwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_initscr.3x.gz endwin.3x.gz )
( cd usr/man/man3 ; rm -rf set_field_userptr.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_userptr.3x.gz set_field_userptr.3x.gz )
( cd usr/man/man3 ; rm -rf mvwaddnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addstr.3x.gz mvwaddnstr.3x.gz )
( cd usr/man/man3 ; rm -rf scale_form.3x.gz )
( cd usr/man/man3 ; ln -sf form_win.3x.gz scale_form.3x.gz )
( cd usr/man/man3 ; rm -rf qiflush.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz qiflush.3x.gz )
( cd usr/man/man3 ; rm -rf resetty.3x.gz )
( cd usr/man/man3 ; ln -sf curs_kernel.3x.gz resetty.3x.gz )
( cd usr/man/man3 ; rm -rf item_value.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_value.3x.gz item_value.3x.gz )
( cd usr/man/man3 ; rm -rf form_opts_off.3x.gz )
( cd usr/man/man3 ; ln -sf form_opts.3x.gz form_opts_off.3x.gz )
( cd usr/man/man3 ; rm -rf mvwget_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_get_wch.3x.gz mvwget_wch.3x.gz )
( cd usr/man/man3 ; rm -rf set_field_buffer.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_buffer.3x.gz set_field_buffer.3x.gz )
( cd usr/man/man3 ; rm -rf savetty.3x.gz )
( cd usr/man/man3 ; ln -sf curs_kernel.3x.gz savetty.3x.gz )
( cd usr/man/man3 ; rm -rf use_default_colors.3x.gz )
( cd usr/man/man3 ; ln -sf default_colors.3x.gz use_default_colors.3x.gz )
( cd usr/man/man3 ; rm -rf wget_wstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_get_wstr.3x.gz wget_wstr.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_spacing.3x.gz )
( cd usr/man/man3 ; ln -sf menu_spacing.3x.gz set_menu_spacing.3x.gz )
( cd usr/man/man3 ; rm -rf field_status.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_buffer.3x.gz field_status.3x.gz )
( cd usr/man/man3 ; rm -rf wrefresh.3x.gz )
( cd usr/man/man3 ; ln -sf curs_refresh.3x.gz wrefresh.3x.gz )
( cd usr/man/man3 ; rm -rf color_content.3x.gz )
( cd usr/man/man3 ; ln -sf curs_color.3x.gz color_content.3x.gz )
( cd usr/man/man3 ; rm -rf item_description.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_name.3x.gz item_description.3x.gz )
( cd usr/man/man3 ; rm -rf box_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border_set.3x.gz box_set.3x.gz )
( cd usr/man/man3 ; rm -rf erasewchar.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termattrs.3x.gz erasewchar.3x.gz )
( cd usr/man/man3 ; rm -rf wattr_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz wattr_set.3x.gz )
( cd usr/man/man3 ; rm -rf set_form_page.3x.gz )
( cd usr/man/man3 ; ln -sf form_page.3x.gz set_form_page.3x.gz )
( cd usr/man/man3 ; rm -rf getmaxyx.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getyx.3x.gz getmaxyx.3x.gz )
( cd usr/man/man3 ; rm -rf is_linetouched.3x.gz )
( cd usr/man/man3 ; ln -sf curs_touch.3x.gz is_linetouched.3x.gz )
( cd usr/man/man3 ; rm -rf mvadd_wchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wchstr.3x.gz mvadd_wchstr.3x.gz )
( cd usr/man/man3 ; rm -rf waddstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addstr.3x.gz waddstr.3x.gz )
( cd usr/man/man3 ; rm -rf del_panel.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz del_panel.3x.gz )
( cd usr/man/man3 ; rm -rf wechochar.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addch.3x.gz wechochar.3x.gz )
( cd usr/man/man3 ; rm -rf mvwinsnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_insstr.3x.gz mvwinsnstr.3x.gz )
( cd usr/man/man3 ; rm -rf hline.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border.3x.gz hline.3x.gz )
( cd usr/man/man3 ; rm -rf leaveok.3x.gz )
( cd usr/man/man3 ; ln -sf curs_outopts.3x.gz leaveok.3x.gz )
( cd usr/man/man3 ; rm -rf vidputs.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz vidputs.3x.gz )
( cd usr/man/man3 ; rm -rf slk_attroff.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_attroff.3x.gz )
( cd usr/man/man3 ; rm -rf set_form_sub.3x.gz )
( cd usr/man/man3 ; ln -sf form_win.3x.gz set_form_sub.3x.gz )
( cd usr/man/man3 ; rm -rf termattrs.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termattrs.3x.gz termattrs.3x.gz )
( cd usr/man/man3 ; rm -rf tgoto.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termcap.3x.gz tgoto.3x.gz )
( cd usr/man/man3 ; rm -rf waddchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addchstr.3x.gz waddchstr.3x.gz )
( cd usr/man/man3 ; rm -rf echo_wchar.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wch.3x.gz echo_wchar.3x.gz )
( cd usr/man/man3 ; rm -rf wtouchln.3x.gz )
( cd usr/man/man3 ; ln -sf curs_touch.3x.gz wtouchln.3x.gz )
( cd usr/man/man3 ; rm -rf standout.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz standout.3x.gz )
( cd usr/man/man3 ; rm -rf mvcur.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz mvcur.3x.gz )
( cd usr/man/man3 ; rm -rf mvhline.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border.3x.gz mvhline.3x.gz )
( cd usr/man/man3 ; rm -rf hide_panel.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz hide_panel.3x.gz )
( cd usr/man/man3 ; rm -rf addchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addchstr.3x.gz addchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf mvderwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_window.3x.gz mvderwin.3x.gz )
( cd usr/man/man3 ; rm -rf winsdelln.3x.gz )
( cd usr/man/man3 ; ln -sf curs_deleteln.3x.gz winsdelln.3x.gz )
( cd usr/man/man3 ; rm -rf wstandend.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz wstandend.3x.gz )
( cd usr/man/man3 ; rm -rf set_item_opts.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_opts.3x.gz set_item_opts.3x.gz )
( cd usr/man/man3 ; rm -rf noecho.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz noecho.3x.gz )
( cd usr/man/man3 ; rm -rf mvwadd_wchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wchstr.3x.gz mvwadd_wchstr.3x.gz )
( cd usr/man/man3 ; rm -rf slk_attron.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_attron.3x.gz )
( cd usr/man/man3 ; rm -rf wadd_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wch.3x.gz wadd_wch.3x.gz )
( cd usr/man/man3 ; rm -rf start_color.3x.gz )
( cd usr/man/man3 ; ln -sf curs_color.3x.gz start_color.3x.gz )
( cd usr/man/man3 ; rm -rf mvwaddstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addstr.3x.gz mvwaddstr.3x.gz )
( cd usr/man/man3 ; rm -rf scrl.3x.gz )
( cd usr/man/man3 ; ln -sf curs_scroll.3x.gz scrl.3x.gz )
( cd usr/man/man3 ; rm -rf _traceattr2.3x.gz )
( cd usr/man/man3 ; ln -sf curs_trace.3x.gz _traceattr2.3x.gz )
( cd usr/man/man3 ; rm -rf wattr_on.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz wattr_on.3x.gz )
( cd usr/man/man3 ; rm -rf nonl.3x.gz )
( cd usr/man/man3 ; ln -sf curs_outopts.3x.gz nonl.3x.gz )
( cd usr/man/man3 ; rm -rf current_item.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_current.3x.gz current_item.3x.gz )
( cd usr/man/man3 ; rm -rf wborder_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border_set.3x.gz wborder_set.3x.gz )
( cd usr/man/man3 ; rm -rf menu_sub.3x.gz )
( cd usr/man/man3 ; ln -sf menu_win.3x.gz menu_sub.3x.gz )
( cd usr/man/man3 ; rm -rf set_field_just.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_just.3x.gz set_field_just.3x.gz )
( cd usr/man/man3 ; rm -rf wattr_get.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz wattr_get.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_back.3x.gz )
( cd usr/man/man3 ; ln -sf menu_attributes.3x.gz set_menu_back.3x.gz )
( cd usr/man/man3 ; rm -rf show_panel.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz show_panel.3x.gz )
( cd usr/man/man3 ; rm -rf _tracechar.3x.gz )
( cd usr/man/man3 ; ln -sf curs_trace.3x.gz _tracechar.3x.gz )
( cd usr/man/man3 ; rm -rf pair_content.3x.gz )
( cd usr/man/man3 ; ln -sf curs_color.3x.gz pair_content.3x.gz )
( cd usr/man/man3 ; rm -rf has_ic.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termattrs.3x.gz has_ic.3x.gz )
( cd usr/man/man3 ; rm -rf set_item_userptr.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_userptr.3x.gz set_item_userptr.3x.gz )
( cd usr/man/man3 ; rm -rf vwscanw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_scanw.3x.gz vwscanw.3x.gz )
( cd usr/man/man3 ; rm -rf mvwaddnwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addwstr.3x.gz mvwaddnwstr.3x.gz )
( cd usr/man/man3 ; rm -rf set_form_term.3x.gz )
( cd usr/man/man3 ; ln -sf form_hook.3x.gz set_form_term.3x.gz )
( cd usr/man/man3 ; rm -rf winwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inwstr.3x.gz winwstr.3x.gz )
( cd usr/man/man3 ; rm -rf wgetbkgrnd.3x.gz )
( cd usr/man/man3 ; ln -sf curs_bkgrnd.3x.gz wgetbkgrnd.3x.gz )
( cd usr/man/man3 ; rm -rf keypad.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz keypad.3x.gz )
( cd usr/man/man3 ; rm -rf mousemask.3x.gz )
( cd usr/man/man3 ; ln -sf curs_mouse.3x.gz mousemask.3x.gz )
( cd usr/man/man3 ; rm -rf mvwvline.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border.3x.gz mvwvline.3x.gz )
( cd usr/man/man3 ; rm -rf winsstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_insstr.3x.gz winsstr.3x.gz )
( cd usr/man/man3 ; rm -rf wgetn_wstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_get_wstr.3x.gz wgetn_wstr.3x.gz )
( cd usr/man/man3 ; rm -rf current_field.3x.gz )
( cd usr/man/man3 ; ln -sf form_page.3x.gz current_field.3x.gz )
( cd usr/man/man3 ; rm -rf mvwaddchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addchstr.3x.gz mvwaddchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf wins_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_ins_wch.3x.gz wins_wch.3x.gz )
( cd usr/man/man3 ; rm -rf set_fieldtype_choice.3x.gz )
( cd usr/man/man3 ; ln -sf form_fieldtype.3x.gz set_fieldtype_choice.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_init.3x.gz )
( cd usr/man/man3 ; ln -sf menu_hook.3x.gz set_menu_init.3x.gz )
( cd usr/man/man3 ; rm -rf inch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inch.3x.gz inch.3x.gz )
( cd usr/man/man3 ; rm -rf tigetflag.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz tigetflag.3x.gz )
( cd usr/man/man3 ; rm -rf addstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addstr.3x.gz addstr.3x.gz )
( cd usr/man/man3 ; rm -rf deleteln.3x.gz )
( cd usr/man/man3 ; ln -sf curs_deleteln.3x.gz deleteln.3x.gz )
( cd usr/man/man3 ; rm -rf reset_prog_mode.3x.gz )
( cd usr/man/man3 ; ln -sf curs_kernel.3x.gz reset_prog_mode.3x.gz )
( cd usr/man/man3 ; rm -rf add_wchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wchstr.3x.gz add_wchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf wadd_wchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wchstr.3x.gz wadd_wchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf wborder.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border.3x.gz wborder.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_pad.3x.gz )
( cd usr/man/man3 ; ln -sf menu_attributes.3x.gz set_menu_pad.3x.gz )
( cd usr/man/man3 ; rm -rf wclrtobot.3x.gz )
( cd usr/man/man3 ; ln -sf curs_clear.3x.gz wclrtobot.3x.gz )
( cd usr/man/man3 ; rm -rf typeahead.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz typeahead.3x.gz )
( cd usr/man/man3 ; rm -rf wsetscrreg.3x.gz )
( cd usr/man/man3 ; ln -sf curs_outopts.3x.gz wsetscrreg.3x.gz )
( cd usr/man/man3 ; rm -rf getbegyx.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getyx.3x.gz getbegyx.3x.gz )
( cd usr/man/man3 ; rm -rf free_field.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_new.3x.gz free_field.3x.gz )
( cd usr/man/man3 ; rm -rf winnwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inwstr.3x.gz winnwstr.3x.gz )
( cd usr/man/man3 ; rm -rf mvwget_wstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_get_wstr.3x.gz mvwget_wstr.3x.gz )
( cd usr/man/man3 ; rm -rf use_extended_names.3x.gz )
( cd usr/man/man3 ; ln -sf curs_extend.3x.gz use_extended_names.3x.gz )
( cd usr/man/man3 ; rm -rf setupterm.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz setupterm.3x.gz )
( cd usr/man/man3 ; rm -rf in_wchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_in_wchstr.3x.gz in_wchstr.3x.gz )
( cd usr/man/man3 ; rm -rf syncok.3x.gz )
( cd usr/man/man3 ; ln -sf curs_window.3x.gz syncok.3x.gz )
( cd usr/man/man3 ; rm -rf panel_window.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz panel_window.3x.gz )
( cd usr/man/man3 ; rm -rf overwrite.3x.gz )
( cd usr/man/man3 ; ln -sf curs_overlay.3x.gz overwrite.3x.gz )
( cd usr/man/man3 ; rm -rf refresh.3x.gz )
( cd usr/man/man3 ; ln -sf curs_refresh.3x.gz refresh.3x.gz )
( cd usr/man/man3 ; rm -rf immedok.3x.gz )
( cd usr/man/man3 ; ln -sf curs_outopts.3x.gz immedok.3x.gz )
( cd usr/man/man3 ; rm -rf newwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_window.3x.gz newwin.3x.gz )
( cd usr/man/man3 ; rm -rf mvwinwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inwstr.3x.gz mvwinwstr.3x.gz )
( cd usr/man/man3 ; rm -rf set_curterm.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz set_curterm.3x.gz )
( cd usr/man/man3 ; rm -rf mvwinsstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_insstr.3x.gz mvwinsstr.3x.gz )
( cd usr/man/man3 ; rm -rf mvinnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_instr.3x.gz mvinnstr.3x.gz )
( cd usr/man/man3 ; rm -rf baudrate.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termattrs.3x.gz baudrate.3x.gz )
( cd usr/man/man3 ; rm -rf mvwaddchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addchstr.3x.gz mvwaddchstr.3x.gz )
( cd usr/man/man3 ; rm -rf trace.3x.gz )
( cd usr/man/man3 ; ln -sf curs_trace.3x.gz trace.3x.gz )
( cd usr/man/man3 ; rm -rf wattr_off.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz wattr_off.3x.gz )
( cd usr/man/man3 ; rm -rf clear.3x.gz )
( cd usr/man/man3 ; ln -sf curs_clear.3x.gz clear.3x.gz )
( cd usr/man/man3 ; rm -rf box.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border.3x.gz box.3x.gz )
( cd usr/man/man3 ; rm -rf mvaddchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addchstr.3x.gz mvaddchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf bottom_panel.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz bottom_panel.3x.gz )
( cd usr/man/man3 ; rm -rf noqiflush.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz noqiflush.3x.gz )
( cd usr/man/man3 ; rm -rf _tracemouse.3x.gz )
( cd usr/man/man3 ; ln -sf curs_trace.3x.gz _tracemouse.3x.gz )
( cd usr/man/man3 ; rm -rf delwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_window.3x.gz delwin.3x.gz )
( cd usr/man/man3 ; rm -rf set_form_opts.3x.gz )
( cd usr/man/man3 ; ln -sf form_opts.3x.gz set_form_opts.3x.gz )
( cd usr/man/man3 ; rm -rf vline.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border.3x.gz vline.3x.gz )
( cd usr/man/man3 ; rm -rf slk_attr_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_attr_set.3x.gz )
( cd usr/man/man3 ; rm -rf def_shell_mode.3x.gz )
( cd usr/man/man3 ; ln -sf curs_kernel.3x.gz def_shell_mode.3x.gz )
( cd usr/man/man3 ; rm -rf getbkgd.3x.gz )
( cd usr/man/man3 ; ln -sf curs_bkgd.3x.gz getbkgd.3x.gz )
( cd usr/man/man3 ; rm -rf mvwin_wchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_in_wchstr.3x.gz mvwin_wchstr.3x.gz )
( cd usr/man/man3 ; rm -rf inwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inwstr.3x.gz inwstr.3x.gz )
( cd usr/man/man3 ; rm -rf setterm.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz setterm.3x.gz )
( cd usr/man/man3 ; rm -rf inchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inchstr.3x.gz inchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf mvinch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inch.3x.gz mvinch.3x.gz )
( cd usr/man/man3 ; rm -rf wvline_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border_set.3x.gz wvline_set.3x.gz )
( cd usr/man/man3 ; rm -rf delscreen.3x.gz )
( cd usr/man/man3 ; ln -sf curs_initscr.3x.gz delscreen.3x.gz )
( cd usr/man/man3 ; rm -rf insstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_insstr.3x.gz insstr.3x.gz )
( cd usr/man/man3 ; rm -rf winchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inchstr.3x.gz winchstr.3x.gz )
( cd usr/man/man3 ; rm -rf nodelay.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz nodelay.3x.gz )
( cd usr/man/man3 ; rm -rf form_request_by_name.3x.gz )
( cd usr/man/man3 ; ln -sf form_requestname.3x.gz form_request_by_name.3x.gz )
( cd usr/man/man3 ; rm -rf free_fieldtype.3x.gz )
( cd usr/man/man3 ; ln -sf form_fieldtype.3x.gz free_fieldtype.3x.gz )
( cd usr/man/man3 ; rm -rf ins_nwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_ins_wstr.3x.gz ins_nwstr.3x.gz )
( cd usr/man/man3 ; rm -rf add_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wch.3x.gz add_wch.3x.gz )
( cd usr/man/man3 ; rm -rf whline_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border_set.3x.gz whline_set.3x.gz )
( cd usr/man/man3 ; rm -rf pos_menu_cursor.3x.gz )
( cd usr/man/man3 ; ln -sf menu_cursor.3x.gz pos_menu_cursor.3x.gz )
( cd usr/man/man3 ; rm -rf napms.3x.gz )
( cd usr/man/man3 ; ln -sf curs_kernel.3x.gz napms.3x.gz )
( cd usr/man/man3 ; rm -rf panel_hidden.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz panel_hidden.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_fore.3x.gz )
( cd usr/man/man3 ; ln -sf menu_attributes.3x.gz set_menu_fore.3x.gz )
( cd usr/man/man3 ; rm -rf set_field_status.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_buffer.3x.gz set_field_status.3x.gz )
( cd usr/man/man3 ; rm -rf dup_field.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_new.3x.gz dup_field.3x.gz )
( cd usr/man/man3 ; rm -rf mvvline.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border.3x.gz mvvline.3x.gz )
( cd usr/man/man3 ; rm -rf attr_on.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz attr_on.3x.gz )
( cd usr/man/man3 ; rm -rf border.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border.3x.gz border.3x.gz )
( cd usr/man/man3 ; rm -rf mvwgetnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getstr.3x.gz mvwgetnstr.3x.gz )
( cd usr/man/man3 ; rm -rf meta.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz meta.3x.gz )
( cd usr/man/man3 ; rm -rf winstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_instr.3x.gz winstr.3x.gz )
( cd usr/man/man3 ; rm -rf form_opts_on.3x.gz )
( cd usr/man/man3 ; ln -sf form_opts.3x.gz form_opts_on.3x.gz )
( cd usr/man/man3 ; rm -rf new_panel.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz new_panel.3x.gz )
( cd usr/man/man3 ; rm -rf tgetflag.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termcap.3x.gz tgetflag.3x.gz )
( cd usr/man/man3 ; rm -rf wchgat.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz wchgat.3x.gz )
( cd usr/man/man3 ; rm -rf termname.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termattrs.3x.gz termname.3x.gz )
( cd usr/man/man3 ; rm -rf noraw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz noraw.3x.gz )
( cd usr/man/man3 ; rm -rf setsyx.3x.gz )
( cd usr/man/man3 ; ln -sf curs_kernel.3x.gz setsyx.3x.gz )
( cd usr/man/man3 ; rm -rf wbkgd.3x.gz )
( cd usr/man/man3 ; ln -sf curs_bkgd.3x.gz wbkgd.3x.gz )
( cd usr/man/man3 ; rm -rf use_env.3x.gz )
( cd usr/man/man3 ; ln -sf curs_util.3x.gz use_env.3x.gz )
( cd usr/man/man3 ; rm -rf win_wchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_in_wchstr.3x.gz win_wchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_term.3x.gz )
( cd usr/man/man3 ; ln -sf menu_hook.3x.gz set_menu_term.3x.gz )
( cd usr/man/man3 ; rm -rf replace_panel.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz replace_panel.3x.gz )
( cd usr/man/man3 ; rm -rf ins_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_ins_wch.3x.gz ins_wch.3x.gz )
( cd usr/man/man3 ; rm -rf wsyncdown.3x.gz )
( cd usr/man/man3 ; ln -sf curs_window.3x.gz wsyncdown.3x.gz )
( cd usr/man/man3 ; rm -rf touchline.3x.gz )
( cd usr/man/man3 ; ln -sf curs_touch.3x.gz touchline.3x.gz )
( cd usr/man/man3 ; rm -rf pos_form_cursor.3x.gz )
( cd usr/man/man3 ; ln -sf form_cursor.3x.gz pos_form_cursor.3x.gz )
( cd usr/man/man3 ; rm -rf mvadd_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wch.3x.gz mvadd_wch.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_format.3x.gz )
( cd usr/man/man3 ; ln -sf menu_format.3x.gz set_menu_format.3x.gz )
( cd usr/man/man3 ; rm -rf mvwins_nwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_ins_wstr.3x.gz mvwins_nwstr.3x.gz )
( cd usr/man/man3 ; rm -rf mvadd_wchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wchstr.3x.gz mvadd_wchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf mvwaddwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addwstr.3x.gz mvwaddwstr.3x.gz )
( cd usr/man/man3 ; rm -rf newterm.3x.gz )
( cd usr/man/man3 ; ln -sf curs_initscr.3x.gz newterm.3x.gz )
( cd usr/man/man3 ; rm -rf slk_refresh.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_refresh.3x.gz )
( cd usr/man/man3 ; rm -rf term_attrs.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termattrs.3x.gz term_attrs.3x.gz )
( cd usr/man/man3 ; rm -rf doupdate.3x.gz )
( cd usr/man/man3 ; ln -sf curs_refresh.3x.gz doupdate.3x.gz )
( cd usr/man/man3 ; rm -rf mvaddnwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addwstr.3x.gz mvaddnwstr.3x.gz )
( cd usr/man/man3 ; rm -rf mvin_wchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_in_wchstr.3x.gz mvin_wchstr.3x.gz )
( cd usr/man/man3 ; rm -rf innwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inwstr.3x.gz innwstr.3x.gz )
( cd usr/man/man3 ; rm -rf ins_wstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_ins_wstr.3x.gz ins_wstr.3x.gz )
( cd usr/man/man3 ; rm -rf nocbreak.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz nocbreak.3x.gz )
( cd usr/man/man3 ; rm -rf data_behind.3x.gz )
( cd usr/man/man3 ; ln -sf form_data.3x.gz data_behind.3x.gz )
( cd usr/man/man3 ; rm -rf _tracef.3x.gz )
( cd usr/man/man3 ; ln -sf curs_trace.3x.gz _tracef.3x.gz )
( cd usr/man/man3 ; rm -rf tgetent.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termcap.3x.gz tgetent.3x.gz )
( cd usr/man/man3 ; rm -rf has_key.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getch.3x.gz has_key.3x.gz )
( cd usr/man/man3 ; rm -rf field_back.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_attributes.3x.gz field_back.3x.gz )
( cd usr/man/man3 ; rm -rf scroll.3x.gz )
( cd usr/man/man3 ; ln -sf curs_scroll.3x.gz scroll.3x.gz )
( cd usr/man/man3 ; rm -rf ungetch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getch.3x.gz ungetch.3x.gz )
( cd usr/man/man3 ; rm -rf scrollok.3x.gz )
( cd usr/man/man3 ; ln -sf curs_outopts.3x.gz scrollok.3x.gz )
( cd usr/man/man3 ; rm -rf waddnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addstr.3x.gz waddnstr.3x.gz )
( cd usr/man/man3 ; rm -rf set_current_item.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_current.3x.gz set_current_item.3x.gz )
( cd usr/man/man3 ; rm -rf top_row.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_current.3x.gz top_row.3x.gz )
( cd usr/man/man3 ; rm -rf subpad.3x.gz )
( cd usr/man/man3 ; ln -sf curs_pad.3x.gz subpad.3x.gz )
( cd usr/man/man3 ; rm -rf wbkgdset.3x.gz )
( cd usr/man/man3 ; ln -sf curs_bkgd.3x.gz wbkgdset.3x.gz )
( cd usr/man/man3 ; rm -rf item_init.3x.gz )
( cd usr/man/man3 ; ln -sf menu_hook.3x.gz item_init.3x.gz )
( cd usr/man/man3 ; rm -rf getyx.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getyx.3x.gz getyx.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_items.3x.gz )
( cd usr/man/man3 ; ln -sf menu_items.3x.gz set_menu_items.3x.gz )
( cd usr/man/man3 ; rm -rf post_menu.3x.gz )
( cd usr/man/man3 ; ln -sf menu_post.3x.gz post_menu.3x.gz )
( cd usr/man/man3 ; rm -rf _tracechtype2.3x.gz )
( cd usr/man/man3 ; ln -sf curs_trace.3x.gz _tracechtype2.3x.gz )
( cd usr/man/man3 ; rm -rf field_opts_on.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_opts.3x.gz field_opts_on.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_grey.3x.gz )
( cd usr/man/man3 ; ln -sf menu_attributes.3x.gz set_menu_grey.3x.gz )
( cd usr/man/man3 ; rm -rf def_prog_mode.3x.gz )
( cd usr/man/man3 ; ln -sf curs_kernel.3x.gz def_prog_mode.3x.gz )
( cd usr/man/man3 ; rm -rf field_init.3x.gz )
( cd usr/man/man3 ; ln -sf form_hook.3x.gz field_init.3x.gz )
( cd usr/man/man3 ; rm -rf mvins_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_ins_wch.3x.gz mvins_wch.3x.gz )
( cd usr/man/man3 ; rm -rf mvget_wstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_get_wstr.3x.gz mvget_wstr.3x.gz )
( cd usr/man/man3 ; rm -rf mouse_trafo.3x.gz )
( cd usr/man/man3 ; ln -sf curs_mouse.3x.gz mouse_trafo.3x.gz )
( cd usr/man/man3 ; rm -rf wmouse_trafo.3x.gz )
( cd usr/man/man3 ; ln -sf curs_mouse.3x.gz wmouse_trafo.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_win.3x.gz )
( cd usr/man/man3 ; ln -sf menu_win.3x.gz set_menu_win.3x.gz )
( cd usr/man/man3 ; rm -rf wget_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_get_wch.3x.gz wget_wch.3x.gz )
( cd usr/man/man3 ; rm -rf item_index.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_current.3x.gz item_index.3x.gz )
( cd usr/man/man3 ; rm -rf setcchar.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getcchar.3x.gz setcchar.3x.gz )
( cd usr/man/man3 ; rm -rf scr_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_scr_dump.3x.gz scr_set.3x.gz )
( cd usr/man/man3 ; rm -rf slk_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_set.3x.gz )
( cd usr/man/man3 ; rm -rf set_item_value.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_value.3x.gz set_item_value.3x.gz )
( cd usr/man/man3 ; rm -rf wcursyncup.3x.gz )
( cd usr/man/man3 ; ln -sf curs_window.3x.gz wcursyncup.3x.gz )
( cd usr/man/man3 ; rm -rf wstandout.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz wstandout.3x.gz )
( cd usr/man/man3 ; rm -rf wenclose.3x.gz )
( cd usr/man/man3 ; ln -sf curs_mouse.3x.gz wenclose.3x.gz )
( cd usr/man/man3 ; rm -rf new_menu.3x.gz )
( cd usr/man/man3 ; ln -sf menu_new.3x.gz new_menu.3x.gz )
( cd usr/man/man3 ; rm -rf wunctrl.3x.gz )
( cd usr/man/man3 ; ln -sf curs_util.3x.gz wunctrl.3x.gz )
( cd usr/man/man3 ; rm -rf mvinnwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inwstr.3x.gz mvinnwstr.3x.gz )
( cd usr/man/man3 ; rm -rf clrtoeol.3x.gz )
( cd usr/man/man3 ; ln -sf curs_clear.3x.gz clrtoeol.3x.gz )
( cd usr/man/man3 ; rm -rf vid_attr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz vid_attr.3x.gz )
( cd usr/man/man3 ; rm -rf add_wchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wchstr.3x.gz add_wchstr.3x.gz )
( cd usr/man/man3 ; rm -rf set_top_row.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_current.3x.gz set_top_row.3x.gz )
( cd usr/man/man3 ; rm -rf set_field_pad.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_attributes.3x.gz set_field_pad.3x.gz )
( cd usr/man/man3 ; rm -rf mvaddchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addchstr.3x.gz mvaddchstr.3x.gz )
( cd usr/man/man3 ; rm -rf winsnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_insstr.3x.gz winsnstr.3x.gz )
( cd usr/man/man3 ; rm -rf mvins_nwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_ins_wstr.3x.gz mvins_nwstr.3x.gz )
( cd usr/man/man3 ; rm -rf inchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inchstr.3x.gz inchstr.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_opts.3x.gz )
( cd usr/man/man3 ; ln -sf menu_opts.3x.gz set_menu_opts.3x.gz )
( cd usr/man/man3 ; rm -rf slk_attr_on.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_attr_on.3x.gz )
( cd usr/man/man3 ; rm -rf delay_output.3x.gz )
( cd usr/man/man3 ; ln -sf curs_util.3x.gz delay_output.3x.gz )
( cd usr/man/man3 ; rm -rf mvin_wchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_in_wchstr.3x.gz mvin_wchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf wprintw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_printw.3x.gz wprintw.3x.gz )
( cd usr/man/man3 ; rm -rf item_name.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_name.3x.gz item_name.3x.gz )
( cd usr/man/man3 ; rm -rf wgetch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getch.3x.gz wgetch.3x.gz )
( cd usr/man/man3 ; rm -rf panel_userptr.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz panel_userptr.3x.gz )
( cd usr/man/man3 ; rm -rf slk_attr_off.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_attr_off.3x.gz )
( cd usr/man/man3 ; rm -rf new_page.3x.gz )
( cd usr/man/man3 ; ln -sf form_new_page.3x.gz new_page.3x.gz )
( cd usr/man/man3 ; rm -rf mvaddstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addstr.3x.gz mvaddstr.3x.gz )
( cd usr/man/man3 ; rm -rf key_name.3x.gz )
( cd usr/man/man3 ; ln -sf curs_util.3x.gz key_name.3x.gz )
( cd usr/man/man3 ; rm -rf menu_opts_off.3x.gz )
( cd usr/man/man3 ; ln -sf menu_opts.3x.gz menu_opts_off.3x.gz )
( cd usr/man/man3 ; rm -rf pecho_wchar.3x.gz )
( cd usr/man/man3 ; ln -sf curs_pad.3x.gz pecho_wchar.3x.gz )
( cd usr/man/man3 ; rm -rf has_il.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termattrs.3x.gz has_il.3x.gz )
( cd usr/man/man3 ; rm -rf field_userptr.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_userptr.3x.gz field_userptr.3x.gz )
( cd usr/man/man3 ; rm -rf ripoffline.3x.gz )
( cd usr/man/man3 ; ln -sf curs_kernel.3x.gz ripoffline.3x.gz )
( cd usr/man/man3 ; rm -rf scr_dump.3x.gz )
( cd usr/man/man3 ; ln -sf curs_scr_dump.3x.gz scr_dump.3x.gz )
( cd usr/man/man3 ; rm -rf mvwin_wchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_in_wchstr.3x.gz mvwin_wchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf wtimeout.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz wtimeout.3x.gz )
( cd usr/man/man3 ; rm -rf mvinchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inchstr.3x.gz mvinchstr.3x.gz )
( cd usr/man/man3 ; rm -rf new_item.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_new.3x.gz new_item.3x.gz )
( cd usr/man/man3 ; rm -rf wdeleteln.3x.gz )
( cd usr/man/man3 ; ln -sf curs_deleteln.3x.gz wdeleteln.3x.gz )
( cd usr/man/man3 ; rm -rf putp.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz putp.3x.gz )
( cd usr/man/man3 ; rm -rf insertln.3x.gz )
( cd usr/man/man3 ; ln -sf curs_deleteln.3x.gz insertln.3x.gz )
( cd usr/man/man3 ; rm -rf field_fore.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_attributes.3x.gz field_fore.3x.gz )
( cd usr/man/man3 ; rm -rf mvwprintw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_printw.3x.gz mvwprintw.3x.gz )
( cd usr/man/man3 ; rm -rf getmouse.3x.gz )
( cd usr/man/man3 ; ln -sf curs_mouse.3x.gz getmouse.3x.gz )
( cd usr/man/man3 ; rm -rf tputs.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz tputs.3x.gz )
( cd usr/man/man3 ; rm -rf init_pair.3x.gz )
( cd usr/man/man3 ; ln -sf curs_color.3x.gz init_pair.3x.gz )
( cd usr/man/man3 ; rm -rf getsyx.3x.gz )
( cd usr/man/man3 ; ln -sf curs_kernel.3x.gz getsyx.3x.gz )
( cd usr/man/man3 ; rm -rf unctrl.3x.gz )
( cd usr/man/man3 ; ln -sf curs_util.3x.gz unctrl.3x.gz )
( cd usr/man/man3 ; rm -rf ungetmouse.3x.gz )
( cd usr/man/man3 ; ln -sf curs_mouse.3x.gz ungetmouse.3x.gz )
( cd usr/man/man3 ; rm -rf wscanw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_scanw.3x.gz wscanw.3x.gz )
( cd usr/man/man3 ; rm -rf field_index.3x.gz )
( cd usr/man/man3 ; ln -sf form_page.3x.gz field_index.3x.gz )
( cd usr/man/man3 ; rm -rf wsyncup.3x.gz )
( cd usr/man/man3 ; ln -sf curs_window.3x.gz wsyncup.3x.gz )
( cd usr/man/man3 ; rm -rf free_menu.3x.gz )
( cd usr/man/man3 ; ln -sf menu_new.3x.gz free_menu.3x.gz )
( cd usr/man/man3 ; rm -rf waddchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addchstr.3x.gz waddchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf form_init.3x.gz )
( cd usr/man/man3 ; ln -sf form_hook.3x.gz form_init.3x.gz )
( cd usr/man/man3 ; rm -rf bkgrndset.3x.gz )
( cd usr/man/man3 ; ln -sf curs_bkgrnd.3x.gz bkgrndset.3x.gz )
( cd usr/man/man3 ; rm -rf _nc_tracebits.3x.gz )
( cd usr/man/man3 ; ln -sf curs_trace.3x.gz _nc_tracebits.3x.gz )
( cd usr/man/man3 ; rm -rf addnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addstr.3x.gz addnstr.3x.gz )
( cd usr/man/man3 ; rm -rf item_term.3x.gz )
( cd usr/man/man3 ; ln -sf menu_hook.3x.gz item_term.3x.gz )
( cd usr/man/man3 ; rm -rf bkgdset.3x.gz )
( cd usr/man/man3 ; ln -sf curs_bkgd.3x.gz bkgdset.3x.gz )
( cd usr/man/man3 ; rm -rf wmove.3x.gz )
( cd usr/man/man3 ; ln -sf curs_move.3x.gz wmove.3x.gz )
( cd usr/man/man3 ; rm -rf bkgd.3x.gz )
( cd usr/man/man3 ; ln -sf curs_bkgd.3x.gz bkgd.3x.gz )
( cd usr/man/man3 ; rm -rf field_term.3x.gz )
( cd usr/man/man3 ; ln -sf form_hook.3x.gz field_term.3x.gz )
( cd usr/man/man3 ; rm -rf vwprintw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_printw.3x.gz vwprintw.3x.gz )
( cd usr/man/man3 ; rm -rf printw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_printw.3x.gz printw.3x.gz )
( cd usr/man/man3 ; rm -rf slk_label.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_label.3x.gz )
( cd usr/man/man3 ; rm -rf set_fieldtype_arg.3x.gz )
( cd usr/man/man3 ; ln -sf form_fieldtype.3x.gz set_fieldtype_arg.3x.gz )
( cd usr/man/man3 ; rm -rf mvinwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inwstr.3x.gz mvinwstr.3x.gz )
( cd usr/man/man3 ; rm -rf get_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_get_wch.3x.gz get_wch.3x.gz )
( cd usr/man/man3 ; rm -rf wattron.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz wattron.3x.gz )
( cd usr/man/man3 ; rm -rf mvinsstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_insstr.3x.gz mvinsstr.3x.gz )
( cd usr/man/man3 ; rm -rf wgetstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getstr.3x.gz wgetstr.3x.gz )
( cd usr/man/man3 ; rm -rf vidattr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz vidattr.3x.gz )
( cd usr/man/man3 ; rm -rf restartterm.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz restartterm.3x.gz )
( cd usr/man/man3 ; rm -rf unpost_menu.3x.gz )
( cd usr/man/man3 ; ln -sf menu_post.3x.gz unpost_menu.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_pattern.3x.gz )
( cd usr/man/man3 ; ln -sf menu_pattern.3x.gz set_menu_pattern.3x.gz )
( cd usr/man/man3 ; rm -rf curses_version.3x.gz )
( cd usr/man/man3 ; ln -sf curs_extend.3x.gz curses_version.3x.gz )
( cd usr/man/man3 ; rm -rf set_max_field.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_buffer.3x.gz set_max_field.3x.gz )
( cd usr/man/man3 ; rm -rf mvwinstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_instr.3x.gz mvwinstr.3x.gz )
( cd usr/man/man3 ; rm -rf waddch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addch.3x.gz waddch.3x.gz )
( cd usr/man/man3 ; rm -rf flash.3x.gz )
( cd usr/man/man3 ; ln -sf curs_beep.3x.gz flash.3x.gz )
( cd usr/man/man3 ; rm -rf insnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_insstr.3x.gz insnstr.3x.gz )
( cd usr/man/man3 ; rm -rf winchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inchstr.3x.gz winchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf subwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_window.3x.gz subwin.3x.gz )
( cd usr/man/man3 ; rm -rf wdelch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_delch.3x.gz wdelch.3x.gz )
( cd usr/man/man3 ; rm -rf form_sub.3x.gz )
( cd usr/man/man3 ; ln -sf form_win.3x.gz form_sub.3x.gz )
( cd usr/man/man3 ; rm -rf del_curterm.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz del_curterm.3x.gz )
( cd usr/man/man3 ; rm -rf isendwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_initscr.3x.gz isendwin.3x.gz )
( cd usr/man/man3 ; rm -rf winsch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_insch.3x.gz winsch.3x.gz )
( cd usr/man/man3 ; rm -rf mvaddnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addstr.3x.gz mvaddnstr.3x.gz )
( cd usr/man/man3 ; rm -rf mvwchgat.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz mvwchgat.3x.gz )
( cd usr/man/man3 ; rm -rf win_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_in_wch.3x.gz win_wch.3x.gz )
( cd usr/man/man3 ; rm -rf border_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border_set.3x.gz border_set.3x.gz )
( cd usr/man/man3 ; rm -rf resize_term.3x.gz )
( cd usr/man/man3 ; ln -sf resizeterm.3x.gz resize_term.3x.gz )
( cd usr/man/man3 ; rm -rf free_item.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_new.3x.gz free_item.3x.gz )
( cd usr/man/man3 ; rm -rf color_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz color_set.3x.gz )
( cd usr/man/man3 ; rm -rf werase.3x.gz )
( cd usr/man/man3 ; ln -sf curs_clear.3x.gz werase.3x.gz )
( cd usr/man/man3 ; rm -rf COLOR_PAIR.3x.gz )
( cd usr/man/man3 ; ln -sf curs_color.3x.gz COLOR_PAIR.3x.gz )
( cd usr/man/man3 ; rm -rf wattrset.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz wattrset.3x.gz )
( cd usr/man/man3 ; rm -rf mvget_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_get_wch.3x.gz mvget_wch.3x.gz )
( cd usr/man/man3 ; rm -rf panel_above.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz panel_above.3x.gz )
( cd usr/man/man3 ; rm -rf mvwgetstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getstr.3x.gz mvwgetstr.3x.gz )
( cd usr/man/man3 ; rm -rf win_wchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_in_wchstr.3x.gz win_wchstr.3x.gz )
( cd usr/man/man3 ; rm -rf set_form_userptr.3x.gz )
( cd usr/man/man3 ; ln -sf form_userptr.3x.gz set_form_userptr.3x.gz )
( cd usr/man/man3 ; rm -rf link_fieldtype.3x.gz )
( cd usr/man/man3 ; ln -sf form_fieldtype.3x.gz link_fieldtype.3x.gz )
( cd usr/man/man3 ; rm -rf slk_noutrefresh.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_noutrefresh.3x.gz )
( cd usr/man/man3 ; rm -rf menu_request_by_name.3x.gz )
( cd usr/man/man3 ; ln -sf menu_requestname.3x.gz menu_request_by_name.3x.gz )
( cd usr/man/man3 ; rm -rf item_opts.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_opts.3x.gz item_opts.3x.gz )
( cd usr/man/man3 ; rm -rf wecho_wchar.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wch.3x.gz wecho_wchar.3x.gz )
( cd usr/man/man3 ; rm -rf data_ahead.3x.gz )
( cd usr/man/man3 ; ln -sf form_data.3x.gz data_ahead.3x.gz )
( cd usr/man/man3 ; rm -rf wnoutrefresh.3x.gz )
( cd usr/man/man3 ; ln -sf curs_refresh.3x.gz wnoutrefresh.3x.gz )
( cd usr/man/man3 ; rm -rf timeout.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz timeout.3x.gz )
( cd usr/man/man3 ; rm -rf field_opts.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_opts.3x.gz field_opts.3x.gz )
( cd usr/man/man3 ; rm -rf item_visible.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_visible.3x.gz item_visible.3x.gz )
( cd usr/man/man3 ; rm -rf post_form.3x.gz )
( cd usr/man/man3 ; ln -sf form_post.3x.gz post_form.3x.gz )
( cd usr/man/man3 ; rm -rf mvinsnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_insstr.3x.gz mvinsnstr.3x.gz )
( cd usr/man/man3 ; rm -rf redrawwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_refresh.3x.gz redrawwin.3x.gz )
( cd usr/man/man3 ; rm -rf assume_default_colors.3x.gz )
( cd usr/man/man3 ; ln -sf default_colors.3x.gz assume_default_colors.3x.gz )
( cd usr/man/man3 ; rm -rf halfdelay.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz halfdelay.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_sub.3x.gz )
( cd usr/man/man3 ; ln -sf menu_win.3x.gz set_menu_sub.3x.gz )
( cd usr/man/man3 ; rm -rf field_type.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_validation.3x.gz field_type.3x.gz )
( cd usr/man/man3 ; rm -rf wgetnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getstr.3x.gz wgetnstr.3x.gz )
( cd usr/man/man3 ; rm -rf form_request_name.3x.gz )
( cd usr/man/man3 ; ln -sf form_requestname.3x.gz form_request_name.3x.gz )
( cd usr/man/man3 ; rm -rf nl.3x.gz )
( cd usr/man/man3 ; ln -sf curs_outopts.3x.gz nl.3x.gz )
( cd usr/man/man3 ; rm -rf move_field.3x.gz )
( cd usr/man/man3 ; ln -sf form_field.3x.gz move_field.3x.gz )
( cd usr/man/man3 ; rm -rf attron.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz attron.3x.gz )
( cd usr/man/man3 ; rm -rf mvwin_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_in_wch.3x.gz mvwin_wch.3x.gz )
( cd usr/man/man3 ; rm -rf getstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getstr.3x.gz getstr.3x.gz )
( cd usr/man/man3 ; rm -rf wins_wstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_ins_wstr.3x.gz wins_wstr.3x.gz )
( cd usr/man/man3 ; rm -rf menu_back.3x.gz )
( cd usr/man/man3 ; ln -sf menu_attributes.3x.gz menu_back.3x.gz )
( cd usr/man/man3 ; rm -rf new_form.3x.gz )
( cd usr/man/man3 ; ln -sf form_new.3x.gz new_form.3x.gz )
( cd usr/man/man3 ; rm -rf initscr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_initscr.3x.gz initscr.3x.gz )
( cd usr/man/man3 ; rm -rf mouseinterval.3x.gz )
( cd usr/man/man3 ; ln -sf curs_mouse.3x.gz mouseinterval.3x.gz )
( cd usr/man/man3 ; rm -rf instr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_instr.3x.gz instr.3x.gz )
( cd usr/man/man3 ; rm -rf getwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_util.3x.gz getwin.3x.gz )
( cd usr/man/man3 ; rm -rf vw_printw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_printw.3x.gz vw_printw.3x.gz )
( cd usr/man/man3 ; rm -rf form_term.3x.gz )
( cd usr/man/man3 ; ln -sf form_hook.3x.gz form_term.3x.gz )
( cd usr/man/man3 ; rm -rf chgat.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz chgat.3x.gz )
( cd usr/man/man3 ; rm -rf beep.3x.gz )
( cd usr/man/man3 ; ln -sf curs_beep.3x.gz beep.3x.gz )
( cd usr/man/man3 ; rm -rf menu_pad.3x.gz )
( cd usr/man/man3 ; ln -sf menu_attributes.3x.gz menu_pad.3x.gz )
( cd usr/man/man3 ; rm -rf menu_init.3x.gz )
( cd usr/man/man3 ; ln -sf menu_hook.3x.gz menu_init.3x.gz )
( cd usr/man/man3 ; rm -rf wins_nwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_ins_wstr.3x.gz wins_nwstr.3x.gz )
( cd usr/man/man3 ; rm -rf top_panel.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz top_panel.3x.gz )
( cd usr/man/man3 ; rm -rf waddwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addwstr.3x.gz waddwstr.3x.gz )
( cd usr/man/man3 ; rm -rf mvinstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_instr.3x.gz mvinstr.3x.gz )
( cd usr/man/man3 ; rm -rf erasechar.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termattrs.3x.gz erasechar.3x.gz )
( cd usr/man/man3 ; rm -rf addnwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addwstr.3x.gz addnwstr.3x.gz )
( cd usr/man/man3 ; rm -rf in_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_in_wch.3x.gz in_wch.3x.gz )
( cd usr/man/man3 ; rm -rf menu_opts_on.3x.gz )
( cd usr/man/man3 ; ln -sf menu_opts.3x.gz menu_opts_on.3x.gz )
( cd usr/man/man3 ; rm -rf getcchar.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getcchar.3x.gz getcchar.3x.gz )
( cd usr/man/man3 ; rm -rf link_field.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_new.3x.gz link_field.3x.gz )
( cd usr/man/man3 ; rm -rf whline.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border.3x.gz whline.3x.gz )
( cd usr/man/man3 ; rm -rf mvwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_window.3x.gz mvwin.3x.gz )
( cd usr/man/man3 ; rm -rf mvchgat.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz mvchgat.3x.gz )
( cd usr/man/man3 ; rm -rf set_term.3x.gz )
( cd usr/man/man3 ; ln -sf curs_initscr.3x.gz set_term.3x.gz )
( cd usr/man/man3 ; rm -rf form_fields.3x.gz )
( cd usr/man/man3 ; ln -sf form_field.3x.gz form_fields.3x.gz )
( cd usr/man/man3 ; rm -rf tigetnum.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz tigetnum.3x.gz )
( cd usr/man/man3 ; rm -rf mvwgetch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getch.3x.gz mvwgetch.3x.gz )
( cd usr/man/man3 ; rm -rf define_key.3x.gz )
( cd usr/man/man3 ; ln -sf key_defined.3x.gz define_key.3x.gz )
( cd usr/man/man3 ; rm -rf wclrtoeol.3x.gz )
( cd usr/man/man3 ; ln -sf curs_clear.3x.gz wclrtoeol.3x.gz )
( cd usr/man/man3 ; rm -rf set_current_field.3x.gz )
( cd usr/man/man3 ; ln -sf form_page.3x.gz set_current_field.3x.gz )
( cd usr/man/man3 ; rm -rf tgetnum.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termcap.3x.gz tgetnum.3x.gz )
( cd usr/man/man3 ; rm -rf wredrawln.3x.gz )
( cd usr/man/man3 ; ln -sf curs_refresh.3x.gz wredrawln.3x.gz )
( cd usr/man/man3 ; rm -rf set_field_back.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_attributes.3x.gz set_field_back.3x.gz )
( cd usr/man/man3 ; rm -rf slk_attr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_attr.3x.gz )
( cd usr/man/man3 ; rm -rf mvwinchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inchstr.3x.gz mvwinchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf getparyx.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getyx.3x.gz getparyx.3x.gz )
( cd usr/man/man3 ; rm -rf set_form_fields.3x.gz )
( cd usr/man/man3 ; ln -sf form_field.3x.gz set_form_fields.3x.gz )
( cd usr/man/man3 ; rm -rf panel_below.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz panel_below.3x.gz )
( cd usr/man/man3 ; rm -rf dynamic_field_info.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_info.3x.gz dynamic_field_info.3x.gz )
( cd usr/man/man3 ; rm -rf get_wstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_get_wstr.3x.gz get_wstr.3x.gz )
( cd usr/man/man3 ; rm -rf move.3x.gz )
( cd usr/man/man3 ; ln -sf curs_move.3x.gz move.3x.gz )
( cd usr/man/man3 ; rm -rf init_color.3x.gz )
( cd usr/man/man3 ; ln -sf curs_color.3x.gz init_color.3x.gz )
( cd usr/man/man3 ; rm -rf getbkgrnd.3x.gz )
( cd usr/man/man3 ; ln -sf curs_bkgrnd.3x.gz getbkgrnd.3x.gz )
( cd usr/man/man3 ; rm -rf set_field_init.3x.gz )
( cd usr/man/man3 ; ln -sf form_hook.3x.gz set_field_init.3x.gz )
( cd usr/man/man3 ; rm -rf attr_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz attr_set.3x.gz )
( cd usr/man/man3 ; rm -rf getn_wstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_get_wstr.3x.gz getn_wstr.3x.gz )
( cd usr/man/man3 ; rm -rf longname.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termattrs.3x.gz longname.3x.gz )
( cd usr/man/man3 ; rm -rf attrset.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz attrset.3x.gz )
( cd usr/man/man3 ; rm -rf clearok.3x.gz )
( cd usr/man/man3 ; ln -sf curs_outopts.3x.gz clearok.3x.gz )
( cd usr/man/man3 ; rm -rf can_change_color.3x.gz )
( cd usr/man/man3 ; ln -sf curs_color.3x.gz can_change_color.3x.gz )
( cd usr/man/man3 ; rm -rf _tracedump.3x.gz )
( cd usr/man/man3 ; ln -sf curs_trace.3x.gz _tracedump.3x.gz )
( cd usr/man/man3 ; rm -rf flushinp.3x.gz )
( cd usr/man/man3 ; ln -sf curs_util.3x.gz flushinp.3x.gz )
( cd usr/man/man3 ; rm -rf echochar.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addch.3x.gz echochar.3x.gz )
( cd usr/man/man3 ; rm -rf _tracechtype.3x.gz )
( cd usr/man/man3 ; ln -sf curs_trace.3x.gz _tracechtype.3x.gz )
( cd usr/man/man3 ; rm -rf item_count.3x.gz )
( cd usr/man/man3 ; ln -sf menu_items.3x.gz item_count.3x.gz )
( cd usr/man/man3 ; rm -rf scale_menu.3x.gz )
( cd usr/man/man3 ; ln -sf menu_win.3x.gz scale_menu.3x.gz )
( cd usr/man/man3 ; rm -rf mvwadd_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wch.3x.gz mvwadd_wch.3x.gz )
( cd usr/man/man3 ; rm -rf addchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addchstr.3x.gz addchstr.3x.gz )
( cd usr/man/man3 ; rm -rf free_form.3x.gz )
( cd usr/man/man3 ; ln -sf form_new.3x.gz free_form.3x.gz )
( cd usr/man/man3 ; rm -rf setscrreg.3x.gz )
( cd usr/man/man3 ; ln -sf curs_outopts.3x.gz setscrreg.3x.gz )
( cd usr/man/man3 ; rm -rf in_wchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_in_wchstr.3x.gz in_wchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf field_just.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_just.3x.gz field_just.3x.gz )
( cd usr/man/man3 ; rm -rf wattroff.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz wattroff.3x.gz )
( cd usr/man/man3 ; rm -rf pnoutrefresh.3x.gz )
( cd usr/man/man3 ; ln -sf curs_pad.3x.gz pnoutrefresh.3x.gz )
( cd usr/man/man3 ; rm -rf mvwscanw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_scanw.3x.gz mvwscanw.3x.gz )
( cd usr/man/man3 ; rm -rf tigetstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz tigetstr.3x.gz )
( cd usr/man/man3 ; rm -rf getnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getstr.3x.gz getnstr.3x.gz )
( cd usr/man/man3 ; rm -rf menu_fore.3x.gz )
( cd usr/man/man3 ; ln -sf menu_attributes.3x.gz menu_fore.3x.gz )
( cd usr/man/man3 ; rm -rf touchwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_touch.3x.gz touchwin.3x.gz )
( cd usr/man/man3 ; rm -rf putwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_util.3x.gz putwin.3x.gz )
( cd usr/man/man3 ; rm -rf insdelln.3x.gz )
( cd usr/man/man3 ; ln -sf curs_deleteln.3x.gz insdelln.3x.gz )
( cd usr/man/man3 ; rm -rf wbkgrnd.3x.gz )
( cd usr/man/man3 ; ln -sf curs_bkgrnd.3x.gz wbkgrnd.3x.gz )
( cd usr/man/man3 ; rm -rf tgetstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termcap.3x.gz tgetstr.3x.gz )
( cd usr/man/man3 ; rm -rf winsertln.3x.gz )
( cd usr/man/man3 ; ln -sf curs_deleteln.3x.gz winsertln.3x.gz )
( cd usr/man/man3 ; rm -rf standend.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz standend.3x.gz )
( cd usr/man/man3 ; rm -rf field_buffer.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_buffer.3x.gz field_buffer.3x.gz )
( cd usr/man/man3 ; rm -rf getch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getch.3x.gz getch.3x.gz )
( cd usr/man/man3 ; rm -rf mvwins_wstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_ins_wstr.3x.gz mvwins_wstr.3x.gz )
( cd usr/man/man3 ; rm -rf untouchwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_touch.3x.gz untouchwin.3x.gz )
( cd usr/man/man3 ; rm -rf overlay.3x.gz )
( cd usr/man/man3 ; ln -sf curs_overlay.3x.gz overlay.3x.gz )
( cd usr/man/man3 ; rm -rf copywin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_overlay.3x.gz copywin.3x.gz )
( cd usr/man/man3 ; rm -rf unpost_form.3x.gz )
( cd usr/man/man3 ; ln -sf form_post.3x.gz unpost_form.3x.gz )
( cd usr/man/man3 ; rm -rf mvwgetn_wstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_get_wstr.3x.gz mvwgetn_wstr.3x.gz )
( cd usr/man/man3 ; rm -rf mvprintw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_printw.3x.gz mvprintw.3x.gz )
( cd usr/man/man3 ; rm -rf killwchar.3x.gz )
( cd usr/man/man3 ; ln -sf curs_termattrs.3x.gz killwchar.3x.gz )
( cd usr/man/man3 ; rm -rf mvwins_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_ins_wch.3x.gz mvwins_wch.3x.gz )
( cd usr/man/man3 ; rm -rf set_form_win.3x.gz )
( cd usr/man/man3 ; ln -sf form_win.3x.gz set_form_win.3x.gz )
( cd usr/man/man3 ; rm -rf derwin.3x.gz )
( cd usr/man/man3 ; ln -sf curs_window.3x.gz derwin.3x.gz )
( cd usr/man/man3 ; rm -rf scr_init.3x.gz )
( cd usr/man/man3 ; ln -sf curs_scr_dump.3x.gz scr_init.3x.gz )
( cd usr/man/man3 ; rm -rf slk_init.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_init.3x.gz )
( cd usr/man/man3 ; rm -rf mvgetch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getch.3x.gz mvgetch.3x.gz )
( cd usr/man/man3 ; rm -rf slk_clear.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_clear.3x.gz )
( cd usr/man/man3 ; rm -rf attr_get.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz attr_get.3x.gz )
( cd usr/man/man3 ; rm -rf menu_term.3x.gz )
( cd usr/man/man3 ; ln -sf menu_hook.3x.gz menu_term.3x.gz )
( cd usr/man/man3 ; rm -rf item_opts_on.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_opts.3x.gz item_opts_on.3x.gz )
( cd usr/man/man3 ; rm -rf addwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addwstr.3x.gz addwstr.3x.gz )
( cd usr/man/man3 ; rm -rf winnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_instr.3x.gz winnstr.3x.gz )
( cd usr/man/man3 ; rm -rf mvwinnwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inwstr.3x.gz mvwinnwstr.3x.gz )
( cd usr/man/man3 ; rm -rf update_panels.3x.gz )
( cd usr/man/man3 ; ln -sf panel.3x.gz update_panels.3x.gz )
( cd usr/man/man3 ; rm -rf mvwaddch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addch.3x.gz mvwaddch.3x.gz )
( cd usr/man/man3 ; rm -rf mvgetnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getstr.3x.gz mvgetnstr.3x.gz )
( cd usr/man/man3 ; rm -rf vline_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border_set.3x.gz vline_set.3x.gz )
( cd usr/man/man3 ; rm -rf mvwdelch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_delch.3x.gz mvwdelch.3x.gz )
( cd usr/man/man3 ; rm -rf field_info.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_info.3x.gz field_info.3x.gz )
( cd usr/man/man3 ; rm -rf set_field_fore.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_attributes.3x.gz set_field_fore.3x.gz )
( cd usr/man/man3 ; rm -rf has_colors.3x.gz )
( cd usr/man/man3 ; ln -sf curs_color.3x.gz has_colors.3x.gz )
( cd usr/man/man3 ; rm -rf prefresh.3x.gz )
( cd usr/man/man3 ; ln -sf curs_pad.3x.gz prefresh.3x.gz )
( cd usr/man/man3 ; rm -rf mvwinsch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_insch.3x.gz mvwinsch.3x.gz )
( cd usr/man/man3 ; rm -rf set_item_init.3x.gz )
( cd usr/man/man3 ; ln -sf menu_hook.3x.gz set_item_init.3x.gz )
( cd usr/man/man3 ; rm -rf hline_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border_set.3x.gz hline_set.3x.gz )
( cd usr/man/man3 ; rm -rf notimeout.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz notimeout.3x.gz )
( cd usr/man/man3 ; rm -rf clrtobot.3x.gz )
( cd usr/man/man3 ; ln -sf curs_clear.3x.gz clrtobot.3x.gz )
( cd usr/man/man3 ; rm -rf wclear.3x.gz )
( cd usr/man/man3 ; ln -sf curs_clear.3x.gz wclear.3x.gz )
( cd usr/man/man3 ; rm -rf idcok.3x.gz )
( cd usr/man/man3 ; ln -sf curs_outopts.3x.gz idcok.3x.gz )
( cd usr/man/man3 ; rm -rf scanw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_scanw.3x.gz scanw.3x.gz )
( cd usr/man/man3 ; rm -rf wvline.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border.3x.gz wvline.3x.gz )
( cd usr/man/man3 ; rm -rf field_count.3x.gz )
( cd usr/man/man3 ; ln -sf form_field.3x.gz field_count.3x.gz )
( cd usr/man/man3 ; rm -rf slk_attrset.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_attrset.3x.gz )
( cd usr/man/man3 ; rm -rf PAIR_NUMBER.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz PAIR_NUMBER.3x.gz )
( cd usr/man/man3 ; rm -rf menu_grey.3x.gz )
( cd usr/man/man3 ; ln -sf menu_attributes.3x.gz menu_grey.3x.gz )
( cd usr/man/man3 ; rm -rf vw_scanw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_scanw.3x.gz vw_scanw.3x.gz )
( cd usr/man/man3 ; rm -rf mvwadd_wchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_add_wchstr.3x.gz mvwadd_wchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf slk_touch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_touch.3x.gz )
( cd usr/man/man3 ; rm -rf mvaddwstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addwstr.3x.gz mvaddwstr.3x.gz )
( cd usr/man/man3 ; rm -rf mvwinnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_instr.3x.gz mvwinnstr.3x.gz )
( cd usr/man/man3 ; rm -rf set_field_term.3x.gz )
( cd usr/man/man3 ; ln -sf form_hook.3x.gz set_field_term.3x.gz )
( cd usr/man/man3 ; rm -rf mvgetn_wstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_get_wstr.3x.gz mvgetn_wstr.3x.gz )
( cd usr/man/man3 ; rm -rf bkgrnd.3x.gz )
( cd usr/man/man3 ; ln -sf curs_bkgrnd.3x.gz bkgrnd.3x.gz )
( cd usr/man/man3 ; rm -rf unget_wch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_get_wch.3x.gz unget_wch.3x.gz )
( cd usr/man/man3 ; rm -rf mvscanw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_scanw.3x.gz mvscanw.3x.gz )
( cd usr/man/man3 ; rm -rf wscrl.3x.gz )
( cd usr/man/man3 ; ln -sf curs_scroll.3x.gz wscrl.3x.gz )
( cd usr/man/man3 ; rm -rf mvinchnstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inchstr.3x.gz mvinchnstr.3x.gz )
( cd usr/man/man3 ; rm -rf is_term_resized.3x.gz )
( cd usr/man/man3 ; ln -sf resizeterm.3x.gz is_term_resized.3x.gz )
( cd usr/man/man3 ; rm -rf slk_color.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_color.3x.gz )
( cd usr/man/man3 ; rm -rf mvwvline_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border_set.3x.gz mvwvline_set.3x.gz )
( cd usr/man/man3 ; rm -rf mvwinchstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inchstr.3x.gz mvwinchstr.3x.gz )
( cd usr/man/man3 ; rm -rf item_userptr.3x.gz )
( cd usr/man/man3 ; ln -sf mitem_userptr.3x.gz item_userptr.3x.gz )
( cd usr/man/man3 ; rm -rf mvwhline_set.3x.gz )
( cd usr/man/man3 ; ln -sf curs_border_set.3x.gz mvwhline_set.3x.gz )
( cd usr/man/man3 ; rm -rf new_fieldtype.3x.gz )
( cd usr/man/man3 ; ln -sf form_fieldtype.3x.gz new_fieldtype.3x.gz )
( cd usr/man/man3 ; rm -rf field_pad.3x.gz )
( cd usr/man/man3 ; ln -sf form_field_attributes.3x.gz field_pad.3x.gz )
( cd usr/man/man3 ; rm -rf echo.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz echo.3x.gz )
( cd usr/man/man3 ; rm -rf intrflush.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz intrflush.3x.gz )
( cd usr/man/man3 ; rm -rf mvgetstr.3x.gz )
( cd usr/man/man3 ; ln -sf curs_getstr.3x.gz mvgetstr.3x.gz )
( cd usr/man/man3 ; rm -rf filter.3x.gz )
( cd usr/man/man3 ; ln -sf curs_util.3x.gz filter.3x.gz )
( cd usr/man/man3 ; rm -rf vid_puts.3x.gz )
( cd usr/man/man3 ; ln -sf curs_terminfo.3x.gz vid_puts.3x.gz )
( cd usr/man/man3 ; rm -rf menu_request_name.3x.gz )
( cd usr/man/man3 ; ln -sf menu_requestname.3x.gz menu_request_name.3x.gz )
( cd usr/man/man3 ; rm -rf slk_restore.3x.gz )
( cd usr/man/man3 ; ln -sf curs_slk.3x.gz slk_restore.3x.gz )
( cd usr/man/man3 ; rm -rf attr_off.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz attr_off.3x.gz )
( cd usr/man/man3 ; rm -rf raw.3x.gz )
( cd usr/man/man3 ; ln -sf curs_inopts.3x.gz raw.3x.gz )
( cd usr/man/man3 ; rm -rf wbkgrndset.3x.gz )
( cd usr/man/man3 ; ln -sf curs_bkgrnd.3x.gz wbkgrndset.3x.gz )
( cd usr/man/man3 ; rm -rf attroff.3x.gz )
( cd usr/man/man3 ; ln -sf curs_attr.3x.gz attroff.3x.gz )
( cd usr/man/man3 ; rm -rf set_menu_mark.3x.gz )
( cd usr/man/man3 ; ln -sf menu_mark.3x.gz set_menu_mark.3x.gz )
( cd usr/man/man3 ; rm -rf set_new_page.3x.gz )
( cd usr/man/man3 ; ln -sf form_new_page.3x.gz set_new_page.3x.gz )
( cd usr/man/man3 ; rm -rf addch.3x.gz )
( cd usr/man/man3 ; ln -sf curs_addch.3x.gz addch.3x.gz )
( cd usr/share/terminfo/1 ; rm -rf 1178 )
( cd usr/share/terminfo/1 ; ln -sf ../a/adm1178 1178 )
( cd usr/share/terminfo/1 ; rm -rf 1730-lm )
( cd usr/share/terminfo/1 ; ln -sf ../d/diablo1740-lm 1730-lm )
( cd usr/share/terminfo/2 ; rm -rf 2621 )
( cd usr/share/terminfo/2 ; ln -sf ../h/hp2621 2621 )
( cd usr/share/terminfo/2 ; rm -rf 2621A )
( cd usr/share/terminfo/2 ; ln -sf ../h/hp2621 2621A )
( cd usr/share/terminfo/2 ; rm -rf 2621a )
( cd usr/share/terminfo/2 ; ln -sf ../h/hp2621 2621a )
( cd usr/share/terminfo/2 ; rm -rf 2621-wl )
( cd usr/share/terminfo/2 ; ln -sf ../h/hp2621 2621-wl )
( cd usr/share/terminfo/3 ; rm -rf 3b1 )
( cd usr/share/terminfo/3 ; ln -sf ../a/att7300 3b1 )
( cd usr/share/terminfo/3 ; rm -rf 386at )
( cd usr/share/terminfo/3 ; ln -sf ../a/att6386 386at )
( cd usr/share/terminfo/4 ; rm -rf 4025ex )
( cd usr/share/terminfo/4 ; ln -sf ../t/tek4025ex 4025ex )
( cd usr/share/terminfo/4 ; rm -rf 4027ex )
( cd usr/share/terminfo/4 ; ln -sf ../t/tek4025ex 4027ex )
( cd usr/share/terminfo/4 ; rm -rf 4410-w )
( cd usr/share/terminfo/4 ; ln -sf ../a/att5410-w 4410-w )
( cd usr/share/terminfo/5 ; rm -rf 5051 )
( cd usr/share/terminfo/5 ; ln -sf ../i/ibm-pc 5051 )
( cd usr/share/terminfo/5 ; rm -rf 5620 )
( cd usr/share/terminfo/5 ; ln -sf ../a/att5620 5620 )
( cd usr/share/terminfo/5 ; rm -rf 5630DMD-24 )
( cd usr/share/terminfo/5 ; ln -sf ../a/att630-24 5630DMD-24 )
( cd usr/share/terminfo/5 ; rm -rf 5630-24 )
( cd usr/share/terminfo/5 ; ln -sf ../a/att630-24 5630-24 )
( cd usr/share/terminfo/5 ; rm -rf 5410-w )
( cd usr/share/terminfo/5 ; ln -sf ../a/att5410-w 5410-w )
( cd usr/share/terminfo/6 ; rm -rf 6053 )
( cd usr/share/terminfo/6 ; ln -sf ../d/dg6053 6053 )
( cd usr/share/terminfo/6 ; rm -rf 605x )
( cd usr/share/terminfo/6 ; ln -sf ../d/dg6053 605x )
( cd usr/share/terminfo/6 ; rm -rf 6053-dg )
( cd usr/share/terminfo/6 ; ln -sf ../d/dg6053 6053-dg )
( cd usr/share/terminfo/6 ; rm -rf 605x-dg )
( cd usr/share/terminfo/6 ; ln -sf ../d/dg6053 605x-dg )
( cd usr/share/terminfo/6 ; rm -rf 630-lm )
( cd usr/share/terminfo/6 ; ln -sf ../d/diablo1740-lm 630-lm )
( cd usr/share/terminfo/6 ; rm -rf 630MTG-24 )
( cd usr/share/terminfo/6 ; ln -sf ../a/att630-24 630MTG-24 )
( cd usr/share/terminfo/7 ; rm -rf 730MTG-24 )
( cd usr/share/terminfo/7 ; ln -sf ../a/att730-24 730MTG-24 )
( cd usr/share/terminfo/7 ; rm -rf 730MTG-41 )
( cd usr/share/terminfo/7 ; ln -sf ../a/att730-41 730MTG-41 )
( cd usr/share/terminfo/7 ; rm -rf 730MTG-41r )
( cd usr/share/terminfo/7 ; ln -sf ../a/att730r-41 730MTG-41r )
( cd usr/share/terminfo/7 ; rm -rf 730MTGr-24 )
( cd usr/share/terminfo/7 ; ln -sf ../a/att730r-24 730MTGr-24 )
( cd usr/share/terminfo/7 ; rm -rf 730MTGr )
( cd usr/share/terminfo/7 ; ln -sf ../a/att730r 730MTGr )
( cd usr/share/terminfo/8 ; rm -rf 8510 )
( cd usr/share/terminfo/8 ; ln -sf ../c/citoh 8510 )
( cd usr/share/terminfo/9 ; rm -rf 955-w )
( cd usr/share/terminfo/9 ; ln -sf ../t/tvi955-w 955-w )
( cd usr/share/terminfo/9 ; rm -rf 955-hb )
( cd usr/share/terminfo/9 ; ln -sf ../t/tvi955-hb 955-hb )
( cd usr/share/terminfo/A ; rm -rf Apple_Terminal )
( cd usr/share/terminfo/A ; ln -sf ../n/nsterm Apple_Terminal )
( cd usr/share/terminfo/E ; rm -rf Eterm-color )
( cd usr/share/terminfo/E ; ln -sf ../E/Eterm Eterm-color )
( cd usr/share/terminfo/L ; rm -rf LFT-PC850 )
( cd usr/share/terminfo/L ; ln -sf ../l/lft LFT-PC850 )
( cd usr/share/terminfo/N ; rm -rf NCRVT100WPP )
( cd usr/share/terminfo/N ; ln -sf ../n/ncrvt100wan NCRVT100WPP )
( cd usr/share/terminfo/P ; rm -rf P4 )
( cd usr/share/terminfo/P ; ln -sf ../p/prism4 P4 )
( cd usr/share/terminfo/P ; rm -rf P5 )
( cd usr/share/terminfo/P ; ln -sf ../p/prism5 P5 )
( cd usr/share/terminfo/P ; rm -rf P7 )
( cd usr/share/terminfo/P ; ln -sf ../p/prism7 P7 )
( cd usr/share/terminfo/P ; rm -rf P8 )
( cd usr/share/terminfo/P ; ln -sf ../p/prism8 P8 )
( cd usr/share/terminfo/P ; rm -rf P9 )
( cd usr/share/terminfo/P ; ln -sf ../p/prism9 P9 )
( cd usr/share/terminfo/P ; rm -rf P12 )
( cd usr/share/terminfo/P ; ln -sf ../p/prism12 P12 )
( cd usr/share/terminfo/P ; rm -rf P14 )
( cd usr/share/terminfo/P ; ln -sf ../p/prism14 P14 )
( cd usr/share/terminfo/P ; rm -rf P8-W )
( cd usr/share/terminfo/P ; ln -sf ../p/prism8-w P8-W )
( cd usr/share/terminfo/P ; rm -rf P9-8 )
( cd usr/share/terminfo/P ; ln -sf ../p/prism9-8 P9-8 )
( cd usr/share/terminfo/P ; rm -rf P9-W )
( cd usr/share/terminfo/P ; ln -sf ../p/prism9-w P9-W )
( cd usr/share/terminfo/P ; rm -rf P12-M )
( cd usr/share/terminfo/P ; ln -sf ../p/prism12-m P12-M )
( cd usr/share/terminfo/P ; rm -rf P12-W )
( cd usr/share/terminfo/P ; ln -sf ../p/prism12-w P12-W )
( cd usr/share/terminfo/P ; rm -rf P14-M )
( cd usr/share/terminfo/P ; ln -sf ../p/prism14-m P14-M )
( cd usr/share/terminfo/P ; rm -rf P14-W )
( cd usr/share/terminfo/P ; ln -sf ../p/prism14-w P14-W )
( cd usr/share/terminfo/P ; rm -rf P9-8-W )
( cd usr/share/terminfo/P ; ln -sf ../p/prism9-8-w P9-8-W )
( cd usr/share/terminfo/P ; rm -rf P12-M-W )
( cd usr/share/terminfo/P ; ln -sf ../p/prism12-m-w P12-M-W )
( cd usr/share/terminfo/P ; rm -rf P14-M-W )
( cd usr/share/terminfo/P ; ln -sf ../p/prism14-m-w P14-M-W )
( cd usr/share/terminfo/Q ; rm -rf Q306-8-pc )
( cd usr/share/terminfo/Q ; ln -sf ../b/bq300-8-pc Q306-8-pc )
( cd usr/share/terminfo/Q ; rm -rf Q310-vip-H )
( cd usr/share/terminfo/Q ; ln -sf ../v/vip-H Q310-vip-H )
( cd usr/share/terminfo/Q ; rm -rf Q310-vip-w )
( cd usr/share/terminfo/Q ; ln -sf ../v/vip-w Q310-vip-w )
( cd usr/share/terminfo/Q ; rm -rf Q310-vip-Hw )
( cd usr/share/terminfo/Q ; ln -sf ../v/vip-Hw Q310-vip-Hw )
( cd usr/share/terminfo/Q ; rm -rf Q310-vip-H-am )
( cd usr/share/terminfo/Q ; ln -sf ../v/vip-H Q310-vip-H-am )
( cd usr/share/terminfo/Q ; rm -rf Q310-vip-w-am )
( cd usr/share/terminfo/Q ; ln -sf ../v/vip-w Q310-vip-w-am )
( cd usr/share/terminfo/X ; rm -rf X-hpterm )
( cd usr/share/terminfo/X ; ln -sf ../h/hpterm X-hpterm )
( cd usr/share/terminfo/a ; rm -rf aj )
( cd usr/share/terminfo/a ; ln -sf ../a/aj830 aj )
( cd usr/share/terminfo/a ; rm -rf a80 )
( cd usr/share/terminfo/a ; ln -sf ../a/ampex80 a80 )
( cd usr/share/terminfo/a ; rm -rf apl )
( cd usr/share/terminfo/a ; ln -sf ../i/ibm-apl apl )
( cd usr/share/terminfo/a ; rm -rf aaa-ctxt )
( cd usr/share/terminfo/a ; ln -sf ../a/aaa-30-ctxt aaa-ctxt )
( cd usr/share/terminfo/a ; rm -rf aaa-s-rv )
( cd usr/share/terminfo/a ; ln -sf ../a/aaa-30-s-rv aaa-s-rv )
( cd usr/share/terminfo/a ; rm -rf a210 )
( cd usr/share/terminfo/a ; ln -sf ../a/ampex210 a210 )
( cd usr/share/terminfo/a ; rm -rf a980 )
( cd usr/share/terminfo/a ; ln -sf ../a/adds980 a980 )
( cd usr/share/terminfo/a ; rm -rf adm1 )
( cd usr/share/terminfo/a ; ln -sf ../a/adm1a adm1 )
( cd usr/share/terminfo/a ; rm -rf alt2 )
( cd usr/share/terminfo/a ; ln -sf ../a/altos2 alt2 )
( cd usr/share/terminfo/a ; rm -rf alt3 )
( cd usr/share/terminfo/a ; ln -sf ../a/altos3 alt3 )
( cd usr/share/terminfo/a ; rm -rf alt4 )
( cd usr/share/terminfo/a ; ln -sf ../a/altos4 alt4 )
( cd usr/share/terminfo/a ; rm -rf alt5 )
( cd usr/share/terminfo/a ; ln -sf ../a/altos3 alt5 )
( cd usr/share/terminfo/a ; rm -rf alt7 )
( cd usr/share/terminfo/a ; ln -sf ../a/altos7 alt7 )
( cd usr/share/terminfo/a ; rm -rf ambassador )
( cd usr/share/terminfo/a ; ln -sf ../a/aaa ambassador )
( cd usr/share/terminfo/a ; rm -rf arm100-am )
( cd usr/share/terminfo/a ; ln -sf ../a/arm100 arm100-am )
( cd usr/share/terminfo/a ; rm -rf ampex-219w )
( cd usr/share/terminfo/a ; ln -sf ../a/ampex219w ampex-219w )
( cd usr/share/terminfo/a ; rm -rf addsviewpoint )
( cd usr/share/terminfo/a ; ln -sf ../v/viewpoint addsviewpoint )
( cd usr/share/terminfo/a ; rm -rf aaa-s )
( cd usr/share/terminfo/a ; ln -sf ../a/aaa-30-s aaa-s )
( cd usr/share/terminfo/a ; rm -rf aj832 )
( cd usr/share/terminfo/a ; ln -sf ../a/aj830 aj832 )
( cd usr/share/terminfo/a ; rm -rf ambas )
( cd usr/share/terminfo/a ; ln -sf ../a/aaa ambas )
( cd usr/share/terminfo/a ; rm -rf at386 )
( cd usr/share/terminfo/a ; ln -sf ../a/att6386 at386 )
( cd usr/share/terminfo/a ; rm -rf ansil )
( cd usr/share/terminfo/a ; ln -sf ../c/cons50 ansil )
( cd usr/share/terminfo/a ; rm -rf ansis )
( cd usr/share/terminfo/a ; ln -sf ../c/cons25 ansis )
( cd usr/share/terminfo/a ; rm -rf ansiw )
( cd usr/share/terminfo/a ; ln -sf ../c/cons25w ansiw )
( cd usr/share/terminfo/a ; rm -rf avt-s )
( cd usr/share/terminfo/a ; ln -sf ../a/avt avt-s )
( cd usr/share/terminfo/a ; rm -rf ampex-219 )
( cd usr/share/terminfo/a ; ln -sf ../a/ampex219 ampex-219 )
( cd usr/share/terminfo/a ; rm -rf ampex-232 )
( cd usr/share/terminfo/a ; ln -sf ../a/ampex232 ampex-232 )
( cd usr/share/terminfo/a ; rm -rf ansi-mono )
( cd usr/share/terminfo/a ; ln -sf ../a/ansi-m ansi-mono )
( cd usr/share/terminfo/a ; rm -rf ansi80x25 )
( cd usr/share/terminfo/a ; ln -sf ../c/cons25 ansi80x25 )
( cd usr/share/terminfo/a ; rm -rf ansi80x30 )
( cd usr/share/terminfo/a ; ln -sf ../c/cons30 ansi80x30 )
( cd usr/share/terminfo/a ; rm -rf ansi80x43 )
( cd usr/share/terminfo/a ; ln -sf ../c/cons43 ansi80x43 )
( cd usr/share/terminfo/a ; rm -rf ansi80x50 )
( cd usr/share/terminfo/a ; ln -sf ../c/cons50 ansi80x50 )
( cd usr/share/terminfo/a ; rm -rf ansi80x60 )
( cd usr/share/terminfo/a ; ln -sf ../c/cons60 ansi80x60 )
( cd usr/share/terminfo/a ; rm -rf ansisysk )
( cd usr/share/terminfo/a ; ln -sf ../a/ansi.sysk ansisysk )
( cd usr/share/terminfo/a ; rm -rf altoheath )
( cd usr/share/terminfo/a ; ln -sf ../a/alto-h19 altoheath )
( cd usr/share/terminfo/a ; rm -rf aaa-rv-ctxt )
( cd usr/share/terminfo/a ; ln -sf ../a/aaa-30-rv-ctxt aaa-rv-ctxt )
( cd usr/share/terminfo/a ; rm -rf att4410-w )
( cd usr/share/terminfo/a ; ln -sf ../a/att5410-w att4410-w )
( cd usr/share/terminfo/a ; rm -rf att4410v1 )
( cd usr/share/terminfo/a ; ln -sf ../a/att5410v1 att4410v1 )
( cd usr/share/terminfo/a ; rm -rf att4425-w )
( cd usr/share/terminfo/a ; ln -sf ../a/att5425-w att4425-w )
( cd usr/share/terminfo/a ; rm -rf avt-rv-s )
( cd usr/share/terminfo/a ; ln -sf ../a/avt-rv avt-rv-s )
( cd usr/share/terminfo/a ; rm -rf att5418-w )
( cd usr/share/terminfo/a ; ln -sf ../a/att4418-w att5418-w )
( cd usr/share/terminfo/a ; rm -rf att5420-w )
( cd usr/share/terminfo/a ; ln -sf ../a/att4415-w att5420-w )
( cd usr/share/terminfo/a ; rm -rf ansi80x25-raw )
( cd usr/share/terminfo/a ; ln -sf ../c/cons25w ansi80x25-raw )
( cd usr/share/terminfo/a ; rm -rf ansi80x25-mono )
( cd usr/share/terminfo/a ; ln -sf ../c/cons25-m ansi80x25-mono )
( cd usr/share/terminfo/a ; rm -rf aa4080 )
( cd usr/share/terminfo/a ; ln -sf ../a/annarbor4080 aa4080 )
( cd usr/share/terminfo/a ; rm -rf att5420-w-nl )
( cd usr/share/terminfo/a ; ln -sf ../a/att4415-w-nl att5420-w-nl )
( cd usr/share/terminfo/a ; rm -rf att5420-w-rv )
( cd usr/share/terminfo/a ; ln -sf ../a/att4415-w-rv att5420-w-rv )
( cd usr/share/terminfo/a ; rm -rf aaa-30 )
( cd usr/share/terminfo/a ; ln -sf ../a/aaa aaa-30 )
( cd usr/share/terminfo/a ; rm -rf aaa-rv )
( cd usr/share/terminfo/a ; ln -sf ../a/aaa-30-rv aaa-rv )
( cd usr/share/terminfo/a ; rm -rf alto-heath )
( cd usr/share/terminfo/a ; ln -sf ../a/alto-h19 alto-heath )
( cd usr/share/terminfo/a ; rm -rf alt7pc )
( cd usr/share/terminfo/a ; ln -sf ../a/altos7pc alt7pc )
( cd usr/share/terminfo/a ; rm -rf altos5 )
( cd usr/share/terminfo/a ; ln -sf ../a/altos3 altos5 )
( cd usr/share/terminfo/a ; rm -rf amp219 )
( cd usr/share/terminfo/a ; ln -sf ../a/ampex219 amp219 )
( cd usr/share/terminfo/a ; rm -rf att513 )
( cd usr/share/terminfo/a ; ln -sf ../a/att500 att513 )
( cd usr/share/terminfo/a ; rm -rf appleIIc )
( cd usr/share/terminfo/a ; ln -sf ../a/appleIIgs appleIIc )
( cd usr/share/terminfo/a ; rm -rf appleIIe )
( cd usr/share/terminfo/a ; ln -sf ../a/appleIIgs appleIIe )
( cd usr/share/terminfo/a ; rm -rf ansi80x30-mono )
( cd usr/share/terminfo/a ; ln -sf ../c/cons30-m ansi80x30-mono )
( cd usr/share/terminfo/a ; rm -rf avt-w-rv-s )
( cd usr/share/terminfo/a ; ln -sf ../a/avt-w-rv avt-w-rv-s )
( cd usr/share/terminfo/a ; rm -rf att4425-nl )
( cd usr/share/terminfo/a ; ln -sf ../a/att5425-nl att4425-nl )
( cd usr/share/terminfo/a ; rm -rf att5420-rv-nl )
( cd usr/share/terminfo/a ; ln -sf ../a/att4415-rv-nl att5420-rv-nl )
( cd usr/share/terminfo/a ; rm -rf aaa-unk )
( cd usr/share/terminfo/a ; ln -sf ../a/aaa+unk aaa-unk )
( cd usr/share/terminfo/a ; rm -rf addsvp60 )
( cd usr/share/terminfo/a ; ln -sf ../v/vp60 addsvp60 )
( cd usr/share/terminfo/a ; rm -rf arm100-wam )
( cd usr/share/terminfo/a ; ln -sf ../a/arm100-w arm100-wam )
( cd usr/share/terminfo/a ; rm -rf aaa-30-s-ctxt )
( cd usr/share/terminfo/a ; ln -sf ../a/aaa-s-ctxt aaa-30-s-ctxt )
( cd usr/share/terminfo/a ; rm -rf att5420+nl )
( cd usr/share/terminfo/a ; ln -sf ../a/att4415+nl att5420+nl )
( cd usr/share/terminfo/a ; rm -rf att5420-nl )
( cd usr/share/terminfo/a ; ln -sf ../a/att4415-nl att5420-nl )
( cd usr/share/terminfo/a ; rm -rf att5420-rv )
( cd usr/share/terminfo/a ; ln -sf ../a/att4415-rv att5420-rv )
( cd usr/share/terminfo/a ; rm -rf ansi80x43-mono )
( cd usr/share/terminfo/a ; ln -sf ../c/cons43-m ansi80x43-mono )
( cd usr/share/terminfo/a ; rm -rf ap-vm80 )
( cd usr/share/terminfo/a ; ln -sf ../a/apple-vm80 ap-vm80 )
( cd usr/share/terminfo/a ; rm -rf altoh19 )
( cd usr/share/terminfo/a ; ln -sf ../a/alto-h19 altoh19 )
( cd usr/share/terminfo/a ; rm -rf altos-2 )
( cd usr/share/terminfo/a ; ln -sf ../a/altos2 altos-2 )
( cd usr/share/terminfo/a ; rm -rf altos-3 )
( cd usr/share/terminfo/a ; ln -sf ../a/altos3 altos-3 )
( cd usr/share/terminfo/a ; rm -rf altos-4 )
( cd usr/share/terminfo/a ; ln -sf ../a/altos4 altos-4 )
( cd usr/share/terminfo/a ; rm -rf altos-5 )
( cd usr/share/terminfo/a ; ln -sf ../a/altos3 altos-5 )
( cd usr/share/terminfo/a ; rm -rf amp219w )
( cd usr/share/terminfo/a ; ln -sf ../a/ampex219w amp219w )
( cd usr/share/terminfo/a ; rm -rf ansi43m )
( cd usr/share/terminfo/a ; ln -sf ../p/pcansi-43-m ansi43m )
( cd usr/share/terminfo/a ; rm -rf ansi80x50-mono )
( cd usr/share/terminfo/a ; ln -sf ../c/cons50-m ansi80x50-mono )
( cd usr/share/terminfo/a ; rm -rf att4425 )
( cd usr/share/terminfo/a ; ln -sf ../a/att5425 att4425 )
( cd usr/share/terminfo/a ; rm -rf att5320 )
( cd usr/share/terminfo/a ; ln -sf ../a/att5310 att5320 )
( cd usr/share/terminfo/a ; rm -rf att5410 )
( cd usr/share/terminfo/a ; ln -sf ../a/att4410 att5410 )
( cd usr/share/terminfo/a ; rm -rf att5418 )
( cd usr/share/terminfo/a ; ln -sf ../a/att4418 att5418 )
( cd usr/share/terminfo/a ; rm -rf att5420 )
( cd usr/share/terminfo/a ; ln -sf ../a/att4415 att5420 )
( cd usr/share/terminfo/a ; rm -rf att5430 )
( cd usr/share/terminfo/a ; ln -sf ../a/att505 att5430 )
( cd usr/share/terminfo/a ; rm -rf avatar1 )
( cd usr/share/terminfo/a ; ln -sf ../a/avatar avatar1 )
( cd usr/share/terminfo/a ; rm -rf avt-w-s )
( cd usr/share/terminfo/a ; ln -sf ../a/avt-w avt-w-s )
( cd usr/share/terminfo/a ; rm -rf ansil-mono )
( cd usr/share/terminfo/a ; ln -sf ../c/cons50-m ansil-mono )
( cd usr/share/terminfo/a ; rm -rf att5420-w-rv-n )
( cd usr/share/terminfo/a ; ln -sf ../a/att4415-w-rv-n att5420-w-rv-n )
( cd usr/share/terminfo/a ; rm -rf aaa-30-s-rv-ct )
( cd usr/share/terminfo/a ; ln -sf ../a/aaa-s-rv-ctxt aaa-30-s-rv-ct )
( cd usr/share/terminfo/a ; rm -rf ansi80x60-mono )
( cd usr/share/terminfo/a ; ln -sf ../c/cons60-m ansi80x60-mono )
( cd usr/share/terminfo/a ; rm -rf att5410v1-w )
( cd usr/share/terminfo/a ; ln -sf ../a/att4410v1-w att5410v1-w )
( cd usr/share/terminfo/a ; rm -rf ansis-mono )
( cd usr/share/terminfo/a ; ln -sf ../c/cons25-m ansis-mono )
( cd usr/share/terminfo/b ; rm -rf bh4 )
( cd usr/share/terminfo/b ; ln -sf ../b/beehive4 bh4 )
( cd usr/share/terminfo/b ; rm -rf bee )
( cd usr/share/terminfo/b ; ln -sf ../b/beehive bee )
( cd usr/share/terminfo/b ; rm -rf bh3m )
( cd usr/share/terminfo/b ; ln -sf ../b/beehive3 bh3m )
( cd usr/share/terminfo/b ; rm -rf b-128 )
( cd usr/share/terminfo/b ; ln -sf ../c/commodore b-128 )
( cd usr/share/terminfo/b ; rm -rf bg3.10 )
( cd usr/share/terminfo/b ; ln -sf ../b/bg2.0 bg3.10 )
( cd usr/share/terminfo/b ; rm -rf basic4 )
( cd usr/share/terminfo/b ; ln -sf ../m/mai basic4 )
( cd usr/share/terminfo/b ; rm -rf beehiveIIIm )
( cd usr/share/terminfo/b ; ln -sf ../b/beehive3 beehiveIIIm )
( cd usr/share/terminfo/b ; rm -rf bg2.0nv )
( cd usr/share/terminfo/b ; ln -sf ../b/bitgraph bg2.0nv )
( cd usr/share/terminfo/b ; rm -rf bsdos-pc-mono )
( cd usr/share/terminfo/b ; ln -sf ../b/bsdos-pc-m bsdos-pc-mono )
( cd usr/share/terminfo/b ; rm -rf bct510a )
( cd usr/share/terminfo/b ; ln -sf ../a/att510a bct510a )
( cd usr/share/terminfo/b ; rm -rf bct510d )
( cd usr/share/terminfo/b ; ln -sf ../a/att510d bct510d )
( cd usr/share/terminfo/b ; rm -rf bg3.10nv )
( cd usr/share/terminfo/b ; ln -sf ../b/bitgraph bg3.10nv )
( cd usr/share/terminfo/b ; rm -rf bg3.10rv )
( cd usr/share/terminfo/b ; ln -sf ../b/bg2.0rv bg3.10rv )
( cd usr/share/terminfo/c ; rm -rf cx )
( cd usr/share/terminfo/c ; ln -sf ../c/color_xterm cx )
( cd usr/share/terminfo/c ; rm -rf c104 )
( cd usr/share/terminfo/c ; ln -sf ../c/c100 c104 )
( cd usr/share/terminfo/c ; rm -rf c300 )
( cd usr/share/terminfo/c ; ln -sf ../c/contel300 c300 )
( cd usr/share/terminfo/c ; rm -rf c301 )
( cd usr/share/terminfo/c ; ln -sf ../c/contel301 c301 )
( cd usr/share/terminfo/c ; rm -rf c321 )
( cd usr/share/terminfo/c ; ln -sf ../c/contel301 c321 )
( cd usr/share/terminfo/c ; rm -rf cci1 )
( cd usr/share/terminfo/c ; ln -sf ../c/cci cci1 )
( cd usr/share/terminfo/c ; rm -rf cgc2 )
( cd usr/share/terminfo/c ; ln -sf ../c/cad68-2 cgc2 )
( cd usr/share/terminfo/c ; rm -rf cgc3 )
( cd usr/share/terminfo/c ; ln -sf ../c/cad68-3 cgc3 )
( cd usr/share/terminfo/c ; rm -rf citc )
( cd usr/share/terminfo/c ; ln -sf ../c/cit101 citc )
( cd usr/share/terminfo/c ; rm -rf ct82 )
( cd usr/share/terminfo/c ; ln -sf ../s/swtp ct82 )
( cd usr/share/terminfo/c ; rm -rf cops )
( cd usr/share/terminfo/c ; ln -sf ../c/cops10 cops )
( cd usr/share/terminfo/c ; rm -rf concept )
( cd usr/share/terminfo/c ; ln -sf ../c/c100 concept )
( cd usr/share/terminfo/c ; rm -rf cops-10 )
( cd usr/share/terminfo/c ; ln -sf ../c/cops10 cops-10 )
( cd usr/share/terminfo/c ; rm -rf colorscan )
( cd usr/share/terminfo/c ; ln -sf ../c/cs10 colorscan )
( cd usr/share/terminfo/c ; rm -rf cons60-iso-m )
( cd usr/share/terminfo/c ; ln -sf ../c/cons60l1-m cons60-iso-m )
( cd usr/share/terminfo/c ; rm -rf cons60-koi8r )
( cd usr/share/terminfo/c ; ln -sf ../c/cons60r cons60-koi8r )
( cd usr/share/terminfo/c ; rm -rf c108-rv-8p )
( cd usr/share/terminfo/c ; ln -sf ../c/c108-rv c108-rv-8p )
( cd usr/share/terminfo/c ; rm -rf cx100 )
( cd usr/share/terminfo/c ; ln -sf ../c/color_xterm cx100 )
( cd usr/share/terminfo/c ; rm -rf c100-1p )
( cd usr/share/terminfo/c ; ln -sf ../o/oc100 c100-1p )
( cd usr/share/terminfo/c ; rm -rf c100-4p )
( cd usr/share/terminfo/c ; ln -sf ../c/c100 c100-4p )
( cd usr/share/terminfo/c ; rm -rf c108-8p )
( cd usr/share/terminfo/c ; ln -sf ../c/c108 c108-8p )
( cd usr/share/terminfo/c ; rm -rf c108-w-8p )
( cd usr/share/terminfo/c ; ln -sf ../c/c108-w c108-w-8p )
( cd usr/share/terminfo/c ; rm -rf cons50-iso8859 )
( cd usr/share/terminfo/c ; ln -sf ../c/cons50l1 cons50-iso8859 )
( cd usr/share/terminfo/c ; rm -rf crt-vt220 )
( cd usr/share/terminfo/c ; ln -sf ../c/crt crt-vt220 )
( cd usr/share/terminfo/c ; rm -rf concept108-w-8 )
( cd usr/share/terminfo/c ; ln -sf ../c/c108-w concept108-w-8 )
( cd usr/share/terminfo/c ; rm -rf concept108-w8p )
( cd usr/share/terminfo/c ; ln -sf ../c/c108-w concept108-w8p )
( cd usr/share/terminfo/c ; rm -rf chromatics )
( cd usr/share/terminfo/c ; ln -sf ../c/cg7900 chromatics )
( cd usr/share/terminfo/c ; rm -rf concept108rv4p )
( cd usr/share/terminfo/c ; ln -sf ../c/c108-rv-4p concept108rv4p )
( cd usr/share/terminfo/c ; rm -rf cons25-iso8859 )
( cd usr/share/terminfo/c ; ln -sf ../c/cons25l1 cons25-iso8859 )
( cd usr/share/terminfo/c ; rm -rf coherent )
( cd usr/share/terminfo/c ; ln -sf ../p/pc-coherent coherent )
( cd usr/share/terminfo/c ; rm -rf contel320 )
( cd usr/share/terminfo/c ; ln -sf ../c/contel300 contel320 )
( cd usr/share/terminfo/c ; rm -rf contel321 )
( cd usr/share/terminfo/c ; ln -sf ../c/contel301 contel321 )
( cd usr/share/terminfo/c ; rm -rf concept-avt )
( cd usr/share/terminfo/c ; ln -sf ../a/avt concept-avt )
( cd usr/share/terminfo/c ; rm -rf cons25-iso-m )
( cd usr/share/terminfo/c ; ln -sf ../c/cons25l1-m cons25-iso-m )
( cd usr/share/terminfo/c ; rm -rf ci8510 )
( cd usr/share/terminfo/c ; ln -sf ../c/citoh ci8510 )
( cd usr/share/terminfo/c ; rm -rf cit-80 )
( cd usr/share/terminfo/c ; ln -sf ../c/cit80 cit-80 )
( cd usr/share/terminfo/c ; rm -rf cons50-koi8r-m )
( cd usr/share/terminfo/c ; ln -sf ../c/cons50r-m cons50-koi8r-m )
( cd usr/share/terminfo/c ; rm -rf cons50-iso-m )
( cd usr/share/terminfo/c ; ln -sf ../c/cons50l1-m cons50-iso-m )
( cd usr/share/terminfo/c ; rm -rf cons50-koi8r )
( cd usr/share/terminfo/c ; ln -sf ../c/cons50r cons50-koi8r )
( cd usr/share/terminfo/c ; rm -rf cons25-koi8-r )
( cd usr/share/terminfo/c ; ln -sf ../c/cons25r cons25-koi8-r )
( cd usr/share/terminfo/c ; rm -rf cons25-koi8r-m )
( cd usr/share/terminfo/c ; ln -sf ../c/cons25r-m cons25-koi8r-m )
( cd usr/share/terminfo/c ; rm -rf cons60-iso )
( cd usr/share/terminfo/c ; ln -sf ../c/cons60l1 cons60-iso )
( cd usr/share/terminfo/c ; rm -rf citoh-ps )
( cd usr/share/terminfo/c ; ln -sf ../c/citoh-prop citoh-ps )
( cd usr/share/terminfo/c ; rm -rf cons60-koi8r-m )
( cd usr/share/terminfo/c ; ln -sf ../c/cons60r-m cons60-koi8r-m )
( cd usr/share/terminfo/c ; rm -rf concept100-rv )
( cd usr/share/terminfo/c ; ln -sf ../c/c100-rv concept100-rv )
( cd usr/share/terminfo/c ; rm -rf concept108-4p )
( cd usr/share/terminfo/c ; ln -sf ../c/c108-4p concept108-4p )
( cd usr/share/terminfo/c ; rm -rf concept108-8p )
( cd usr/share/terminfo/c ; ln -sf ../c/c108 concept108-8p )
( cd usr/share/terminfo/c ; rm -rf c100-rv-4p )
( cd usr/share/terminfo/c ; ln -sf ../c/c100-rv c100-rv-4p )
( cd usr/share/terminfo/c ; rm -rf concept100 )
( cd usr/share/terminfo/c ; ln -sf ../c/c100 concept100 )
( cd usr/share/terminfo/c ; rm -rf concept108 )
( cd usr/share/terminfo/c ; ln -sf ../c/c108 concept108 )
( cd usr/share/terminfo/d ; rm -rf d2 )
( cd usr/share/terminfo/d ; ln -sf ../d/dg6053 d2 )
( cd usr/share/terminfo/d ; rm -rf dw )
( cd usr/share/terminfo/d ; ln -sf ../d/dw2 dw )
( cd usr/share/terminfo/d ; rm -rf d80 )
( cd usr/share/terminfo/d ; ln -sf ../a/ampex80 d80 )
( cd usr/share/terminfo/d ; rm -rf dmd )
( cd usr/share/terminfo/d ; ln -sf ../a/att5620 dmd )
( cd usr/share/terminfo/d ; rm -rf dg-ansi )
( cd usr/share/terminfo/d ; ln -sf ../d/dg210 dg-ansi )
( cd usr/share/terminfo/d ; rm -rf darwin-200x64 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-200x64 darwin-200x64 )
( cd usr/share/terminfo/d ; rm -rf darwin-200x75 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-200x75 darwin-200x75 )
( cd usr/share/terminfo/d ; rm -rf darwin-80x25-m )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-80x25-m darwin-80x25-m )
( cd usr/share/terminfo/d ; rm -rf darwin-80x30-m )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-80x30-m darwin-80x30-m )
( cd usr/share/terminfo/d ; rm -rf d214 )
( cd usr/share/terminfo/d ; ln -sf ../d/d210 d214 )
( cd usr/share/terminfo/d ; rm -rf d215 )
( cd usr/share/terminfo/d ; ln -sf ../d/d211 d215 )
( cd usr/share/terminfo/d ; rm -rf d230 )
( cd usr/share/terminfo/d ; ln -sf ../d/d230c d230 )
( cd usr/share/terminfo/d ; rm -rf d411 )
( cd usr/share/terminfo/d ; ln -sf ../d/d410 d411 )
( cd usr/share/terminfo/d ; rm -rf d450 )
( cd usr/share/terminfo/d ; ln -sf ../d/d400 d450 )
( cd usr/share/terminfo/d ; rm -rf d460 )
( cd usr/share/terminfo/d ; ln -sf ../d/d410 d460 )
( cd usr/share/terminfo/d ; rm -rf d461 )
( cd usr/share/terminfo/d ; ln -sf ../d/d410 d461 )
( cd usr/share/terminfo/d ; rm -rf d470 )
( cd usr/share/terminfo/d ; ln -sf ../d/d470c d470 )
( cd usr/share/terminfo/d ; rm -rf dmd1 )
( cd usr/share/terminfo/d ; ln -sf ../a/att5620-1 dmd1 )
( cd usr/share/terminfo/d ; rm -rf ds40 )
( cd usr/share/terminfo/d ; ln -sf ../t/tty40 ds40 )
( cd usr/share/terminfo/d ; rm -rf darwin-256x96 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-256x96 darwin-256x96 )
( cd usr/share/terminfo/d ; rm -rf dt80 )
( cd usr/share/terminfo/d ; ln -sf ../d/dm80 dt80 )
( cd usr/share/terminfo/d ; rm -rf dialogue )
( cd usr/share/terminfo/d ; ln -sf ../a/ampex80 dialogue )
( cd usr/share/terminfo/d ; rm -rf ddr3180 )
( cd usr/share/terminfo/d ; ln -sf ../d/ddr ddr3180 )
( cd usr/share/terminfo/d ; rm -rf d462-unix-25 )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix-25 d462-unix-25 )
( cd usr/share/terminfo/d ; rm -rf d462-unix-sr )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix-sr d462-unix-sr )
( cd usr/share/terminfo/d ; rm -rf d463-unix-s )
( cd usr/share/terminfo/d ; ln -sf ../d/d413-unix-s d463-unix-s )
( cd usr/share/terminfo/d ; rm -rf d463-unix-w )
( cd usr/share/terminfo/d ; ln -sf ../d/d413-unix-w d463-unix-w )
( cd usr/share/terminfo/d ; rm -rf darwin-100x37-m )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-100x37-m darwin-100x37-m )
( cd usr/share/terminfo/d ; rm -rf d430-unix-sr-ccc )
( cd usr/share/terminfo/d ; ln -sf ../d/d430c-unix-sr-ccc d430-unix-sr-ccc )
( cd usr/share/terminfo/d ; rm -rf darwin-b )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-b darwin-b )
( cd usr/share/terminfo/d ; rm -rf darwin-f )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-f darwin-f )
( cd usr/share/terminfo/d ; rm -rf darwin-m )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-m darwin-m )
( cd usr/share/terminfo/d ; rm -rf d216+ )
( cd usr/share/terminfo/d ; ln -sf ../d/d216-unix d216+ )
( cd usr/share/terminfo/d ; rm -rf d2-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/dg6053 d2-dg )
( cd usr/share/terminfo/d ; rm -rf d412+ )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix d412+ )
( cd usr/share/terminfo/d ; rm -rf d462+ )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix d462+ )
( cd usr/share/terminfo/d ; rm -rf dg100 )
( cd usr/share/terminfo/d ; ln -sf ../d/dg6053-old dg100 )
( cd usr/share/terminfo/d ; rm -rf dt80w )
( cd usr/share/terminfo/d ; ln -sf ../d/dm80w dt80w )
( cd usr/share/terminfo/d ; rm -rf dku7102 )
( cd usr/share/terminfo/d ; ln -sf ../t/tws-generic dku7102 )
( cd usr/share/terminfo/d ; rm -rf dku7102-sna )
( cd usr/share/terminfo/d ; ln -sf ../t/tws2102-sna dku7102-sna )
( cd usr/share/terminfo/d ; rm -rf dku7103-sna )
( cd usr/share/terminfo/d ; ln -sf ../t/tws2103-sna dku7103-sna )
( cd usr/share/terminfo/d ; rm -rf dmdt80w )
( cd usr/share/terminfo/d ; ln -sf ../d/dm80w dmdt80w )
( cd usr/share/terminfo/d ; rm -rf darwin-90x30-m )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-90x30-m darwin-90x30-m )
( cd usr/share/terminfo/d ; rm -rf d430-unix-25-ccc )
( cd usr/share/terminfo/d ; ln -sf ../d/d430c-unix-25-ccc d430-unix-25-ccc )
( cd usr/share/terminfo/d ; rm -rf diablo1640-m8 )
( cd usr/share/terminfo/d ; ln -sf ../d/diablo1620-m8 diablo1640-m8 )
( cd usr/share/terminfo/d ; rm -rf d430-unix-25 )
( cd usr/share/terminfo/d ; ln -sf ../d/d430c-unix-25 d430-unix-25 )
( cd usr/share/terminfo/d ; rm -rf d430-unix-sr )
( cd usr/share/terminfo/d ; ln -sf ../d/d430c-unix-sr d430-unix-sr )
( cd usr/share/terminfo/d ; rm -rf dt-100w )
( cd usr/share/terminfo/d ; ln -sf ../d/dt100w dt-100w )
( cd usr/share/terminfo/d ; rm -rf d464-unix-25 )
( cd usr/share/terminfo/d ; ln -sf ../d/d414-unix-25 d464-unix-25 )
( cd usr/share/terminfo/d ; rm -rf d464-unix-sr )
( cd usr/share/terminfo/d ; ln -sf ../d/d414-unix-sr d464-unix-sr )
( cd usr/share/terminfo/d ; rm -rf darwin-112x37-m )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-112x37-m darwin-112x37-m )
( cd usr/share/terminfo/d ; rm -rf darwin-f2 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-f2 darwin-f2 )
( cd usr/share/terminfo/d ; rm -rf datapoint )
( cd usr/share/terminfo/d ; ln -sf ../d/dp3360 datapoint )
( cd usr/share/terminfo/d ; rm -rf diablo-lm )
( cd usr/share/terminfo/d ; ln -sf ../d/diablo1640-lm diablo-lm )
( cd usr/share/terminfo/d ; rm -rf diablo450 )
( cd usr/share/terminfo/d ; ln -sf ../d/diablo1620 diablo450 )
( cd usr/share/terminfo/d ; rm -rf diablo630 )
( cd usr/share/terminfo/d ; ln -sf ../d/diablo1640 diablo630 )
( cd usr/share/terminfo/d ; rm -rf datagraphix )
( cd usr/share/terminfo/d ; ln -sf ../d/d132 datagraphix )
( cd usr/share/terminfo/d ; rm -rf d200-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d200 d200-dg )
( cd usr/share/terminfo/d ; rm -rf d214-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d210-dg d214-dg )
( cd usr/share/terminfo/d ; rm -rf d215-7b )
( cd usr/share/terminfo/d ; ln -sf ../d/d211-7b d215-7b )
( cd usr/share/terminfo/d ; rm -rf d215-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d211-dg d215-dg )
( cd usr/share/terminfo/d ; rm -rf d216+25 )
( cd usr/share/terminfo/d ; ln -sf ../d/d216-unix-25 d216+25 )
( cd usr/share/terminfo/d ; rm -rf d216+dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d216-dg d216+dg )
( cd usr/share/terminfo/d ; rm -rf d217-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d216-dg d217-dg )
( cd usr/share/terminfo/d ; rm -rf d230-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d230c-dg d230-dg )
( cd usr/share/terminfo/d ; rm -rf d460-7b-w )
( cd usr/share/terminfo/d ; ln -sf ../d/d410-7b-w d460-7b-w )
( cd usr/share/terminfo/d ; rm -rf d430-dg-ccc )
( cd usr/share/terminfo/d ; ln -sf ../d/d430c-dg-ccc d430-dg-ccc )
( cd usr/share/terminfo/d ; rm -rf d216e+dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d216-dg d216e+dg )
( cd usr/share/terminfo/d ; rm -rf d216e-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d216-dg d216e-dg )
( cd usr/share/terminfo/d ; rm -rf d461-7b-w )
( cd usr/share/terminfo/d ; ln -sf ../d/d410-7b-w d461-7b-w )
( cd usr/share/terminfo/d ; rm -rf d400-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d400 d400-dg )
( cd usr/share/terminfo/d ; rm -rf d411-7b )
( cd usr/share/terminfo/d ; ln -sf ../d/d410-7b d411-7b )
( cd usr/share/terminfo/d ; rm -rf d411-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d410-dg d411-dg )
( cd usr/share/terminfo/d ; rm -rf d412+25 )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix-25 d412+25 )
( cd usr/share/terminfo/d ; rm -rf d412+dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-dg d412+dg )
( cd usr/share/terminfo/d ; rm -rf d412+sr )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix-sr d412+sr )
( cd usr/share/terminfo/d ; rm -rf d413-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-dg d413-dg )
( cd usr/share/terminfo/d ; rm -rf d430-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d430c-dg d430-dg )
( cd usr/share/terminfo/d ; rm -rf d450-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d400 d450-dg )
( cd usr/share/terminfo/d ; rm -rf d460-7b )
( cd usr/share/terminfo/d ; ln -sf ../d/d410-7b d460-7b )
( cd usr/share/terminfo/d ; rm -rf d460-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d410-dg d460-dg )
( cd usr/share/terminfo/d ; rm -rf d461-7b )
( cd usr/share/terminfo/d ; ln -sf ../d/d410-7b d461-7b )
( cd usr/share/terminfo/d ; rm -rf d461-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d410-dg d461-dg )
( cd usr/share/terminfo/d ; rm -rf d462+25 )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix-25 d462+25 )
( cd usr/share/terminfo/d ; rm -rf d462+dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-dg d462+dg )
( cd usr/share/terminfo/d ; rm -rf d462+sr )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix-sr d462+sr )
( cd usr/share/terminfo/d ; rm -rf d462-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-dg d462-dg )
( cd usr/share/terminfo/d ; rm -rf d463-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-dg d463-dg )
( cd usr/share/terminfo/d ; rm -rf d470-7b )
( cd usr/share/terminfo/d ; ln -sf ../d/d470c-7b d470-7b )
( cd usr/share/terminfo/d ; rm -rf d470-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d470c-dg d470-dg )
( cd usr/share/terminfo/d ; rm -rf d462-unix )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix d462-unix )
( cd usr/share/terminfo/d ; rm -rf d578-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d577-dg d578-dg )
( cd usr/share/terminfo/d ; rm -rf d463-unix )
( cd usr/share/terminfo/d ; ln -sf ../d/d413-unix d463-unix )
( cd usr/share/terminfo/d ; rm -rf d464-unix )
( cd usr/share/terminfo/d ; ln -sf ../d/d414-unix d464-unix )
( cd usr/share/terminfo/d ; rm -rf d216e+ )
( cd usr/share/terminfo/d ; ln -sf ../d/d216-unix d216e+ )
( cd usr/share/terminfo/d ; rm -rf d411-w )
( cd usr/share/terminfo/d ; ln -sf ../d/d410-w d411-w )
( cd usr/share/terminfo/d ; rm -rf d412+s )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix-s d412+s )
( cd usr/share/terminfo/d ; rm -rf d412+w )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix-w d412+w )
( cd usr/share/terminfo/d ; rm -rf d460-w )
( cd usr/share/terminfo/d ; ln -sf ../d/d410-w d460-w )
( cd usr/share/terminfo/d ; rm -rf d461-w )
( cd usr/share/terminfo/d ; ln -sf ../d/d410-w d461-w )
( cd usr/share/terminfo/d ; rm -rf d462+s )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix-s d462+s )
( cd usr/share/terminfo/d ; rm -rf d462+w )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix-w d462+w )
( cd usr/share/terminfo/d ; rm -rf dd5000 )
( cd usr/share/terminfo/d ; ln -sf ../d/delta dd5000 )
( cd usr/share/terminfo/d ; rm -rf dialogue80 )
( cd usr/share/terminfo/d ; ln -sf ../a/ampex80 dialogue80 )
( cd usr/share/terminfo/d ; rm -rf dg605x )
( cd usr/share/terminfo/d ; ln -sf ../d/dg6053 dg605x )
( cd usr/share/terminfo/d ; rm -rf dg6134 )
( cd usr/share/terminfo/d ; ln -sf ../d/dg450 dg6134 )
( cd usr/share/terminfo/d ; rm -rf darwin )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc darwin )
( cd usr/share/terminfo/d ; rm -rf decwriter )
( cd usr/share/terminfo/d ; ln -sf ../d/dw2 decwriter )
( cd usr/share/terminfo/d ; rm -rf d462-unix-s )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix-s d462-unix-s )
( cd usr/share/terminfo/d ; rm -rf d462-unix-w )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-unix-w d462-unix-w )
( cd usr/share/terminfo/d ; rm -rf decpro )
( cd usr/share/terminfo/d ; ln -sf ../p/pro350 decpro )
( cd usr/share/terminfo/d ; rm -rf dm1521 )
( cd usr/share/terminfo/d ; ln -sf ../d/dm1520 dm1521 )
( cd usr/share/terminfo/d ; rm -rf diablo )
( cd usr/share/terminfo/d ; ln -sf ../d/diablo1640 diablo )
( cd usr/share/terminfo/d ; rm -rf darwin-128x40-m )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-128x40-m darwin-128x40-m )
( cd usr/share/terminfo/d ; rm -rf darwin-128x48-m )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-128x48-m darwin-128x48-m )
( cd usr/share/terminfo/d ; rm -rf dmd-24 )
( cd usr/share/terminfo/d ; ln -sf ../a/att5620-24 dmd-24 )
( cd usr/share/terminfo/d ; rm -rf dmd-34 )
( cd usr/share/terminfo/d ; ln -sf ../a/att5620-34 dmd-34 )
( cd usr/share/terminfo/d ; rm -rf dmdt80 )
( cd usr/share/terminfo/d ; ln -sf ../d/dm80 dmdt80 )
( cd usr/share/terminfo/d ; rm -rf ds40-2 )
( cd usr/share/terminfo/d ; ln -sf ../t/tty40 ds40-2 )
( cd usr/share/terminfo/d ; rm -rf dt-100 )
( cd usr/share/terminfo/d ; ln -sf ../d/dt100 dt-100 )
( cd usr/share/terminfo/d ; rm -rf darwin-256x96-m )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-256x96-m darwin-256x96-m )
( cd usr/share/terminfo/d ; rm -rf dwk-vt )
( cd usr/share/terminfo/d ; ln -sf ../d/dwk dwk-vt )
( cd usr/share/terminfo/d ; rm -rf dec-vt330 )
( cd usr/share/terminfo/d ; ln -sf ../v/vt340 dec-vt330 )
( cd usr/share/terminfo/d ; rm -rf dec-vt340 )
( cd usr/share/terminfo/d ; ln -sf ../v/vt340 dec-vt340 )
( cd usr/share/terminfo/d ; rm -rf dec-vt400 )
( cd usr/share/terminfo/d ; ln -sf ../v/vt400 dec-vt400 )
( cd usr/share/terminfo/d ; rm -rf darwin-m-f2 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-m-f2 darwin-m-f2 )
( cd usr/share/terminfo/d ; rm -rf d430-unix-s )
( cd usr/share/terminfo/d ; ln -sf ../d/d430c-unix-s d430-unix-s )
( cd usr/share/terminfo/d ; rm -rf d430-unix-w )
( cd usr/share/terminfo/d ; ln -sf ../d/d430c-unix-w d430-unix-w )
( cd usr/share/terminfo/d ; rm -rf d411-7b-w )
( cd usr/share/terminfo/d ; ln -sf ../d/d410-7b-w d411-7b-w )
( cd usr/share/terminfo/d ; rm -rf d463-unix-25 )
( cd usr/share/terminfo/d ; ln -sf ../d/d413-unix-25 d463-unix-25 )
( cd usr/share/terminfo/d ; rm -rf d463-unix-sr )
( cd usr/share/terminfo/d ; ln -sf ../d/d413-unix-sr d463-unix-sr )
( cd usr/share/terminfo/d ; rm -rf datamedia2500 )
( cd usr/share/terminfo/d ; ln -sf ../d/dm2500 datamedia2500 )
( cd usr/share/terminfo/d ; rm -rf d464-unix-s )
( cd usr/share/terminfo/d ; ln -sf ../d/d414-unix-s d464-unix-s )
( cd usr/share/terminfo/d ; rm -rf d464-unix-w )
( cd usr/share/terminfo/d ; ln -sf ../d/d414-unix-w d464-unix-w )
( cd usr/share/terminfo/d ; rm -rf darwin-200x64-m )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-200x64-m darwin-200x64-m )
( cd usr/share/terminfo/d ; rm -rf darwin-200x75-m )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-200x75-m darwin-200x75-m )
( cd usr/share/terminfo/d ; rm -rf d462e-dg )
( cd usr/share/terminfo/d ; ln -sf ../d/d412-dg d462e-dg )
( cd usr/share/terminfo/d ; rm -rf darwin-m-b )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-m-b darwin-m-b )
( cd usr/share/terminfo/d ; rm -rf darwin-m-f )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-m-f darwin-m-f )
( cd usr/share/terminfo/d ; rm -rf darwin-144x48-m )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-144x48-m darwin-144x48-m )
( cd usr/share/terminfo/d ; rm -rf d430-unix-ccc )
( cd usr/share/terminfo/d ; ln -sf ../d/d430c-unix-ccc d430-unix-ccc )
( cd usr/share/terminfo/d ; rm -rf d430-unix-s-ccc )
( cd usr/share/terminfo/d ; ln -sf ../d/d430c-unix-s-ccc d430-unix-s-ccc )
( cd usr/share/terminfo/d ; rm -rf d430-unix-w-ccc )
( cd usr/share/terminfo/d ; ln -sf ../d/d430c-unix-w-ccc d430-unix-w-ccc )
( cd usr/share/terminfo/d ; rm -rf d430-unix )
( cd usr/share/terminfo/d ; ln -sf ../d/d430c-unix d430-unix )
( cd usr/share/terminfo/d ; rm -rf d216e-unix )
( cd usr/share/terminfo/d ; ln -sf ../d/d216-unix d216e-unix )
( cd usr/share/terminfo/d ; rm -rf darwin-80x25 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-80x25 darwin-80x25 )
( cd usr/share/terminfo/d ; rm -rf darwin-80x30 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-80x30 darwin-80x30 )
( cd usr/share/terminfo/d ; rm -rf darwin-90x30 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-90x30 darwin-90x30 )
( cd usr/share/terminfo/d ; rm -rf darwin-160x64-m )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-160x64-m darwin-160x64-m )
( cd usr/share/terminfo/d ; rm -rf diablo1720 )
( cd usr/share/terminfo/d ; ln -sf ../d/diablo1620 diablo1720 )
( cd usr/share/terminfo/d ; rm -rf diablo1730 )
( cd usr/share/terminfo/d ; ln -sf ../d/diablo1640 diablo1730 )
( cd usr/share/terminfo/d ; rm -rf diablo1740 )
( cd usr/share/terminfo/d ; ln -sf ../d/diablo1640 diablo1740 )
( cd usr/share/terminfo/d ; rm -rf darwin-100x37 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-100x37 darwin-100x37 )
( cd usr/share/terminfo/d ; rm -rf darwin-112x37 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-112x37 darwin-112x37 )
( cd usr/share/terminfo/d ; rm -rf darwin-128x40 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-128x40 darwin-128x40 )
( cd usr/share/terminfo/d ; rm -rf darwin-128x48 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-128x48 darwin-128x48 )
( cd usr/share/terminfo/d ; rm -rf darwin-144x48 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-144x48 darwin-144x48 )
( cd usr/share/terminfo/d ; rm -rf dataspeed40 )
( cd usr/share/terminfo/d ; ln -sf ../t/tty40 dataspeed40 )
( cd usr/share/terminfo/d ; rm -rf darwin-160x64 )
( cd usr/share/terminfo/d ; ln -sf ../x/xnuppc-160x64 darwin-160x64 )
( cd usr/share/terminfo/e ; rm -rf emots )
( cd usr/share/terminfo/e ; ln -sf ../g/gs6300 emots )
( cd usr/share/terminfo/e ; rm -rf excel64-w )
( cd usr/share/terminfo/e ; ln -sf ../e/excel62-w excel64-w )
( cd usr/share/terminfo/e ; rm -rf excel64-rv )
( cd usr/share/terminfo/e ; ln -sf ../e/excel62-rv excel64-rv )
( cd usr/share/terminfo/e ; rm -rf excel64 )
( cd usr/share/terminfo/e ; ln -sf ../e/excel62 excel64 )
( cd usr/share/terminfo/e ; rm -rf ep4000 )
( cd usr/share/terminfo/e ; ln -sf ../e/ep40 ep4000 )
( cd usr/share/terminfo/e ; rm -rf ep4080 )
( cd usr/share/terminfo/e ; ln -sf ../e/ep48 ep4080 )
( cd usr/share/terminfo/e ; rm -rf exec80 )
( cd usr/share/terminfo/e ; ln -sf ../h/hazel exec80 )
( cd usr/share/terminfo/e ; rm -rf envision230 )
( cd usr/share/terminfo/e ; ln -sf ../e/env230 envision230 )
( cd usr/share/terminfo/f ; rm -rf fenix )
( cd usr/share/terminfo/f ; ln -sf ../p/pt100 fenix )
( cd usr/share/terminfo/f ; rm -rf freedom100 )
( cd usr/share/terminfo/f ; ln -sf ../f/f100 freedom100 )
( cd usr/share/terminfo/f ; rm -rf freedom110 )
( cd usr/share/terminfo/f ; ln -sf ../f/f110 freedom110 )
( cd usr/share/terminfo/f ; rm -rf freedom200 )
( cd usr/share/terminfo/f ; ln -sf ../f/f200 freedom200 )
( cd usr/share/terminfo/f ; rm -rf freedom-rv )
( cd usr/share/terminfo/f ; ln -sf ../f/f100-rv freedom-rv )
( cd usr/share/terminfo/f ; rm -rf fixterm )
( cd usr/share/terminfo/f ; ln -sf ../c/cbblit fixterm )
( cd usr/share/terminfo/f ; rm -rf f1720a )
( cd usr/share/terminfo/f ; ln -sf ../f/f1720 f1720a )
( cd usr/share/terminfo/f ; rm -rf fortune )
( cd usr/share/terminfo/f ; ln -sf ../f/fos fortune )
( cd usr/share/terminfo/f ; rm -rf fenixw )
( cd usr/share/terminfo/f ; ln -sf ../p/pt100w fenixw )
( cd usr/share/terminfo/f ; rm -rf freedom )
( cd usr/share/terminfo/f ; ln -sf ../f/f100 freedom )
( cd usr/share/terminfo/g ; rm -rf gt100 )
( cd usr/share/terminfo/g ; ln -sf ../i/i100 gt100 )
( cd usr/share/terminfo/g ; rm -rf go-225 )
( cd usr/share/terminfo/g ; ln -sf ../g/go225 go-225 )
( cd usr/share/terminfo/g ; rm -rf gs5430 )
( cd usr/share/terminfo/g ; ln -sf ../a/att505 gs5430 )
( cd usr/share/terminfo/g ; rm -rf gt100a )
( cd usr/share/terminfo/g ; ln -sf ../i/i100 gt100a )
( cd usr/share/terminfo/g ; rm -rf guru-33 )
( cd usr/share/terminfo/g ; ln -sf ../g/guru guru-33 )
( cd usr/share/terminfo/g ; rm -rf guru-lp )
( cd usr/share/terminfo/g ; ln -sf ../g/guru-76-lp guru-lp )
( cd usr/share/terminfo/g ; rm -rf guru-33-rv )
( cd usr/share/terminfo/g ; ln -sf ../g/guru-rv guru-33-rv )
( cd usr/share/terminfo/g ; rm -rf guru+unk )
( cd usr/share/terminfo/g ; ln -sf ../g/guru guru+unk )
( cd usr/share/terminfo/g ; rm -rf guru-33-s )
( cd usr/share/terminfo/g ; ln -sf ../g/guru-s guru-33-s )
( cd usr/share/terminfo/g ; rm -rf gs5430-22 )
( cd usr/share/terminfo/g ; ln -sf ../t/tt505-22 gs5430-22 )
( cd usr/share/terminfo/g ; rm -rf gs5430-24 )
( cd usr/share/terminfo/g ; ln -sf ../a/att505-24 gs5430-24 )
( cd usr/share/terminfo/h ; rm -rf hp )
( cd usr/share/terminfo/h ; ln -sf ../h/hpgeneric hp )
( cd usr/share/terminfo/h ; rm -rf h80 )
( cd usr/share/terminfo/h ; ln -sf ../h/hazel h80 )
( cd usr/share/terminfo/h ; rm -rf hft )
( cd usr/share/terminfo/h ; ln -sf ../i/ibm5081 hft )
( cd usr/share/terminfo/h ; rm -rf h100 )
( cd usr/share/terminfo/h ; ln -sf ../z/z100 h100 )
( cd usr/share/terminfo/h ; rm -rf h19a )
( cd usr/share/terminfo/h ; ln -sf ../h/h19-a h19a )
( cd usr/share/terminfo/h ; rm -rf h19g )
( cd usr/share/terminfo/h ; ln -sf ../h/h19-g h19g )
( cd usr/share/terminfo/h ; rm -rf he80 )
( cd usr/share/terminfo/h ; ln -sf ../h/hazel he80 )
( cd usr/share/terminfo/h ; rm -rf hp45 )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2645 hp45 )
( cd usr/share/terminfo/h ; rm -rf h19kermit )
( cd usr/share/terminfo/h ; ln -sf ../h/h19k h19kermit )
( cd usr/share/terminfo/h ; rm -rf h-100 )
( cd usr/share/terminfo/h ; ln -sf ../z/z100 h-100 )
( cd usr/share/terminfo/h ; rm -rf h19-b )
( cd usr/share/terminfo/h ; ln -sf ../h/h19 h19-b )
( cd usr/share/terminfo/h ; rm -rf h19us )
( cd usr/share/terminfo/h ; ln -sf ../h/h19-us h19us )
( cd usr/share/terminfo/h ; rm -rf heath )
( cd usr/share/terminfo/h ; ln -sf ../h/h19 heath )
( cd usr/share/terminfo/h ; rm -rf hp700 )
( cd usr/share/terminfo/h ; ln -sf ../h/hpansi hp700 )
( cd usr/share/terminfo/h ; rm -rf hpex2 )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2 hpex2 )
( cd usr/share/terminfo/h ; rm -rf htx11 )
( cd usr/share/terminfo/h ; ln -sf ../z/ztx htx11 )
( cd usr/share/terminfo/h ; rm -rf heath-ansi )
( cd usr/share/terminfo/h ; ln -sf ../h/h19-a heath-ansi )
( cd usr/share/terminfo/h ; rm -rf h29a-kc-bc )
( cd usr/share/terminfo/h ; ln -sf ../z/z29a h29a-kc-bc )
( cd usr/share/terminfo/h ; rm -rf h29a-kc-uc )
( cd usr/share/terminfo/h ; ln -sf ../z/z29a-kc-uc h29a-kc-uc )
( cd usr/share/terminfo/h ; rm -rf heathkit-a )
( cd usr/share/terminfo/h ; ln -sf ../h/h19-a heathkit-a )
( cd usr/share/terminfo/h ; rm -rf hp2621-wl )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2621 hp2621-wl )
( cd usr/share/terminfo/h ; rm -rf hp2621a-a )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2621-a hp2621a-a )
( cd usr/share/terminfo/h ; rm -rf hp2621k45 )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2621-k45 hp2621k45 )
( cd usr/share/terminfo/h ; rm -rf hp2624b-4p )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2624 hp2624b-4p )
( cd usr/share/terminfo/h ; rm -rf h100bw )
( cd usr/share/terminfo/h ; ln -sf ../z/z100bw h100bw )
( cd usr/share/terminfo/h ; rm -rf hp2382 )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2382a hp2382 )
( cd usr/share/terminfo/h ; rm -rf hp2397 )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2397a hp2397 )
( cd usr/share/terminfo/h ; rm -rf hp2624a-10p )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2624-10p hp2624a-10p )
( cd usr/share/terminfo/h ; rm -rf hp2624b-10p )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2624-10p hp2624b-10p )
( cd usr/share/terminfo/h ; rm -rf h19-smul )
( cd usr/share/terminfo/h ; ln -sf ../h/h19-us h19-smul )
( cd usr/share/terminfo/h ; rm -rf hp2621A )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2621 hp2621A )
( cd usr/share/terminfo/h ; rm -rf hp2621a )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2621 hp2621a )
( cd usr/share/terminfo/h ; rm -rf hp2622a )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2622 hp2622a )
( cd usr/share/terminfo/h ; rm -rf hp2623a )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2623 hp2623a )
( cd usr/share/terminfo/h ; rm -rf hp2624a )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2624 hp2624a )
( cd usr/share/terminfo/h ; rm -rf hp2624b )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2624 hp2624b )
( cd usr/share/terminfo/h ; rm -rf hp2626a )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2626 hp2626a )
( cd usr/share/terminfo/h ; rm -rf hp2626p )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2626 hp2626p )
( cd usr/share/terminfo/h ; rm -rf hp2644a )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2640b hp2644a )
( cd usr/share/terminfo/h ; rm -rf hp2645a )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2641a hp2645a )
( cd usr/share/terminfo/h ; rm -rf hp2647a )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2641a hp2647a )
( cd usr/share/terminfo/h ; rm -rf hp2648a )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2648 hp2648a )
( cd usr/share/terminfo/h ; rm -rf hp98720 )
( cd usr/share/terminfo/h ; ln -sf ../h/hp9837 hp98720 )
( cd usr/share/terminfo/h ; rm -rf hp98721 )
( cd usr/share/terminfo/h ; ln -sf ../h/hp9837 hp98721 )
( cd usr/share/terminfo/h ; rm -rf hp70092A )
( cd usr/share/terminfo/h ; ln -sf ../h/hp70092 hp70092A )
( cd usr/share/terminfo/h ; rm -rf hp70092a )
( cd usr/share/terminfo/h ; ln -sf ../h/hp70092 hp70092a )
( cd usr/share/terminfo/h ; rm -rf h-100bw )
( cd usr/share/terminfo/h ; ln -sf ../z/z100bw h-100bw )
( cd usr/share/terminfo/h ; rm -rf hp2624b-4p-p )
( cd usr/share/terminfo/h ; ln -sf ../h/hp2624b-p hp2624b-4p-p )
( cd usr/share/terminfo/h ; rm -rf hp98550a )
( cd usr/share/terminfo/h ; ln -sf ../h/hp98550 hp98550a )
( cd usr/share/terminfo/h ; rm -rf heath-19 )
( cd usr/share/terminfo/h ; ln -sf ../h/h19 heath-19 )
( cd usr/share/terminfo/h ; rm -rf heathkit )
( cd usr/share/terminfo/h ; ln -sf ../h/h19 heathkit )
( cd usr/share/terminfo/h ; rm -rf h29a-nkc-bc )
( cd usr/share/terminfo/h ; ln -sf ../z/z29a-nkc-bc h29a-nkc-bc )
( cd usr/share/terminfo/h ; rm -rf h29a-nkc-uc )
( cd usr/share/terminfo/h ; ln -sf ../z/z29a-nkc-uc h29a-nkc-uc )
( cd usr/share/terminfo/i ; rm -rf ips )
( cd usr/share/terminfo/i ; ln -sf ../c/citoh-prop ips )
( cd usr/share/terminfo/i ; rm -rf ibm6154-c )
( cd usr/share/terminfo/i ; ln -sf ../i/ibmapa8c-c ibm6154-c )
( cd usr/share/terminfo/i ; rm -rf ibmx )
( cd usr/share/terminfo/i ; ln -sf ../i/ibmpcx ibmx )
( cd usr/share/terminfo/i ; rm -rf ipsi )
( cd usr/share/terminfo/i ; ln -sf ../d/diablo1620 ipsi )
( cd usr/share/terminfo/i ; rm -rf i3101 )
( cd usr/share/terminfo/i ; ln -sf ../i/ibm3101 i3101 )
( cd usr/share/terminfo/i ; rm -rf i3164 )
( cd usr/share/terminfo/i ; ln -sf ../i/ibm3164 i3164 )
( cd usr/share/terminfo/i ; rm -rf iq120 )
( cd usr/share/terminfo/i ; ln -sf ../s/soroc120 iq120 )
( cd usr/share/terminfo/i ; rm -rf iq140 )
( cd usr/share/terminfo/i ; ln -sf ../s/soroc140 iq140 )
( cd usr/share/terminfo/i ; rm -rf ibmapa16 )
( cd usr/share/terminfo/i ; ln -sf ../r/rtpc ibmapa16 )
( cd usr/share/terminfo/i ; rm -rf iris-ansi-net )
( cd usr/share/terminfo/i ; ln -sf ../i/iris-ansi iris-ansi-net )
( cd usr/share/terminfo/i ; rm -rf iris40 )
( cd usr/share/terminfo/i ; ln -sf ../w/wsiris iris40 )
( cd usr/share/terminfo/i ; rm -rf ibmpc3r-mono )
( cd usr/share/terminfo/i ; ln -sf ../c/cons25r-m ibmpc3r-mono )
( cd usr/share/terminfo/i ; rm -rf ibm3163 )
( cd usr/share/terminfo/i ; ln -sf ../i/ibm3161 ibm3163 )
( cd usr/share/terminfo/i ; rm -rf ibm5051 )
( cd usr/share/terminfo/i ; ln -sf ../i/ibm-pc ibm5051 )
( cd usr/share/terminfo/i ; rm -rf ibm8507 )
( cd usr/share/terminfo/i ; ln -sf ../i/ibm8503 ibm8507 )
( cd usr/share/terminfo/i ; rm -rf ibm8513 )
( cd usr/share/terminfo/i ; ln -sf ../i/ibm8512 ibm8513 )
( cd usr/share/terminfo/i ; rm -rf ibm8604 )
( cd usr/share/terminfo/i ; ln -sf ../i/ibm8503 ibm8604 )
( cd usr/share/terminfo/i ; rm -rf ibmapa8 )
( cd usr/share/terminfo/i ; ln -sf ../i/ibmapa8c ibmapa8 )
( cd usr/share/terminfo/i ; rm -rf ibmpc3r )
( cd usr/share/terminfo/i ; ln -sf ../c/cons25r ibmpc3r )
( cd usr/share/terminfo/i ; rm -rf icl6402 )
( cd usr/share/terminfo/i ; ln -sf ../i/icl6404 icl6402 )
( cd usr/share/terminfo/i ; rm -rf ibmmpel-c )
( cd usr/share/terminfo/i ; ln -sf ../i/ibm5081-c ibmmpel-c )
( cd usr/share/terminfo/i ; rm -rf intertec )
( cd usr/share/terminfo/i ; ln -sf ../i/intertube intertec )
( cd usr/share/terminfo/i ; rm -rf intextii )
( cd usr/share/terminfo/i ; ln -sf ../i/intext2 intextii )
( cd usr/share/terminfo/i ; rm -rf ibm5154-c )
( cd usr/share/terminfo/i ; ln -sf ../i/ibmega-c ibm5154-c )
( cd usr/share/terminfo/j ; rm -rf jerq )
( cd usr/share/terminfo/j ; ln -sf ../b/blit jerq )
( cd usr/share/terminfo/k ; rm -rf k45 )
( cd usr/share/terminfo/k ; ln -sf ../h/hp2621-k45 k45 )
( cd usr/share/terminfo/k ; rm -rf ktm )
( cd usr/share/terminfo/k ; ln -sf ../s/synertek ktm )
( cd usr/share/terminfo/k ; rm -rf kaypro2 )
( cd usr/share/terminfo/k ; ln -sf ../k/kaypro kaypro2 )
( cd usr/share/terminfo/k ; rm -rf kds6402 )
( cd usr/share/terminfo/k ; ln -sf ../i/icl6404 kds6402 )
( cd usr/share/terminfo/k ; rm -rf kds7372 )
( cd usr/share/terminfo/k ; ln -sf ../i/icl6404 kds7372 )
( cd usr/share/terminfo/k ; rm -rf kds7372-w )
( cd usr/share/terminfo/k ; ln -sf ../i/icl6404-w kds7372-w )
( cd usr/share/terminfo/k ; rm -rf kterm-co )
( cd usr/share/terminfo/k ; ln -sf ../k/kterm-color kterm-co )
( cd usr/share/terminfo/l ; rm -rf lft-pc850 )
( cd usr/share/terminfo/l ; ln -sf ../l/lft lft-pc850 )
( cd usr/share/terminfo/l ; rm -rf la120 )
( cd usr/share/terminfo/l ; ln -sf ../d/dw3 la120 )
( cd usr/share/terminfo/l ; rm -rf layer )
( cd usr/share/terminfo/l ; ln -sf ../a/att5620-s layer )
( cd usr/share/terminfo/l ; rm -rf luna68k )
( cd usr/share/terminfo/l ; ln -sf ../l/luna luna68k )
( cd usr/share/terminfo/m ; rm -rf mod )
( cd usr/share/terminfo/m ; ln -sf ../m/modgraph48 mod )
( cd usr/share/terminfo/m ; rm -rf mouse-sun )
( cd usr/share/terminfo/m ; ln -sf ../m/mterm mouse-sun )
( cd usr/share/terminfo/m ; rm -rf mm314 )
( cd usr/share/terminfo/m ; ln -sf ../m/mime314 mm314 )
( cd usr/share/terminfo/m ; rm -rf mime1 )
( cd usr/share/terminfo/m ; ln -sf ../m/mime mime1 )
( cd usr/share/terminfo/m ; rm -rf mime2 )
( cd usr/share/terminfo/m ; ln -sf ../m/mime mime2 )
( cd usr/share/terminfo/m ; rm -rf mimei )
( cd usr/share/terminfo/m ; ln -sf ../m/mime mimei )
( cd usr/share/terminfo/m ; rm -rf mod24 )
( cd usr/share/terminfo/m ; ln -sf ../m/modgraph mod24 )
( cd usr/share/terminfo/m ; rm -rf mt-70 )
( cd usr/share/terminfo/m ; ln -sf ../m/mt70 mt-70 )
( cd usr/share/terminfo/m ; rm -rf mskermit227 )
( cd usr/share/terminfo/m ; ln -sf ../m/msk227 mskermit227 )
( cd usr/share/terminfo/m ; rm -rf minitel-2 )
( cd usr/share/terminfo/m ; ln -sf ../m/m2-nam minitel-2 )
( cd usr/share/terminfo/m ; rm -rf mskermit22714 )
( cd usr/share/terminfo/m ; ln -sf ../m/msk22714 mskermit22714 )
( cd usr/share/terminfo/m ; rm -rf mskermit227am )
( cd usr/share/terminfo/m ; ln -sf ../m/msk227am mskermit227am )
( cd usr/share/terminfo/m ; rm -rf mime340 )
( cd usr/share/terminfo/m ; ln -sf ../m/mm340 mime340 )
( cd usr/share/terminfo/m ; rm -rf minitel )
( cd usr/share/terminfo/m ; ln -sf ../m/m2-nam minitel )
( cd usr/share/terminfo/m ; rm -rf microbee )
( cd usr/share/terminfo/m ; ln -sf ../m/microb microbee )
( cd usr/share/terminfo/m ; rm -rf mime-3ax )
( cd usr/share/terminfo/m ; ln -sf ../m/mime3ax mime-3ax )
( cd usr/share/terminfo/m ; rm -rf mime2a-v )
( cd usr/share/terminfo/m ; ln -sf ../m/mime2a mime2a-v )
( cd usr/share/terminfo/m ; rm -rf mdl110 )
( cd usr/share/terminfo/m ; ln -sf ../c/cyb110 mdl110 )
( cd usr/share/terminfo/m ; rm -rf mimeii )
( cd usr/share/terminfo/m ; ln -sf ../m/mime mimeii )
( cd usr/share/terminfo/m ; rm -rf microterm5 )
( cd usr/share/terminfo/m ; ln -sf ../a/act5 microterm5 )
( cd usr/share/terminfo/m ; rm -rf minitel-2-nam )
( cd usr/share/terminfo/m ; ln -sf ../m/m2-nam minitel-2-nam )
( cd usr/share/terminfo/m ; rm -rf microterm )
( cd usr/share/terminfo/m ; ln -sf ../a/act4 microterm )
( cd usr/share/terminfo/m ; rm -rf macterminal-w )
( cd usr/share/terminfo/m ; ln -sf ../m/mac-w macterminal-w )
( cd usr/share/terminfo/m ; rm -rf macintosh )
( cd usr/share/terminfo/m ; ln -sf ../m/mac macintosh )
( cd usr/share/terminfo/n ; rm -rf nec )
( cd usr/share/terminfo/n ; ln -sf ../n/nec5520 nec )
( cd usr/share/terminfo/n ; rm -rf news )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512 news )
( cd usr/share/terminfo/n ; rm -rf nansisys )
( cd usr/share/terminfo/n ; ln -sf ../n/nansi.sys nansisys )
( cd usr/share/terminfo/n ; rm -rf nwe501-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a nwe501-a )
( cd usr/share/terminfo/n ; rm -rf nwe501-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o nwe501-o )
( cd usr/share/terminfo/n ; rm -rf ncsa-vt220-8 )
( cd usr/share/terminfo/n ; ln -sf ../n/ncsa-m ncsa-vt220-8 )
( cd usr/share/terminfo/n ; rm -rf ntconsole )
( cd usr/share/terminfo/n ; ln -sf ../i/interix ntconsole )
( cd usr/share/terminfo/n ; rm -rf ntconsole-w )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-w ntconsole-w )
( cd usr/share/terminfo/n ; rm -rf ntconsole-25 )
( cd usr/share/terminfo/n ; ln -sf ../i/interix ntconsole-25 )
( cd usr/share/terminfo/n ; rm -rf ntconsole-35 )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-35 ntconsole-35 )
( cd usr/share/terminfo/n ; rm -rf ntconsole-50 )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-50 ntconsole-50 )
( cd usr/share/terminfo/n ; rm -rf ntconsole-60 )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-60 ntconsole-60 )
( cd usr/share/terminfo/n ; rm -rf nwp251-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a nwp251-a )
( cd usr/share/terminfo/n ; rm -rf nwp251-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o nwp251-o )
( cd usr/share/terminfo/n ; rm -rf nwp514-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-a nwp514-a )
( cd usr/share/terminfo/n ; rm -rf nwp514-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-o nwp514-o )
( cd usr/share/terminfo/n ; rm -rf nwp518-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a nwp518-a )
( cd usr/share/terminfo/n ; rm -rf nwp518-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o nwp518-o )
( cd usr/share/terminfo/n ; rm -rf nsterm-7-m )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-m-7 nsterm-7-m )
( cd usr/share/terminfo/n ; rm -rf nsterm-7-s )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-s-7 nsterm-7-s )
( cd usr/share/terminfo/n ; rm -rf nsterm-c-7 )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-7-c nsterm-c-7 )
( cd usr/share/terminfo/n ; rm -rf ncrvt100pp )
( cd usr/share/terminfo/n ; ln -sf ../n/ncrvt100an ncrvt100pp )
( cd usr/share/terminfo/n ; rm -rf nansisysk )
( cd usr/share/terminfo/n ; ln -sf ../n/nansi.sysk nansisysk )
( cd usr/share/terminfo/n ; rm -rf nsterm-acs-c-s )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-c-s-acs nsterm-acs-c-s )
( cd usr/share/terminfo/n ; rm -rf nsterm-acs-m-s )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-m-s-acs nsterm-acs-m-s )
( cd usr/share/terminfo/n ; rm -rf ntconsole-25-w )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-w ntconsole-25-w )
( cd usr/share/terminfo/n ; rm -rf ntconsole-35-w )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-35-w ntconsole-35-w )
( cd usr/share/terminfo/n ; rm -rf ntconsole-50-w )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-50-w ntconsole-50-w )
( cd usr/share/terminfo/n ; rm -rf ntconsole-60-w )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-60-w ntconsole-60-w )
( cd usr/share/terminfo/n ; rm -rf ntconsole-w-vt )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-w-vt ntconsole-w-vt )
( cd usr/share/terminfo/n ; rm -rf ncr7900 )
( cd usr/share/terminfo/n ; ln -sf ../n/ncr7900i ncr7900 )
( cd usr/share/terminfo/n ; rm -rf ntconsole-100 )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-100 ntconsole-100 )
( cd usr/share/terminfo/n ; rm -rf newscbm )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513 newscbm )
( cd usr/share/terminfo/n ; rm -rf ntconsole-25-nti )
( cd usr/share/terminfo/n ; ln -sf ../i/interix-nti ntconsole-25-nti )
( cd usr/share/terminfo/n ; rm -rf ntconsole-35-nti )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-35-nti ntconsole-35-nti )
( cd usr/share/terminfo/n ; rm -rf ntconsole-50-nti )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-50-nti ntconsole-50-nti )
( cd usr/share/terminfo/n ; rm -rf ntconsole-60-nti )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-60-nti ntconsole-60-nti )
( cd usr/share/terminfo/n ; rm -rf news-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-a news-a )
( cd usr/share/terminfo/n ; rm -rf news-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-o news-o )
( cd usr/share/terminfo/n ; rm -rf news31 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513 news31 )
( cd usr/share/terminfo/n ; rm -rf news33 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a news33 )
( cd usr/share/terminfo/n ; rm -rf news40 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512 news40 )
( cd usr/share/terminfo/n ; rm -rf news42 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-a news42 )
( cd usr/share/terminfo/n ; rm -rf ntconsole-100-nti )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-100-nti ntconsole-100-nti )
( cd usr/share/terminfo/n ; rm -rf nwe501 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513 nwe501 )
( cd usr/share/terminfo/n ; rm -rf nwp514 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512 nwp514 )
( cd usr/share/terminfo/n ; rm -rf nwp518 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513 nwp518 )
( cd usr/share/terminfo/n ; rm -rf nxterm )
( cd usr/share/terminfo/n ; ln -sf ../x/xterm-color nxterm )
( cd usr/share/terminfo/n ; rm -rf ncrvt100wpp )
( cd usr/share/terminfo/n ; ln -sf ../n/ncrvt100wan ncrvt100wpp )
( cd usr/share/terminfo/n ; rm -rf nsterm-7-c-s )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-c-s-7 nsterm-7-c-s )
( cd usr/share/terminfo/n ; rm -rf nsterm-7-m-s )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-m-s-7 nsterm-7-m-s )
( cd usr/share/terminfo/n ; rm -rf news28-a )
( cd usr/share/terminfo/n ; ln -sf ../n/news29 news28-a )
( cd usr/share/terminfo/n ; rm -rf news31-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a news31-a )
( cd usr/share/terminfo/n ; rm -rf news31-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o news31-o )
( cd usr/share/terminfo/n ; rm -rf news40-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-a news40-a )
( cd usr/share/terminfo/n ; rm -rf news40-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-o news40-o )
( cd usr/share/terminfo/n ; rm -rf nwp-511 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp511 nwp-511 )
( cd usr/share/terminfo/n ; rm -rf nwp-517 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp517 nwp-517 )
( cd usr/share/terminfo/n ; rm -rf nsterm-acs-c )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-c-acs nsterm-acs-c )
( cd usr/share/terminfo/n ; rm -rf nsterm-acs-m )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-m-acs nsterm-acs-m )
( cd usr/share/terminfo/n ; rm -rf nsterm-acs-s )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-s-acs nsterm-acs-s )
( cd usr/share/terminfo/n ; rm -rf ntconsole-25-w-vt )
( cd usr/share/terminfo/n ; ln -sf ../o/opennt-w-vt ntconsole-25-w-vt )
( cd usr/share/terminfo/n ; rm -rf nwp-517-w )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp517-w nwp-517-w )
( cd usr/share/terminfo/n ; rm -rf ncr260vt300wpp )
( cd usr/share/terminfo/n ; ln -sf ../N/NCR260VT300WPP ncr260vt300wpp )
( cd usr/share/terminfo/n ; rm -rf newscbm-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a newscbm-a )
( cd usr/share/terminfo/n ; rm -rf newscbm-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o newscbm-o )
( cd usr/share/terminfo/n ; rm -rf newscbm33 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a newscbm33 )
( cd usr/share/terminfo/o ; rm -rf o31 )
( cd usr/share/terminfo/o ; ln -sf ../a/adm31-old o31 )
( cd usr/share/terminfo/o ; rm -rf o85h )
( cd usr/share/terminfo/o ; ln -sf ../a/abm85h-old o85h )
( cd usr/share/terminfo/o ; rm -rf osborne1-w )
( cd usr/share/terminfo/o ; ln -sf ../o/osborne-w osborne1-w )
( cd usr/share/terminfo/o ; rm -rf osborne1 )
( cd usr/share/terminfo/o ; ln -sf ../o/osborne osborne1 )
( cd usr/share/terminfo/o ; rm -rf ojerq )
( cd usr/share/terminfo/o ; ln -sf ../o/oblit ojerq )
( cd usr/share/terminfo/o ; rm -rf o4112-nd )
( cd usr/share/terminfo/o ; ln -sf ../o/otek4112 o4112-nd )
( cd usr/share/terminfo/o ; rm -rf opennt-25-w-vt )
( cd usr/share/terminfo/o ; ln -sf ../o/opennt-w-vt opennt-25-w-vt )
( cd usr/share/terminfo/o ; rm -rf otek4113 )
( cd usr/share/terminfo/o ; ln -sf ../o/otek4112 otek4113 )
( cd usr/share/terminfo/o ; rm -rf otek4114 )
( cd usr/share/terminfo/o ; ln -sf ../o/otek4112 otek4114 )
( cd usr/share/terminfo/o ; rm -rf opennt-25-w )
( cd usr/share/terminfo/o ; ln -sf ../o/opennt-w opennt-25-w )
( cd usr/share/terminfo/o ; rm -rf origibmpc3 )
( cd usr/share/terminfo/o ; ln -sf ../o/origpc3 origibmpc3 )
( cd usr/share/terminfo/o ; rm -rf opennt-25 )
( cd usr/share/terminfo/o ; ln -sf ../i/interix opennt-25 )
( cd usr/share/terminfo/o ; rm -rf oabm85h )
( cd usr/share/terminfo/o ; ln -sf ../a/abm85h-old oabm85h )
( cd usr/share/terminfo/o ; rm -rf os9LII )
( cd usr/share/terminfo/o ; ln -sf ../c/coco3 os9LII )
( cd usr/share/terminfo/o ; rm -rf opennt )
( cd usr/share/terminfo/o ; ln -sf ../i/interix opennt )
( cd usr/share/terminfo/o ; rm -rf opennt-25-nti )
( cd usr/share/terminfo/o ; ln -sf ../i/interix-nti opennt-25-nti )
( cd usr/share/terminfo/o ; rm -rf oldibmpc3 )
( cd usr/share/terminfo/o ; ln -sf ../o/oldpc3 oldibmpc3 )
( cd usr/share/terminfo/o ; rm -rf oconcept )
( cd usr/share/terminfo/o ; ln -sf ../o/oc100 oconcept )
( cd usr/share/terminfo/o ; rm -rf opennt-nti )
( cd usr/share/terminfo/o ; ln -sf ../i/interix-nti opennt-nti )
( cd usr/share/terminfo/p ; rm -rf p4 )
( cd usr/share/terminfo/p ; ln -sf ../p/prism4 p4 )
( cd usr/share/terminfo/p ; rm -rf p5 )
( cd usr/share/terminfo/p ; ln -sf ../p/prism5 p5 )
( cd usr/share/terminfo/p ; rm -rf p7 )
( cd usr/share/terminfo/p ; ln -sf ../p/prism7 p7 )
( cd usr/share/terminfo/p ; rm -rf p8 )
( cd usr/share/terminfo/p ; ln -sf ../p/prism8 p8 )
( cd usr/share/terminfo/p ; rm -rf p9 )
( cd usr/share/terminfo/p ; ln -sf ../p/prism9 p9 )
( cd usr/share/terminfo/p ; rm -rf p12 )
( cd usr/share/terminfo/p ; ln -sf ../p/prism12 p12 )
( cd usr/share/terminfo/p ; rm -rf p14 )
( cd usr/share/terminfo/p ; ln -sf ../p/prism14 p14 )
( cd usr/share/terminfo/p ; rm -rf p8-w )
( cd usr/share/terminfo/p ; ln -sf ../p/prism8-w p8-w )
( cd usr/share/terminfo/p ; rm -rf p9-8 )
( cd usr/share/terminfo/p ; ln -sf ../p/prism9-8 p9-8 )
( cd usr/share/terminfo/p ; rm -rf p9-w )
( cd usr/share/terminfo/p ; ln -sf ../p/prism9-w p9-w )
( cd usr/share/terminfo/p ; rm -rf pc3r )
( cd usr/share/terminfo/p ; ln -sf ../c/cons25r pc3r )
( cd usr/share/terminfo/p ; rm -rf pmconsole )
( cd usr/share/terminfo/p ; ln -sf ../p/pmcons pmconsole )
( cd usr/share/terminfo/p ; rm -rf p12-m-w )
( cd usr/share/terminfo/p ; ln -sf ../p/prism12-m-w p12-m-w )
( cd usr/share/terminfo/p ; rm -rf p14-m-w )
( cd usr/share/terminfo/p ; ln -sf ../p/prism14-m-w p14-m-w )
( cd usr/share/terminfo/p ; rm -rf psx_ansi )
( cd usr/share/terminfo/p ; ln -sf ../a/ansi-nt psx_ansi )
( cd usr/share/terminfo/p ; rm -rf pcconsole )
( cd usr/share/terminfo/p ; ln -sf ../p/pccons pcconsole )
( cd usr/share/terminfo/p ; rm -rf pckermit12 )
( cd usr/share/terminfo/p ; ln -sf ../p/pckermit pckermit12 )
( cd usr/share/terminfo/p ; rm -rf p12-m )
( cd usr/share/terminfo/p ; ln -sf ../p/prism12-m p12-m )
( cd usr/share/terminfo/p ; rm -rf p12-w )
( cd usr/share/terminfo/p ; ln -sf ../p/prism12-w p12-w )
( cd usr/share/terminfo/p ; rm -rf p14-m )
( cd usr/share/terminfo/p ; ln -sf ../p/prism14-m p14-m )
( cd usr/share/terminfo/p ; rm -rf p14-w )
( cd usr/share/terminfo/p ; ln -sf ../p/prism14-w p14-w )
( cd usr/share/terminfo/p ; rm -rf pe550 )
( cd usr/share/terminfo/p ; ln -sf ../b/bantam pe550 )
( cd usr/share/terminfo/p ; rm -rf pcz19 )
( cd usr/share/terminfo/p ; ln -sf ../p/pc-coherent pcz19 )
( cd usr/share/terminfo/p ; rm -rf pt200 )
( cd usr/share/terminfo/p ; ln -sf ../p/pt100 pt200 )
( cd usr/share/terminfo/p ; rm -rf pt505 )
( cd usr/share/terminfo/p ; ln -sf ../a/att505 pt505 )
( cd usr/share/terminfo/p ; rm -rf pt505-22 )
( cd usr/share/terminfo/p ; ln -sf ../t/tt505-22 pt505-22 )
( cd usr/share/terminfo/p ; rm -rf pt505-24 )
( cd usr/share/terminfo/p ; ln -sf ../a/att505-24 pt505-24 )
( cd usr/share/terminfo/p ; rm -rf psterm-basic )
( cd usr/share/terminfo/p ; ln -sf ../p/psterm psterm-basic )
( cd usr/share/terminfo/p ; rm -rf pcansi25 )
( cd usr/share/terminfo/p ; ln -sf ../p/pcansi-25 pcansi25 )
( cd usr/share/terminfo/p ; rm -rf pcansi33 )
( cd usr/share/terminfo/p ; ln -sf ../p/pcansi-33 pcansi33 )
( cd usr/share/terminfo/p ; rm -rf pcansi43 )
( cd usr/share/terminfo/p ; ln -sf ../p/pcansi-43 pcansi43 )
( cd usr/share/terminfo/p ; rm -rf p9-8-w )
( cd usr/share/terminfo/p ; ln -sf ../p/prism9-8-w p9-8-w )
( cd usr/share/terminfo/p ; rm -rf pc7300 )
( cd usr/share/terminfo/p ; ln -sf ../a/att7300 pc7300 )
( cd usr/share/terminfo/p ; rm -rf pc3r-m )
( cd usr/share/terminfo/p ; ln -sf ../c/cons25r-m pc3r-m )
( cd usr/share/terminfo/p ; rm -rf pe1100 )
( cd usr/share/terminfo/p ; ln -sf ../f/fox pe1100 )
( cd usr/share/terminfo/p ; rm -rf pe1200 )
( cd usr/share/terminfo/p ; ln -sf ../o/owl pe1200 )
( cd usr/share/terminfo/p ; rm -rf pe6100 )
( cd usr/share/terminfo/p ; ln -sf ../b/bantam pe6100 )
( cd usr/share/terminfo/p ; rm -rf pe6300 )
( cd usr/share/terminfo/p ; ln -sf ../p/pe1251 pe6300 )
( cd usr/share/terminfo/p ; rm -rf pe6312 )
( cd usr/share/terminfo/p ; ln -sf ../p/pe1251 pe6312 )
( cd usr/share/terminfo/p ; rm -rf pt200w )
( cd usr/share/terminfo/p ; ln -sf ../p/pt100w pt200w )
( cd usr/share/terminfo/p ; rm -rf prism8gl )
( cd usr/share/terminfo/p ; ln -sf ../p/p8gl prism8gl )
( cd usr/share/terminfo/p ; rm -rf pc3-bold )
( cd usr/share/terminfo/p ; ln -sf ../i/ibmpc3 pc3-bold )
( cd usr/share/terminfo/p ; rm -rf pcansi25m )
( cd usr/share/terminfo/p ; ln -sf ../p/pcansi-25-m pcansi25m )
( cd usr/share/terminfo/p ; rm -rf pcansi33m )
( cd usr/share/terminfo/p ; ln -sf ../p/pcansi-33-m pcansi33m )
( cd usr/share/terminfo/p ; rm -rf pcansi-mono )
( cd usr/share/terminfo/p ; ln -sf ../p/pcansi-m pcansi-mono )
( cd usr/share/terminfo/p ; rm -rf printer )
( cd usr/share/terminfo/p ; ln -sf ../l/lpr printer )
( cd usr/share/terminfo/q ; rm -rf qnx4 )
( cd usr/share/terminfo/q ; ln -sf ../q/qnx qnx4 )
( cd usr/share/terminfo/q ; rm -rf qume )
( cd usr/share/terminfo/q ; ln -sf ../q/qume5 qume )
( cd usr/share/terminfo/q ; rm -rf qnxt4 )
( cd usr/share/terminfo/q ; ln -sf ../q/qnxt qnxt4 )
( cd usr/share/terminfo/q ; rm -rf qvt101p )
( cd usr/share/terminfo/q ; ln -sf ../q/qvt101+ qvt101p )
( cd usr/share/terminfo/q ; rm -rf qvt119p )
( cd usr/share/terminfo/q ; ln -sf ../q/qvt119+ qvt119p )
( cd usr/share/terminfo/q ; rm -rf qvt203+ )
( cd usr/share/terminfo/q ; ln -sf ../q/qvt203 qvt203+ )
( cd usr/share/terminfo/q ; rm -rf qvt119p-25 )
( cd usr/share/terminfo/q ; ln -sf ../q/qvt119+-25 qvt119p-25 )
( cd usr/share/terminfo/q ; rm -rf qvt119-25-w )
( cd usr/share/terminfo/q ; ln -sf ../q/qvt119+-25-w qvt119-25-w )
( cd usr/share/terminfo/q ; rm -rf qdcons )
( cd usr/share/terminfo/q ; ln -sf ../q/qdss qdcons )
( cd usr/share/terminfo/q ; rm -rf qvt108 )
( cd usr/share/terminfo/q ; ln -sf ../q/qvt101 qvt108 )
( cd usr/share/terminfo/q ; rm -rf qvt119 )
( cd usr/share/terminfo/q ; ln -sf ../q/qvt119+ qvt119 )
( cd usr/share/terminfo/q ; rm -rf qvt119p-w )
( cd usr/share/terminfo/q ; ln -sf ../q/qvt119+-w qvt119p-w )
( cd usr/share/terminfo/q ; rm -rf qvt203-w-am )
( cd usr/share/terminfo/q ; ln -sf ../q/qvt203-w qvt203-w-am )
( cd usr/share/terminfo/q ; rm -rf qvt119p-25-w )
( cd usr/share/terminfo/q ; ln -sf ../q/qvt119+-25-w qvt119p-25-w )
( cd usr/share/terminfo/q ; rm -rf qvt119-w )
( cd usr/share/terminfo/q ; ln -sf ../q/qvt119+-w qvt119-w )
( cd usr/share/terminfo/r ; rm -rf rebus3180 )
( cd usr/share/terminfo/r ; ln -sf ../d/ddr rebus3180 )
( cd usr/share/terminfo/r ; rm -rf regent200 )
( cd usr/share/terminfo/r ; ln -sf ../r/regent60 regent200 )
( cd usr/share/terminfo/s ; rm -rf s4 )
( cd usr/share/terminfo/s ; ln -sf ../a/att7300 s4 )
( cd usr/share/terminfo/s ; rm -rf sb3 )
( cd usr/share/terminfo/s ; ln -sf ../s/sb2 sb3 )
( cd usr/share/terminfo/s ; rm -rf sv80 )
( cd usr/share/terminfo/s ; ln -sf ../a/att2300 sv80 )
( cd usr/share/terminfo/s ; rm -rf sun1 )
( cd usr/share/terminfo/s ; ln -sf ../s/sun sun1 )
( cd usr/share/terminfo/s ; rm -rf sun2 )
( cd usr/share/terminfo/s ; ln -sf ../s/sun sun2 )
( cd usr/share/terminfo/s ; rm -rf sune )
( cd usr/share/terminfo/s ; ln -sf ../s/sun-e sune )
( cd usr/share/terminfo/s ; rm -rf superbee )
( cd usr/share/terminfo/s ; ln -sf ../s/sbi superbee )
( cd usr/share/terminfo/s ; rm -rf sc410 )
( cd usr/share/terminfo/s ; ln -sf ../s/scanset sc410 )
( cd usr/share/terminfo/s ; rm -rf sc415 )
( cd usr/share/terminfo/s ; ln -sf ../s/scanset sc415 )
( cd usr/share/terminfo/s ; rm -rf soroc )
( cd usr/share/terminfo/s ; ln -sf ../s/soroc120 soroc )
( cd usr/share/terminfo/s ; rm -rf sbobcat )
( cd usr/share/terminfo/s ; ln -sf ../b/bobcat sbobcat )
( cd usr/share/terminfo/s ; rm -rf sun-cmd )
( cd usr/share/terminfo/s ; ln -sf ../s/sun-c sun-cmd )
( cd usr/share/terminfo/s ; rm -rf sun-s-e )
( cd usr/share/terminfo/s ; ln -sf ../s/sun-e-s sun-s-e )
( cd usr/share/terminfo/s ; rm -rf sun-nic )
( cd usr/share/terminfo/s ; ln -sf ../s/sun-e sun-nic )
( cd usr/share/terminfo/s ; rm -rf sun-ss5 )
( cd usr/share/terminfo/s ; ln -sf ../s/sun-cgsix sun-ss5 )
( cd usr/share/terminfo/s ; rm -rf system1 )
( cd usr/share/terminfo/s ; ln -sf ../i/ibm-system1 system1 )
( cd usr/share/terminfo/s ; rm -rf spinwriter )
( cd usr/share/terminfo/s ; ln -sf ../n/nec5520 spinwriter )
( cd usr/share/terminfo/s ; rm -rf synertek380 )
( cd usr/share/terminfo/s ; ln -sf ../s/synertek synertek380 )
( cd usr/share/terminfo/t ; rm -rf tab )
( cd usr/share/terminfo/t ; ln -sf ../t/tab132 tab )
( cd usr/share/terminfo/t ; rm -rf ts1 )
( cd usr/share/terminfo/t ; ln -sf ../f/falco ts1 )
( cd usr/share/terminfo/t ; rm -rf ts-1 )
( cd usr/share/terminfo/t ; ln -sf ../f/falco ts-1 )
( cd usr/share/terminfo/t ; rm -rf ts1p )
( cd usr/share/terminfo/t ; ln -sf ../f/falco-p ts1p )
( cd usr/share/terminfo/t ; rm -rf tvi912c-2p-mc )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-2p-mc tvi912c-2p-mc )
( cd usr/share/terminfo/t ; rm -rf tvi920b-unk-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-2p-unk tvi920b-unk-2p )
( cd usr/share/terminfo/t ; rm -rf tvi920b-unk-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-vb-unk tvi920b-unk-vb )
( cd usr/share/terminfo/t ; rm -rf tab132-15 )
( cd usr/share/terminfo/t ; ln -sf ../t/tab132 tab132-15 )
( cd usr/share/terminfo/t ; rm -rf tvi920c-unk )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-unk tvi920c-unk )
( cd usr/share/terminfo/t ; rm -rf tvi920b-p-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-2p-p tvi920b-p-2p )
( cd usr/share/terminfo/t ; rm -rf tvi920b-p-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-vb-p tvi920b-p-vb )
( cd usr/share/terminfo/t ; rm -rf tvi920c-2p-p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-2p-p tvi920c-2p-p )
( cd usr/share/terminfo/t ; rm -rf tvi912c-mc-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-2p-mc tvi912c-mc-2p )
( cd usr/share/terminfo/t ; rm -rf tvi912c-mc-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-vb-mc tvi912c-mc-vb )
( cd usr/share/terminfo/t ; rm -rf tvi920c-p-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-2p-p tvi920c-p-2p )
( cd usr/share/terminfo/t ; rm -rf tvi920c-p-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-vb-p tvi920c-p-vb )
( cd usr/share/terminfo/t ; rm -rf tvi920c-vb-p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-vb-p tvi920c-vb-p )
( cd usr/share/terminfo/t ; rm -rf tvi912c-vb-mc )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-vb-mc tvi912c-vb-mc )
( cd usr/share/terminfo/t ; rm -rf t653x )
( cd usr/share/terminfo/t ; ln -sf ../t/tandem653 t653x )
( cd usr/share/terminfo/t ; rm -rf tek4027-ex )
( cd usr/share/terminfo/t ; ln -sf ../t/tek4025-ex tek4027-ex )
( cd usr/share/terminfo/t ; rm -rf ti733 )
( cd usr/share/terminfo/t ; ln -sf ../t/ti700 ti733 )
( cd usr/share/terminfo/t ; rm -rf ti735 )
( cd usr/share/terminfo/t ; ln -sf ../t/ti700 ti735 )
( cd usr/share/terminfo/t ; rm -rf ti745 )
( cd usr/share/terminfo/t ; ln -sf ../t/ti700 ti745 )
( cd usr/share/terminfo/t ; rm -rf ti800 )
( cd usr/share/terminfo/t ; ln -sf ../t/ti700 ti800 )
( cd usr/share/terminfo/t ; rm -rf tn300 )
( cd usr/share/terminfo/t ; ln -sf ../t/terminet1200 tn300 )
( cd usr/share/terminfo/t ; rm -rf ts-1p )
( cd usr/share/terminfo/t ; ln -sf ../f/falco-p ts-1p )
( cd usr/share/terminfo/t ; rm -rf trsII )
( cd usr/share/terminfo/t ; ln -sf ../t/trs2 trsII )
( cd usr/share/terminfo/t ; rm -rf tty35 )
( cd usr/share/terminfo/t ; ln -sf ../t/tty33 tty35 )
( cd usr/share/terminfo/t ; rm -rf tek4107brl )
( cd usr/share/terminfo/t ; ln -sf ../t/tek4106brl tek4107brl )
( cd usr/share/terminfo/t ; rm -rf tek4109brl )
( cd usr/share/terminfo/t ; ln -sf ../t/tek4106brl tek4109brl )
( cd usr/share/terminfo/t ; rm -rf terminet300 )
( cd usr/share/terminfo/t ; ln -sf ../t/terminet1200 terminet300 )
( cd usr/share/terminfo/t ; rm -rf tty5420-w-nl )
( cd usr/share/terminfo/t ; ln -sf ../a/att4415-w-nl tty5420-w-nl )
( cd usr/share/terminfo/t ; rm -rf tty5420-w-rv )
( cd usr/share/terminfo/t ; ln -sf ../a/att4415-w-rv tty5420-w-rv )
( cd usr/share/terminfo/t ; rm -rf tty5420-w-rv-n )
( cd usr/share/terminfo/t ; ln -sf ../a/att4415-w-rv-n tty5420-w-rv-n )
( cd usr/share/terminfo/t ; rm -rf terminet )
( cd usr/share/terminfo/t ; ln -sf ../t/terminet1200 terminet )
( cd usr/share/terminfo/t ; rm -rf tvi920b-mc-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-2p-mc tvi920b-mc-2p )
( cd usr/share/terminfo/t ; rm -rf tvi920b-mc-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-vb-mc tvi920b-mc-vb )
( cd usr/share/terminfo/t ; rm -rf tek4012 )
( cd usr/share/terminfo/t ; ln -sf ../t/tek tek4012 )
( cd usr/share/terminfo/t ; rm -rf tek4025 )
( cd usr/share/terminfo/t ; ln -sf ../t/tek4024 tek4025 )
( cd usr/share/terminfo/t ; rm -rf tek4027 )
( cd usr/share/terminfo/t ; ln -sf ../t/tek4024 tek4027 )
( cd usr/share/terminfo/t ; rm -rf tek4109 )
( cd usr/share/terminfo/t ; ln -sf ../t/tek4107 tek4109 )
( cd usr/share/terminfo/t ; rm -rf tek4114 )
( cd usr/share/terminfo/t ; ln -sf ../t/tek4112 tek4114 )
( cd usr/share/terminfo/t ; rm -rf teleray )
( cd usr/share/terminfo/t ; ln -sf ../t/t1061 teleray )
( cd usr/share/terminfo/t ; rm -rf tty5420+nl )
( cd usr/share/terminfo/t ; ln -sf ../a/att4415+nl tty5420+nl )
( cd usr/share/terminfo/t ; rm -rf tty5420-nl )
( cd usr/share/terminfo/t ; ln -sf ../a/att4415-nl tty5420-nl )
( cd usr/share/terminfo/t ; rm -rf tty5420-rv )
( cd usr/share/terminfo/t ; ln -sf ../a/att4415-rv tty5420-rv )
( cd usr/share/terminfo/t ; rm -rf tty5425-nl )
( cd usr/share/terminfo/t ; ln -sf ../a/att5425-nl tty5425-nl )
( cd usr/share/terminfo/t ; rm -rf tvi920c-2p-mc )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-2p-mc tvi920c-2p-mc )
( cd usr/share/terminfo/t ; rm -rf ts100-sp )
( cd usr/share/terminfo/t ; ln -sf ../t/ts100 ts100-sp )
( cd usr/share/terminfo/t ; rm -rf tty5620-24 )
( cd usr/share/terminfo/t ; ln -sf ../a/att5620-24 tty5620-24 )
( cd usr/share/terminfo/t ; rm -rf tty5620-34 )
( cd usr/share/terminfo/t ; ln -sf ../a/att5620-34 tty5620-34 )
( cd usr/share/terminfo/t ; rm -rf tvi912c-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-2p tvi912c-2p )
( cd usr/share/terminfo/t ; rm -rf tvi912c-mc )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-mc tvi912c-mc )
( cd usr/share/terminfo/t ; rm -rf tvi912c-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-vb tvi912c-vb )
( cd usr/share/terminfo/t ; rm -rf tvi920c-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-2p tvi920c-2p )
( cd usr/share/terminfo/t ; rm -rf tvi920c-mc )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-mc tvi920c-mc )
( cd usr/share/terminfo/t ; rm -rf tvi920c-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-vb tvi920c-vb )
( cd usr/share/terminfo/t ; rm -rf tvi920c-mc-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-2p-mc tvi920c-mc-2p )
( cd usr/share/terminfo/t ; rm -rf tvi920c-mc-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-vb-mc tvi920c-mc-vb )
( cd usr/share/terminfo/t ; rm -rf tvi920c-vb-mc )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-vb-mc tvi920c-vb-mc )
( cd usr/share/terminfo/t ; rm -rf tty4424m )
( cd usr/share/terminfo/t ; ln -sf ../a/att4424m tty4424m )
( cd usr/share/terminfo/t ; rm -rf tvi912c-vb-unk )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-vb-unk tvi912c-vb-unk )
( cd usr/share/terminfo/t ; rm -rf trs80II )
( cd usr/share/terminfo/t ; ln -sf ../t/trs2 trs80II )
( cd usr/share/terminfo/t ; rm -rf tvi912c-unk-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-2p-unk tvi912c-unk-2p )
( cd usr/share/terminfo/t ; rm -rf tvi912c-unk-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-vb-unk tvi912c-unk-vb )
( cd usr/share/terminfo/t ; rm -rf tty4420 )
( cd usr/share/terminfo/t ; ln -sf ../a/att4420 tty4420 )
( cd usr/share/terminfo/t ; rm -rf tty4424 )
( cd usr/share/terminfo/t ; ln -sf ../a/att4424 tty4424 )
( cd usr/share/terminfo/t ; rm -rf tty4426 )
( cd usr/share/terminfo/t ; ln -sf ../a/att4426 tty4426 )
( cd usr/share/terminfo/t ; rm -rf tty5410 )
( cd usr/share/terminfo/t ; ln -sf ../a/att4410 tty5410 )
( cd usr/share/terminfo/t ; rm -rf tty5420 )
( cd usr/share/terminfo/t ; ln -sf ../a/att4415 tty5420 )
( cd usr/share/terminfo/t ; rm -rf tty5425 )
( cd usr/share/terminfo/t ; ln -sf ../a/att5425 tty5425 )
( cd usr/share/terminfo/t ; rm -rf tty5620 )
( cd usr/share/terminfo/t ; ln -sf ../a/att5620 tty5620 )
( cd usr/share/terminfo/t ; rm -rf tvi912c )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b tvi912c )
( cd usr/share/terminfo/t ; rm -rf tvi920c )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b tvi920c )
( cd usr/share/terminfo/t ; rm -rf tgtelnet )
( cd usr/share/terminfo/t ; ln -sf ../p/pilot tgtelnet )
( cd usr/share/terminfo/t ; rm -rf tty5410v1-w )
( cd usr/share/terminfo/t ; ln -sf ../a/att4410v1-w tty5410v1-w )
( cd usr/share/terminfo/t ; rm -rf tvi920c-vb-unk )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-vb-unk tvi920c-vb-unk )
( cd usr/share/terminfo/t ; rm -rf tvi912c-2p-unk )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-2p-unk tvi912c-2p-unk )
( cd usr/share/terminfo/t ; rm -rf tn1200 )
( cd usr/share/terminfo/t ; ln -sf ../t/terminet1200 tn1200 )
( cd usr/share/terminfo/t ; rm -rf tvi920c-unk-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-2p-unk tvi920c-unk-2p )
( cd usr/share/terminfo/t ; rm -rf tvi920c-unk-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-vb-unk tvi920c-unk-vb )
( cd usr/share/terminfo/t ; rm -rf tkterm )
( cd usr/share/terminfo/t ; ln -sf ../t/tt tkterm )
( cd usr/share/terminfo/t ; rm -rf ttydmd )
( cd usr/share/terminfo/t ; ln -sf ../a/att5620 ttydmd )
( cd usr/share/terminfo/t ; rm -rf tvi914 )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912 tvi914 )
( cd usr/share/terminfo/t ; rm -rf tvi920 )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912 tvi920 )
( cd usr/share/terminfo/t ; rm -rf tvi920c-2p-unk )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-2p-unk tvi920c-2p-unk )
( cd usr/share/terminfo/t ; rm -rf tvi912b-p-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-2p-p tvi912b-p-2p )
( cd usr/share/terminfo/t ; rm -rf tvi912b-p-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-vb-p tvi912b-p-vb )
( cd usr/share/terminfo/t ; rm -rf tvi912c-2p-p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-2p-p tvi912c-2p-p )
( cd usr/share/terminfo/t ; rm -rf tvi912c-p-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-2p-p tvi912c-p-2p )
( cd usr/share/terminfo/t ; rm -rf tvi912c-p-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-vb-p tvi912c-p-vb )
( cd usr/share/terminfo/t ; rm -rf tvi912c-vb-p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-vb-p tvi912c-vb-p )
( cd usr/share/terminfo/t ; rm -rf tty5420-rv-nl )
( cd usr/share/terminfo/t ; ln -sf ../a/att4415-rv-nl tty5420-rv-nl )
( cd usr/share/terminfo/t ; rm -rf tvi912c-p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-p tvi912c-p )
( cd usr/share/terminfo/t ; rm -rf tvi920c-p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi920b-p tvi920c-p )
( cd usr/share/terminfo/t ; rm -rf ti916-220-7 )
( cd usr/share/terminfo/t ; ln -sf ../t/ti916 ti916-220-7 )
( cd usr/share/terminfo/t ; rm -rf ti916-220-8 )
( cd usr/share/terminfo/t ; ln -sf ../t/ti916-8 ti916-220-8 )
( cd usr/share/terminfo/t ; rm -rf tty4424-1 )
( cd usr/share/terminfo/t ; ln -sf ../a/att4424-1 tty4424-1 )
( cd usr/share/terminfo/t ; rm -rf tty5410-w )
( cd usr/share/terminfo/t ; ln -sf ../a/att5410-w tty5410-w )
( cd usr/share/terminfo/t ; rm -rf tty5410v1 )
( cd usr/share/terminfo/t ; ln -sf ../a/att5410v1 tty5410v1 )
( cd usr/share/terminfo/t ; rm -rf tty5420-w )
( cd usr/share/terminfo/t ; ln -sf ../a/att4415-w tty5420-w )
( cd usr/share/terminfo/t ; rm -rf tty5425-w )
( cd usr/share/terminfo/t ; ln -sf ../a/att5425-w tty5425-w )
( cd usr/share/terminfo/t ; rm -rf tty5620-1 )
( cd usr/share/terminfo/t ; ln -sf ../a/att5620-1 tty5620-1 )
( cd usr/share/terminfo/t ; rm -rf tty5620-s )
( cd usr/share/terminfo/t ; ln -sf ../a/att5620-s tty5620-s )
( cd usr/share/terminfo/t ; rm -rf tvi912b-unk-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-2p-unk tvi912b-unk-2p )
( cd usr/share/terminfo/t ; rm -rf tvi912b-unk-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-vb-unk tvi912b-unk-vb )
( cd usr/share/terminfo/t ; rm -rf tvi912c-unk )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-unk tvi912c-unk )
( cd usr/share/terminfo/t ; rm -rf tvi912b-mc-2p )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-2p-mc tvi912b-mc-2p )
( cd usr/share/terminfo/t ; rm -rf tvi912b-mc-vb )
( cd usr/share/terminfo/t ; ln -sf ../t/tvi912b-vb-mc tvi912b-mc-vb )
( cd usr/share/terminfo/u ; rm -rf uniterm49 )
( cd usr/share/terminfo/u ; ln -sf ../u/uniterm uniterm49 )
( cd usr/share/terminfo/u ; rm -rf ultima2 )
( cd usr/share/terminfo/u ; ln -sf ../i/ims-ansi ultima2 )
( cd usr/share/terminfo/u ; rm -rf unixpc )
( cd usr/share/terminfo/u ; ln -sf ../a/att7300 unixpc )
( cd usr/share/terminfo/u ; rm -rf ultimaII )
( cd usr/share/terminfo/u ; ln -sf ../i/ims-ansi ultimaII )
( cd usr/share/terminfo/v ; rm -rf vtnt )
( cd usr/share/terminfo/v ; ln -sf ../m/ms-vt100-color vtnt )
( cd usr/share/terminfo/v ; rm -rf vip7800-H )
( cd usr/share/terminfo/v ; ln -sf ../v/vip-H vip7800-H )
( cd usr/share/terminfo/v ; rm -rf vip7800-w )
( cd usr/share/terminfo/v ; ln -sf ../v/vip-w vip7800-w )
( cd usr/share/terminfo/v ; rm -rf v200-nam )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-nam v200-nam )
( cd usr/share/terminfo/v ; rm -rf v320n )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320nam v320n )
( cd usr/share/terminfo/v ; rm -rf vc103 )
( cd usr/share/terminfo/v ; ln -sf ../v/vc303 vc103 )
( cd usr/share/terminfo/v ; rm -rf vc203 )
( cd usr/share/terminfo/v ; ln -sf ../v/vc303 vc203 )
( cd usr/share/terminfo/v ; rm -rf vk100 )
( cd usr/share/terminfo/v ; ln -sf ../g/gigi vk100 )
( cd usr/share/terminfo/v ; rm -rf venix )
( cd usr/share/terminfo/v ; ln -sf ../p/pc-venix venix )
( cd usr/share/terminfo/v ; rm -rf vitty )
( cd usr/share/terminfo/v ; ln -sf ../a/att5620-s vitty )
( cd usr/share/terminfo/v ; rm -rf vs100 )
( cd usr/share/terminfo/v ; ln -sf ../x/xterm-24 vs100 )
( cd usr/share/terminfo/v ; rm -rf vt-61 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt61 vt-61 )
( cd usr/share/terminfo/v ; rm -rf vt200 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220 vt200 )
( cd usr/share/terminfo/v ; rm -rf vt300 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320 vt300 )
( cd usr/share/terminfo/v ; rm -rf vt330 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt340 vt330 )
( cd usr/share/terminfo/v ; rm -rf vv100 )
( cd usr/share/terminfo/v ; ln -sf ../m/mvterm vv100 )
( cd usr/share/terminfo/v ; rm -rf vt100-bot-s )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-s-bot vt100-bot-s )
( cd usr/share/terminfo/v ; rm -rf viewpoint3a+ )
( cd usr/share/terminfo/v ; ln -sf ../v/vp3a+ viewpoint3a+ )
( cd usr/share/terminfo/v ; rm -rf vt100-nam-w )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-w-nam vt100-nam-w )
( cd usr/share/terminfo/v ; rm -rf vt100-s-top )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-s vt100-s-top )
( cd usr/share/terminfo/v ; rm -rf vt100-w-nav )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-nav-w vt100-w-nav )
( cd usr/share/terminfo/v ; rm -rf vt100-top-s )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-s vt100-top-s )
( cd usr/share/terminfo/v ; rm -rf viewpoint60 )
( cd usr/share/terminfo/v ; ln -sf ../v/vp60 viewpoint60 )
( cd usr/share/terminfo/v ; rm -rf viewpoint90 )
( cd usr/share/terminfo/v ; ln -sf ../v/vp90 viewpoint90 )
( cd usr/share/terminfo/v ; rm -rf vt200-8bit )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-8bit vt200-8bit )
( cd usr/share/terminfo/v ; rm -rf vt300-w-nam )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320-w-nam vt300-w-nam )
( cd usr/share/terminfo/v ; rm -rf visual603 )
( cd usr/share/terminfo/v ; ln -sf ../v/vi603 visual603 )
( cd usr/share/terminfo/v ; rm -rf vt100-nam )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100nam vt100-nam )
( cd usr/share/terminfo/v ; rm -rf vip7800-Hw )
( cd usr/share/terminfo/v ; ln -sf ../v/vip-Hw vip7800-Hw )
( cd usr/share/terminfo/v ; rm -rf vt200-old )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-old vt200-old )
( cd usr/share/terminfo/v ; rm -rf vc403a )
( cd usr/share/terminfo/v ; ln -sf ../v/vc303a vc403a )
( cd usr/share/terminfo/v ; rm -rf vc414h )
( cd usr/share/terminfo/v ; ln -sf ../v/vc414 vc414h )
( cd usr/share/terminfo/v ; rm -rf vapple )
( cd usr/share/terminfo/v ; ln -sf ../a/apple-videx3 vapple )
( cd usr/share/terminfo/v ; rm -rf vt100+ )
( cd usr/share/terminfo/v ; ln -sf ../m/ms-vt100+ vt100+ )
( cd usr/share/terminfo/v ; rm -rf vt61.5 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt61 vt61.5 )
( cd usr/share/terminfo/v ; rm -rf vt100-bm-o )
( cd usr/share/terminfo/v ; ln -sf ../n/nwp512-o vt100-bm-o )
( cd usr/share/terminfo/v ; rm -rf vt100-w-am )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-w vt100-w-am )
( cd usr/share/terminfo/v ; rm -rf vt100-am )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100 vt100-am )
( cd usr/share/terminfo/v ; rm -rf vt100-bm )
( cd usr/share/terminfo/v ; ln -sf ../n/nwp512 vt100-bm )
( cd usr/share/terminfo/v ; rm -rf vt220-js )
( cd usr/share/terminfo/v ; ln -sf ../v/vt200-js vt220-js )
( cd usr/share/terminfo/v ; rm -rf vt200-8 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-8bit vt200-8 )
( cd usr/share/terminfo/v ; rm -rf vt200-w )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-w vt200-w )
( cd usr/share/terminfo/v ; rm -rf vt220-8 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-8bit vt220-8 )
( cd usr/share/terminfo/v ; rm -rf vt300-w )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320-w vt300-w )
( cd usr/share/terminfo/v ; rm -rf vt-utf8 )
( cd usr/share/terminfo/v ; ln -sf ../m/ms-vt-utf8 vt-utf8 )
( cd usr/share/terminfo/v ; rm -rf vt300-nam )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320-nam vt300-nam )
( cd usr/share/terminfo/v ; rm -rf vt400-24 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt400 vt400-24 )
( cd usr/share/terminfo/v ; rm -rf vs100-x10 )
( cd usr/share/terminfo/v ; ln -sf ../x/x10term vs100-x10 )
( cd usr/share/terminfo/w ; rm -rf wyse150-w-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-w-vb wyse150-w-vb )
( cd usr/share/terminfo/w ; rm -rf wy-75ap )
( cd usr/share/terminfo/w ; ln -sf ../w/wy75ap wy-75ap )
( cd usr/share/terminfo/w ; rm -rf wy150-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-w wy150-w )
( cd usr/share/terminfo/w ; rm -rf wren )
( cd usr/share/terminfo/w ; ln -sf ../p/pt100 wren )
( cd usr/share/terminfo/w ; rm -rf wy60-AT )
( cd usr/share/terminfo/w ; ln -sf ../i/ibm5151 wy60-AT )
( cd usr/share/terminfo/w ; rm -rf wy60-PC )
( cd usr/share/terminfo/w ; ln -sf ../i/ibmpc wy60-PC )
( cd usr/share/terminfo/w ; rm -rf wy99fgt )
( cd usr/share/terminfo/w ; ln -sf ../w/wy99f wy99fgt )
( cd usr/share/terminfo/w ; rm -rf wyse-325 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-25 wyse-325 )
( cd usr/share/terminfo/w ; rm -rf wyse50-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy50-w wyse50-w )
( cd usr/share/terminfo/w ; rm -rf wyse60-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy60-w wyse60-w )
( cd usr/share/terminfo/w ; rm -rf wyse75-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy75-w wyse75-w )
( cd usr/share/terminfo/w ; rm -rf wyse75ap )
( cd usr/share/terminfo/w ; ln -sf ../w/wy75ap wyse75ap )
( cd usr/share/terminfo/w ; rm -rf wyse85-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy85-w wyse85-w )
( cd usr/share/terminfo/w ; rm -rf wyse99gt )
( cd usr/share/terminfo/w ; ln -sf ../w/wy99gt wyse99gt )
( cd usr/share/terminfo/w ; rm -rf wy370-101k )
( cd usr/share/terminfo/w ; ln -sf ../w/wy370 wy370-101k )
( cd usr/share/terminfo/w ; rm -rf wy-99fgt )
( cd usr/share/terminfo/w ; ln -sf ../w/wy99f wy-99fgt )
( cd usr/share/terminfo/w ; rm -rf wyse120 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120 wyse120 )
( cd usr/share/terminfo/w ; rm -rf wyse150 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120 wyse150 )
( cd usr/share/terminfo/w ; rm -rf wyse160 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy160 wyse160 )
( cd usr/share/terminfo/w ; rm -rf wyse185 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy185 wyse185 )
( cd usr/share/terminfo/w ; rm -rf wyse325 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325 wyse325 )
( cd usr/share/terminfo/w ; rm -rf wyse350 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy350 wyse350 )
( cd usr/share/terminfo/w ; rm -rf wyse370 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy370 wyse370 )
( cd usr/share/terminfo/w ; rm -rf wyse520 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520 wyse520 )
( cd usr/share/terminfo/w ; rm -rf wy120-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-w-vb wy120-wvb )
( cd usr/share/terminfo/w ; rm -rf wy150-25 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-25 wy150-25 )
( cd usr/share/terminfo/w ; rm -rf wy150-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-vb wy150-vb )
( cd usr/share/terminfo/w ; rm -rf wy325-80 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-25 wy325-80 )
( cd usr/share/terminfo/w ; rm -rf wyse160-25-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy160-25-w wyse160-25-w )
( cd usr/share/terminfo/w ; rm -rf wyse160-42-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy160-42-w wyse160-42-w )
( cd usr/share/terminfo/w ; rm -rf wyse160-43-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy160-43-w wyse160-43-w )
( cd usr/share/terminfo/w ; rm -rf wy160-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy160-w-vb wy160-wvb )
( cd usr/share/terminfo/w ; rm -rf wrenw )
( cd usr/share/terminfo/w ; ln -sf ../p/pt100w wrenw )
( cd usr/share/terminfo/w ; rm -rf wy150 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120 wy150 )
( cd usr/share/terminfo/w ; rm -rf wy60-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy60-w-vb wy60-wvb )
( cd usr/share/terminfo/w ; rm -rf wyse99gt-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy99gt-w-vb wyse99gt-wvb )
( cd usr/share/terminfo/w ; rm -rf wy99fgta )
( cd usr/share/terminfo/w ; ln -sf ../w/wy99fa wy99fgta )
( cd usr/share/terminfo/w ; rm -rf wyse120-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-w-vb wyse120-wvb )
( cd usr/share/terminfo/w ; rm -rf wy325-42wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-42w-vb wy325-42wvb )
( cd usr/share/terminfo/w ; rm -rf wy325-43wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-43w-vb wy325-43wvb )
( cd usr/share/terminfo/w ; rm -rf wyse160-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy160-w-vb wyse160-wvb )
( cd usr/share/terminfo/w ; rm -rf wyse85-8bit )
( cd usr/share/terminfo/w ; ln -sf ../w/wy85-8bit wyse85-8bit )
( cd usr/share/terminfo/w ; rm -rf wyse185-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy185-wvb wyse185-wvb )
( cd usr/share/terminfo/w ; rm -rf wyse120-25 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-25 wyse120-25 )
( cd usr/share/terminfo/w ; rm -rf wyse120-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-vb wyse120-vb )
( cd usr/share/terminfo/w ; rm -rf wyse150-25 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-25 wyse150-25 )
( cd usr/share/terminfo/w ; rm -rf wyse150-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-vb wyse150-vb )
( cd usr/share/terminfo/w ; rm -rf wyse160-25 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy160-25 wyse160-25 )
( cd usr/share/terminfo/w ; rm -rf wyse160-42 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy160-42 wyse160-42 )
( cd usr/share/terminfo/w ; rm -rf wyse160-43 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy160-43 wyse160-43 )
( cd usr/share/terminfo/w ; rm -rf wyse160-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy160-vb wyse160-vb )
( cd usr/share/terminfo/w ; rm -rf wyse185-24 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy185-24 wyse185-24 )
( cd usr/share/terminfo/w ; rm -rf wyse185-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy185-vb wyse185-vb )
( cd usr/share/terminfo/w ; rm -rf wyse-75ap )
( cd usr/share/terminfo/w ; ln -sf ../w/wy75ap wyse-75ap )
( cd usr/share/terminfo/w ; rm -rf wyse120-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-w wyse120-w )
( cd usr/share/terminfo/w ; rm -rf wyse150-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-w wyse150-w )
( cd usr/share/terminfo/w ; rm -rf wyse160-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy160-w wyse160-w )
( cd usr/share/terminfo/w ; rm -rf wyse185-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy185-w wyse185-w )
( cd usr/share/terminfo/w ; rm -rf wy325-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-w-vb wy325-wvb )
( cd usr/share/terminfo/w ; rm -rf wyse30-mc )
( cd usr/share/terminfo/w ; ln -sf ../w/wy30-mc wyse30-mc )
( cd usr/share/terminfo/w ; rm -rf wyse30-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy30-vb wyse30-vb )
( cd usr/share/terminfo/w ; rm -rf wyse325-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-w wyse325-w )
( cd usr/share/terminfo/w ; rm -rf wyse350-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy350-w wyse350-w )
( cd usr/share/terminfo/w ; rm -rf wyse50-mc )
( cd usr/share/terminfo/w ; ln -sf ../w/wy50-mc wyse50-mc )
( cd usr/share/terminfo/w ; rm -rf wyse50-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy50-vb wyse50-vb )
( cd usr/share/terminfo/w ; rm -rf wyse520-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-w wyse520-w )
( cd usr/share/terminfo/w ; rm -rf wyse60-25 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy60-25 wyse60-25 )
( cd usr/share/terminfo/w ; rm -rf wyse60-42 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy60-42 wyse60-42 )
( cd usr/share/terminfo/w ; rm -rf wyse60-43 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy60-43 wyse60-43 )
( cd usr/share/terminfo/w ; rm -rf wyse60-AT )
( cd usr/share/terminfo/w ; ln -sf ../i/ibm5151 wyse60-AT )
( cd usr/share/terminfo/w ; rm -rf wyse60-PC )
( cd usr/share/terminfo/w ; ln -sf ../i/ibmpc wyse60-PC )
( cd usr/share/terminfo/w ; rm -rf wyse60-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy60-vb wyse60-vb )
( cd usr/share/terminfo/w ; rm -rf wyse520-36wpc )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-36wpc wyse520-36wpc )
( cd usr/share/terminfo/w ; rm -rf wyse520-48wpc )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-48wpc wyse520-48wpc )
( cd usr/share/terminfo/w ; rm -rf wyse75-mc )
( cd usr/share/terminfo/w ; ln -sf ../w/wy75-mc wyse75-mc )
( cd usr/share/terminfo/w ; rm -rf wyse75-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy75-vb wyse75-vb )
( cd usr/share/terminfo/w ; rm -rf wy325w-24 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-w wy325w-24 )
( cd usr/share/terminfo/w ; rm -rf wyse85-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy85-vb wyse85-vb )
( cd usr/share/terminfo/w ; rm -rf wyse325-25 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-25 wyse325-25 )
( cd usr/share/terminfo/w ; rm -rf wyse325-42 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-42 wyse325-42 )
( cd usr/share/terminfo/w ; rm -rf wyse325-43 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-43 wyse325-43 )
( cd usr/share/terminfo/w ; rm -rf wyse325-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-vb wyse325-vb )
( cd usr/share/terminfo/w ; rm -rf wyse350-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy350-vb wyse350-vb )
( cd usr/share/terminfo/w ; rm -rf wyse50-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy50-wvb wyse50-wvb )
( cd usr/share/terminfo/w ; rm -rf wyse520-24 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-24 wyse520-24 )
( cd usr/share/terminfo/w ; rm -rf wyse520-36 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-36 wyse520-36 )
( cd usr/share/terminfo/w ; rm -rf wyse520-48 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-48 wyse520-48 )
( cd usr/share/terminfo/w ; rm -rf wyse520-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-vb wyse520-vb )
( cd usr/share/terminfo/w ; rm -rf wyse60-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy60-w-vb wyse60-wvb )
( cd usr/share/terminfo/w ; rm -rf wyse75-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy75-wvb wyse75-wvb )
( cd usr/share/terminfo/w ; rm -rf wyse520-epc-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-epc-w wyse520-epc-w )
( cd usr/share/terminfo/w ; rm -rf wyse520-p-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-epc-wvb wyse520-p-wvb )
( cd usr/share/terminfo/w ; rm -rf wyse85-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy85-wvb wyse85-wvb )
( cd usr/share/terminfo/w ; rm -rf wyse520-pc-24 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-epc-24 wyse520-pc-24 )
( cd usr/share/terminfo/w ; rm -rf wyse520-pc-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-epc-vb wyse520-pc-vb )
( cd usr/share/terminfo/w ; rm -rf wyse99gt-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy99gt-w wyse99gt-w )
( cd usr/share/terminfo/w ; rm -rf wyse325-25w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-25w wyse325-25w )
( cd usr/share/terminfo/w ; rm -rf wyse325-42w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-42w wyse325-42w )
( cd usr/share/terminfo/w ; rm -rf wyse325-43w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-43w wyse325-43w )
( cd usr/share/terminfo/w ; rm -rf wyse325-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy325-w-vb wyse325-wvb )
( cd usr/share/terminfo/w ; rm -rf wyse120-25-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-25-w wyse120-25-w )
( cd usr/share/terminfo/w ; rm -rf wyse99gt-25 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy99gt-25 wyse99gt-25 )
( cd usr/share/terminfo/w ; rm -rf wyse99gt-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy99gt-vb wyse99gt-vb )
( cd usr/share/terminfo/w ; rm -rf wy150-25-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-25-w wy150-25-w )
( cd usr/share/terminfo/w ; rm -rf wyse350-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy350-wvb wyse350-wvb )
( cd usr/share/terminfo/w ; rm -rf wy150-w-vb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-w-vb wy150-w-vb )
( cd usr/share/terminfo/w ; rm -rf wy-99fgta )
( cd usr/share/terminfo/w ; ln -sf ../w/wy99fa wy-99fgta )
( cd usr/share/terminfo/w ; rm -rf wy99gt-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy99gt-w-vb wy99gt-wvb )
( cd usr/share/terminfo/w ; rm -rf wyse30 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy30 wyse30 )
( cd usr/share/terminfo/w ; rm -rf wyse50 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy50 wyse50 )
( cd usr/share/terminfo/w ; rm -rf wyse60 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy60 wyse60 )
( cd usr/share/terminfo/w ; rm -rf wyse75 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy75 wyse75 )
( cd usr/share/terminfo/w ; rm -rf wyse85 )
( cd usr/share/terminfo/w ; ln -sf ../w/wy85 wyse85 )
( cd usr/share/terminfo/w ; rm -rf wy60-316X )
( cd usr/share/terminfo/w ; ln -sf ../i/ibm3161 wy60-316X )
( cd usr/share/terminfo/w ; rm -rf wyse99gt-25-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy99gt-25-w wyse99gt-25-w )
( cd usr/share/terminfo/w ; rm -rf wyse520-36w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-36w wyse520-36w )
( cd usr/share/terminfo/w ; rm -rf wyse520-48w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-48w wyse520-48w )
( cd usr/share/terminfo/w ; rm -rf wyse520-epc )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-epc wyse520-epc )
( cd usr/share/terminfo/w ; rm -rf wyse520-wvb )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-wvb wyse520-wvb )
( cd usr/share/terminfo/w ; rm -rf wyse60-25-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy60-25-w wyse60-25-w )
( cd usr/share/terminfo/w ; rm -rf wyse60-316X )
( cd usr/share/terminfo/w ; ln -sf ../i/ibm3161 wyse60-316X )
( cd usr/share/terminfo/w ; rm -rf wyse60-42-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy60-42-w wyse60-42-w )
( cd usr/share/terminfo/w ; rm -rf wyse60-43-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy60-43-w wyse60-43-w )
( cd usr/share/terminfo/w ; rm -rf wyse520-36pc )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-36pc wyse520-36pc )
( cd usr/share/terminfo/w ; rm -rf wyse520-48pc )
( cd usr/share/terminfo/w ; ln -sf ../w/wy520-48pc wyse520-48pc )
( cd usr/share/terminfo/w ; rm -rf wyse150-25-w )
( cd usr/share/terminfo/w ; ln -sf ../w/wy120-25-w wyse150-25-w )
( cd usr/share/terminfo/x ; rm -rf x820 )
( cd usr/share/terminfo/x ; ln -sf ../x/xerox820 x820 )
( cd usr/share/terminfo/x ; rm -rf xdku )
( cd usr/share/terminfo/x ; ln -sf ../t/tws2103 xdku )
( cd usr/share/terminfo/x ; rm -rf xl83 )
( cd usr/share/terminfo/x ; ln -sf ../c/cyb83 xl83 )
( cd usr/share/terminfo/x ; rm -rf xwsh )
( cd usr/share/terminfo/x ; ln -sf ../i/iris-color xwsh )
( cd usr/share/terminfo/x ; rm -rf x68k-ite )
( cd usr/share/terminfo/x ; ln -sf ../x/x68k x68k-ite )
( cd usr/share/terminfo/x ; rm -rf x1700 )
( cd usr/share/terminfo/x ; ln -sf ../d/diablo1640 x1700 )
( cd usr/share/terminfo/x ; rm -rf x1720 )
( cd usr/share/terminfo/x ; ln -sf ../x/xerox1720 x1720 )
( cd usr/share/terminfo/x ; rm -rf x1750 )
( cd usr/share/terminfo/x ; ln -sf ../x/xerox1720 x1750 )
( cd usr/share/terminfo/x ; rm -rf xenix )
( cd usr/share/terminfo/x ; ln -sf ../i/ibmpcx xenix )
( cd usr/share/terminfo/x ; rm -rf xerox )
( cd usr/share/terminfo/x ; ln -sf ../d/diablo1640 xerox )
( cd usr/share/terminfo/x ; rm -rf xterm-new )
( cd usr/share/terminfo/x ; ln -sf ../x/xterm-xfree86 xterm-new )
( cd usr/share/terminfo/x ; rm -rf xterm-old )
( cd usr/share/terminfo/x ; ln -sf ../x/xterm-r6 xterm-old )
( cd usr/share/terminfo/x ; rm -rf x1700-lm )
( cd usr/share/terminfo/x ; ln -sf ../d/diablo1740-lm x1700-lm )
( cd usr/share/terminfo/x ; rm -rf xerox-lm )
( cd usr/share/terminfo/x ; ln -sf ../d/diablo1640-lm xerox-lm )
( cd usr/share/terminfo/x ; rm -rf xterms )
( cd usr/share/terminfo/x ; ln -sf ../x/xterm-24 xterms )
( cd usr/share/terminfo/z ; rm -rf z19 )
( cd usr/share/terminfo/z ; ln -sf ../h/h19 z19 )
( cd usr/share/terminfo/z ; rm -rf z30 )
( cd usr/share/terminfo/z ; ln -sf ../z/zen30 z30 )
( cd usr/share/terminfo/z ; rm -rf z50 )
( cd usr/share/terminfo/z ; ln -sf ../z/zen50 z50 )
( cd usr/share/terminfo/z ; rm -rf z110 )
( cd usr/share/terminfo/z ; ln -sf ../z/z100 z110 )
( cd usr/share/terminfo/z ; rm -rf z29b )
( cd usr/share/terminfo/z ; ln -sf ../z/z29 z29b )
( cd usr/share/terminfo/z ; rm -rf z39a )
( cd usr/share/terminfo/z ; ln -sf ../z/z39-a z39a )
( cd usr/share/terminfo/z ; rm -rf zt-1 )
( cd usr/share/terminfo/z ; ln -sf ../z/ztx zt-1 )
( cd usr/share/terminfo/z ; rm -rf zenith39-a )
( cd usr/share/terminfo/z ; ln -sf ../z/z39-a zenith39-a )
( cd usr/share/terminfo/z ; rm -rf z-100 )
( cd usr/share/terminfo/z ; ln -sf ../z/z100 z-100 )
( cd usr/share/terminfo/z ; rm -rf z8001 )
( cd usr/share/terminfo/z ; ln -sf ../c/cci z8001 )
( cd usr/share/terminfo/z ; rm -rf ztx11 )
( cd usr/share/terminfo/z ; ln -sf ../z/ztx ztx11 )
( cd usr/share/terminfo/z ; rm -rf zenith39-ansi )
( cd usr/share/terminfo/z ; ln -sf ../z/z39-a zenith39-ansi )
( cd usr/share/terminfo/z ; rm -rf zen8001 )
( cd usr/share/terminfo/z ; ln -sf ../c/cci zen8001 )
( cd usr/share/terminfo/z ; rm -rf z-100bw )
( cd usr/share/terminfo/z ; ln -sf ../z/z100bw z-100bw )
( cd usr/share/terminfo/z ; rm -rf ztx-1-a )
( cd usr/share/terminfo/z ; ln -sf ../z/ztx ztx-1-a )
( cd usr/share/terminfo/z ; rm -rf z110bw )
( cd usr/share/terminfo/z ; ln -sf ../z/z100bw z110bw )
( cd usr/share/terminfo/z ; rm -rf zenith )
( cd usr/share/terminfo/z ; ln -sf ../h/h19 zenith )
( cd usr/share/terminfo/z ; rm -rf z29a-kc-bc )
( cd usr/share/terminfo/z ; ln -sf ../z/z29a z29a-kc-bc )
( cd usr/share/terminfo/z ; rm -rf zenith29 )
( cd usr/share/terminfo/z ; ln -sf ../z/z29 zenith29 )
( cd usr/include ; rm -rf cursesapp.h )
( cd usr/include ; ln -sf ncurses/cursesapp.h cursesapp.h )
( cd usr/include ; rm -rf unctrl.h )
( cd usr/include ; ln -sf ncurses/unctrl.h unctrl.h )
( cd usr/include ; rm -rf eti.h )
( cd usr/include ; ln -sf ncurses/eti.h eti.h )
( cd usr/include ; rm -rf curses.h )
( cd usr/include ; ln -sf ncurses/curses.h curses.h )
( cd usr/include ; rm -rf etip.h )
( cd usr/include ; ln -sf ncurses/etip.h etip.h )
( cd usr/include/ncurses ; rm -rf ncurses.h )
( cd usr/include/ncurses ; ln -sf curses.h ncurses.h )
( cd usr/include ; rm -rf form.h )
( cd usr/include ; ln -sf ncurses/form.h form.h )
( cd usr/include ; rm -rf ncurses.h )
( cd usr/include ; ln -sf ncurses/ncurses.h ncurses.h )
( cd usr/include ; rm -rf menu.h )
( cd usr/include ; ln -sf ncurses/menu.h menu.h )
( cd usr/include ; rm -rf cursesf.h )
( cd usr/include ; ln -sf ncurses/cursesf.h cursesf.h )
( cd usr/include ; rm -rf cursesm.h )
( cd usr/include ; ln -sf ncurses/cursesm.h cursesm.h )
( cd usr/include ; rm -rf cursesp.h )
( cd usr/include ; ln -sf ncurses/cursesp.h cursesp.h )
( cd usr/include ; rm -rf cursesw.h )
( cd usr/include ; ln -sf ncurses/cursesw.h cursesw.h )
( cd usr/include ; rm -rf term.h )
( cd usr/include ; ln -sf ncurses/term.h term.h )
( cd usr/include ; rm -rf cursslk.h )
( cd usr/include ; ln -sf ncurses/cursslk.h cursslk.h )
( cd usr/include ; rm -rf panel.h )
( cd usr/include ; ln -sf ncurses/panel.h panel.h )
( cd usr/include ; rm -rf ncurses_dll.h )
( cd usr/include ; ln -sf ncurses/ncurses_dll.h ncurses_dll.h )
